(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1611372,      31382]
NotebookOptionsPosition[   1597361,      30943]
NotebookOutlinePosition[   1597745,      30960]
CellTagsIndexPosition[   1597702,      30957]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["RF AM Stabilization", "Title",
 CellChangeTimes->{{3.447176540308875*^9, 3.44717655098075*^9}, {
  3.449447792796875*^9, 3.44944779925*^9}, {3.449522699436625*^9, 
  3.449522699717875*^9}}],

Cell["\<\
T0900198-v1
April 22, 2009
Daniel Sigg
\
\>", "Subsubtitle",
 CellChangeTimes->{
  3.4428679809275*^9, 3.446833023320875*^9, {3.4471765541995*^9, 
   3.447176573512*^9}, {3.44718802016825*^9, 3.447188020887*^9}, {
   3.449447803671875*^9, 3.449447814953125*^9}, {3.449522835936625*^9, 
   3.449522837030375*^9}}],

Cell[CellGroupData[{

Cell["Theory of Operations", "Subtitle"],

Cell["\<\
The frequency stabilization circuit requires a low noise RF detector. The \
presented design uses a combination of series and shunt diode detectors in a \
differential arrangement to effectively quadruple the response. A parallel \
chain of diodes is used to both compensate for temperature drifts and to \
remove a bias. Under nominal RF load this detector then has zero output and \
can directly be used in a compensation network to control a variable RF \
attenuator ahead of the detector. A relatively high bias current is applied \
to the diodes to minimize Johnson and flicker noise.\
\>", "Text",
 CellChangeTimes->{{3.447176586012*^9, 3.447176720262*^9}, {
  3.4480244727608747`*^9, 3.4480244907921247`*^9}, {3.44944782196875*^9, 
  3.44944785746875*^9}, {3.449447924046875*^9, 3.449448193140625*^9}, {
  3.450641079253625*^9, 3.450641104363*^9}, {3.450641692784875*^9, 
  3.450641693066125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specifications", "Subtitle"],

Cell[TextData[{
 "TBD.",
 StyleBox["\n",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.447176586012*^9, 3.447176720262*^9}, {3.447176765512*^9,
   3.447176766465125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<BarCharts`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<PieCharts`\>\"", "]"}], ";", " ", 
  RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}], ";", " ", 
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}], "\n", 
 RowBox[{"Needs", "[", "\"\<Controls`LinearControl`\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.447186817308875*^9, 3.44718682460575*^9}, {
  3.448375377015625*^9, 3.4483753788125*^9}, {3.4483799034375*^9, 
  3.448379905703125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Definitions", "Subtitle",
 CellChangeTimes->{{3.447176974183875*^9, 3.447176980652625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FromdB", "[", "x_", "]"}], ":=", " ", 
  SuperscriptBox["10", 
   RowBox[{"x", "/", "20"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FromdBc", "[", "x_", "]"}], ":=", " ", 
  SuperscriptBox["10", 
   RowBox[{
    RowBox[{"-", "x"}], "/", "20"}]]}]}], "Input",
 CellChangeTimes->{{3.44717698429325*^9, 3.447177008996375*^9}, {
   3.447177168871375*^9, 3.447177169262*^9}, {3.448375416125*^9, 
   3.44837542875*^9}, {3.448380204390625*^9, 3.448380204875*^9}, {
   3.449451784203125*^9, 3.4494517875*^9}, 3.44945184875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoiseLevelBottom", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", "175", "]"}]}]], "Input",
 CellChangeTimes->{{3.447180482590125*^9, 3.447180488387*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model", "Subtitle",
 CellChangeTimes->{{3.4471767958245*^9, 3.44717679679325*^9}}],

Cell["Parallel and Serial Impedance", "Subsubtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"par", "[", 
   RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{
    FractionBox["1", "r1"], "+", 
    FractionBox["1", "r2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"par", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "r3_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{
    FractionBox["1", "r1"], "+", 
    FractionBox["1", "r2"], "+", 
    FractionBox["1", "r3"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ser", "[", 
   RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
  RowBox[{"r1", "+", "r2"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ser", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "r3_"}], "]"}], ":=", 
  RowBox[{"r1", "+", "r2", "+", "r3"}]}]}], "Input",
 CellChangeTimes->{{3.447515625697245*^9, 3.44751564138334*^9}, {
  3.4481980910637503`*^9, 3.4481980914075003`*^9}, {3.449497971499125*^9, 
  3.449498003046*^9}}],

Cell[CellGroupData[{

Cell["Pole/zero", "Subsubtitle",
 CellChangeTimes->{{3.4501428137642665`*^9, 3.4501428171236415`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pole", "[", 
   RowBox[{"f_", ",", "f0_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{"1", "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     FractionBox["f", "f0"]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zero", "[", 
   RowBox[{"f_", ",", "f0_"}], "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    FractionBox["f", "f0"]}]}]}]}], "Input",
 CellChangeTimes->{{3.4501428204986415`*^9, 3.4501428549986415`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Transfer ",
 Cell[BoxData[
  FormBox["Function", TraditionalForm]]],
 " of an OpAmp"
}], "Subsubtitle"],

Cell["\<\
This function computes the transfer function of an idealized OpAmp circuit
g: +1 for non-inverting configuration or -1 for inverting configuration, 0 \
for differential configuration
z2: Impedance in feedback path [Ohm]
z1: Impedance of input path (inverting) or impedance to ground \
(non-inverting) [Ohm]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OpAmp", "[", 
   RowBox[{"g_", ",", "z1_", ",", "z2_"}], "]"}], ":=", "\[IndentingNewLine]",
   
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"g", ">", "0"}], ",", 
    RowBox[{"1", "+", 
     FractionBox["z2", "z1"]}], ",", 
    RowBox[{"g", "<", "0"}], ",", 
    FractionBox["z2", "z1"], ",", "True", ",", " ", 
    FractionBox["z2", "z1"]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Noise of an OpAmp", "Subsubtitle"],

Cell["\<\
This function computes the equivalent input noise of an OpAmp circuit
g: +1 for non-inverting configuration or -1 for inverting configuration, 0 \
for differential configuration
z1: Impedance of input path (inverting) or impedance to ground \
(non-inverting) [Ohm]
z2: Impedance over feedback path [Ohm]
en: voltage noise [Volt]
in: current noise [Ampere]\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FourKT", "=", "1.62*^-20"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["V", "2"], "/", "Hz"}], "/", "Ohm"}], ";", " ", 
    RowBox[{"room", " ", "temperature", " ", "20", "C"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoise", "[", 
   RowBox[{"g_", ",", "z1_", ",", "z2_", ",", "en_", ",", "in_"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"g", ">", "0"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"z1", "\[Equal]", "Infinity"}], ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["en", "2"], "+", 
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", "z2", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"in", " ", 
           RowBox[{"Abs", "[", "z2", "]"}]}], ")"}], "2"]}]], ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["en", "2"], "+", 
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"par", "[", 
           RowBox[{"z1", ",", "z2"}], "]"}], "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"in", " ", 
           RowBox[{"Abs", "[", 
            RowBox[{"par", "[", 
             RowBox[{"z1", ",", "z2"}], "]"}], "]"}]}], ")"}], "2"]}]]}], 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"g", "<", "0"}], ",", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"1", "+", 
           FractionBox["z1", "z2"]}], "]"}], "2"], 
        SuperscriptBox["en", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "z1", "]"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["in", "2"], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z1"], "]"}], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z2"], "]"}]}], ")"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", "True", ",", " ", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"1", "+", 
           FractionBox["z1", "z2"]}], "]"}], "2"], 
        SuperscriptBox["en", "2"]}], "+", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "z1", "]"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["in", "2"], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z1"], "]"}], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z2"], "]"}]}], ")"}]}]}], ")"}]}]}], 
   "]"}]}]}], "Input"],

Cell["\<\
Flicker Noise: The variable $Flicker determines if flicker noise is added or \
not. It can also be explicitly specficied with the option Flicker.\
\>", "Text",
 CellChangeTimes->{{3.44949627895225*^9, 3.4494963331085*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Flicker", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "OpAmpNoiseFlicker", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "OpAmpNoiseFlicker", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"Flicker", "\[RuleDelayed]", "$Flicker"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoiseFlicker", "[", 
   RowBox[{"f_", ",", "fknee_", ",", "opts___"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Flicker", "/.", 
      RowBox[{"{", "opts", "}"}]}], "/.", 
     RowBox[{"Options", "[", "OpAmpNoiseFlicker", "]"}]}], ",", 
    SqrtBox[
     RowBox[{
      FractionBox["fknee", "f"], "+", "1"}]], ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoiseFlicker", "[", 
   RowBox[{"f_", ",", "fknee_", ",", "floor_", ",", "opts___"}], "]"}], ":=", 
  
  RowBox[{"floor", " ", 
   RowBox[{"OpAmpNoiseFlicker", "[", 
    RowBox[{"f", ",", "fknee", ",", "opts"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.449492983436625*^9, 3.449492983967875*^9}, {
  3.449493062311625*^9, 3.44949309057725*^9}, {3.449493128436625*^9, 
  3.4494931503585*^9}, {3.449493200717875*^9, 3.44949322232725*^9}, {
  3.449493349967875*^9, 3.449493369030375*^9}, {3.44949356382725*^9, 
  3.44949358195225*^9}, {3.4494955214835*^9, 3.449495521546*^9}, {
  3.449495836967875*^9, 3.449495864530375*^9}, {3.449495901905375*^9, 
  3.4494959422335*^9}, {3.449495976405375*^9, 3.449495981717875*^9}, {
  3.449496066374125*^9, 3.449496140171*^9}, {3.4494961832335*^9, 
  3.449496259921*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["OpAmp Parameters", "Subsubtitle",
 CellChangeTimes->{{3.44949523045225*^9, 3.449495233921*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"AD829", ",", "OP27"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AD829", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enAD829"}], ",", 
      RowBox[{"in", "\[Rule]", "inAD829"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorAD829"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorAD829"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enAD829", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeAD829", ",", "enfloorAD829"}], "]"}]}], ",", 
      RowBox[{"inAD829", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeAD829", ",", "infloorAD829"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ekneeAD829", "\[Rule]", "50"}], ",", 
      RowBox[{"ikneeAD829", "\[Rule]", "100"}], ",", 
      RowBox[{"(*", "guess", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"enfloorAD829", "\[Rule]", "1.7*^-9"}], ",", 
      RowBox[{"infloorAD829", "\[Rule]", "1.5*^-12"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OP27", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enOP27"}], ",", 
      RowBox[{"in", "\[Rule]", "inOP27"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorOP27"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorOP27"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enOP27", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeOP27", ",", "enfloorOP27"}], "]"}]}], ",", 
      RowBox[{"inOP27", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeOP27", ",", "infloorOP27"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ekneeOP27", "\[Rule]", "2.7"}], ",", 
      RowBox[{"ikneeOP27", "\[Rule]", "140"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloorOP27", "\[Rule]", "3.0*^-9"}], ",", 
      RowBox[{"infloorOP27", "\[Rule]", "0.4*^-12"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LT1028", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enLT1028"}], ",", 
      RowBox[{"in", "\[Rule]", "inLT1028"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorLT1028"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorLT1028"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enLT1028", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeLT1028", ",", "enfloorLT1028"}], "]"}]}], ",",
       
      RowBox[{"inLT1028", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeLT1028", ",", "infloorLT1028"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"ekneeLT1028", "\[Rule]", "3.5"}], ",", 
      RowBox[{"ikneeLT1028", "\[Rule]", "250"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloorLT1028", "\[Rule]", "0.85*^-9"}], ",", 
      RowBox[{"infloorLT1028", "\[Rule]", "1*^-12"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LT1128", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enLT1128"}], ",", 
      RowBox[{"in", "\[Rule]", "inLT1128"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorLT1128"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorLT1128"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enLT1128", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeLT1128", ",", "enfloorLT1128"}], "]"}]}], ",",
       
      RowBox[{"inLT1128", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeLT1128", ",", "infloorLT1128"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"ekneeLT1128", "\[Rule]", "3.5"}], ",", 
      RowBox[{"ikneeLT1128", "\[Rule]", "250"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloorLT1128", "\[Rule]", "0.85*^-9"}], ",", 
      RowBox[{"infloorLT1128", "\[Rule]", "1*^-12"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AD797", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enAD797"}], ",", 
      RowBox[{"in", "\[Rule]", "inAD797"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorAD797"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorAD797"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enAD797", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeAD797", ",", "enfloorAD797"}], "]"}]}], ",", 
      RowBox[{"inAD797", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeAD797", ",", "infloorAD797"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ekneeAD797", "\[Rule]", "50"}], ",", 
      RowBox[{"ikneeAD797", "\[Rule]", "100"}], ",", 
      RowBox[{"(*", "guess", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"enfloorAD797", "\[Rule]", "0.9*^-9"}], ",", 
      RowBox[{"infloorAD797", "\[Rule]", "2*^-12"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LT1012", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}], ",", 
      RowBox[{"en", "\[Rule]", "enLT1012"}], ",", 
      RowBox[{"in", "\[Rule]", "inLT1012"}], ",", "\[IndentingNewLine]", 
      RowBox[{"enfloor", "\[Rule]", "enfloorLT1012"}], ",", 
      RowBox[{"infloor", "\[Rule]", "infloorLT1012"}]}], "}"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"enLT1012", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ekneeLT1012", ",", "enfloorLT1012"}], "]"}]}], ",",
       
      RowBox[{"inLT1012", "\[Rule]", 
       RowBox[{"OpAmpNoiseFlicker", "[", 
        RowBox[{"f", ",", "ikneeLT1012", ",", "infloorLT1012"}], "]"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"ekneeLT1012", "\[Rule]", "2.5"}], ",", 
      RowBox[{"ikneeLT1012", "\[Rule]", "120"}], ",", 
      RowBox[{"(*", "guess", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"enfloorLT1012", "\[Rule]", "14*^-9"}], ",", 
      RowBox[{"infloorLT1012", "\[Rule]", "6*^-15"}]}], "}"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.449495245967875*^9, 3.449495354311625*^9}, {
  3.44949539345225*^9, 3.449495490421*^9}, {3.449495564905375*^9, 
  3.449495711874125*^9}, {3.449496421249125*^9, 3.449496466936625*^9}, {
  3.449496505155375*^9, 3.44949664520225*^9}, {3.44949678870225*^9, 
  3.449496842374125*^9}, {3.449496953186625*^9, 3.449496960342875*^9}, {
  3.4494970218585*^9, 3.44949703395225*^9}, {3.449606323765625*^9, 
  3.44960638546875*^9}, {3.44960641834375*^9, 3.449606420109375*^9}, {
  3.449606473*^9, 3.4496065055*^9}, {3.4496068329375*^9, 3.449607019*^9}, {
  3.4496070498125*^9, 3.449607051671875*^9}, {3.449713744359375*^9, 
  3.44971382403125*^9}, {3.449713854359375*^9, 3.449713855109375*^9}, {
  3.449713886140625*^9, 3.449713888546875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples (AD829)", "Subsubtitle"],

Cell["\<\
Non-Inverting configuration: input noise w/ gain of 10 as function of r1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1*^9", 
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{
       RowBox[{"+", "1"}], ",", "r", ",", 
       RowBox[{"9", "r"}], ",", "en", ",", "in"}], "]"}]}], "/.", 
    RowBox[{"AD829", "[", "1000", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "10", ",", "5000"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<R1[Ohm]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4481982372043753`*^9, 3.4481982585481253`*^9}, {
  3.449497072686625*^9, 3.449497088717875*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVz2tMU3cYBvByuPQGAqWFtoC0UA8rjDEv0bmp50UERbAyvBBALna0Qygg
UBGzkYArl0GBrizqqqvLIvuAosDAoBZElCFuioAXqDKRTqQOREJFq6d1/314
8+SXPHmSVyjNT5BhFApFgu7/VAZe+astBwNseg92q5okDOY07k/5GCxbd93B
73uScGrDMsuKMGjvUHyUh9xIbH8v+QaDwZHuf1k1JNG+b1w8W4OBtDM1Lq2W
JF4de1OJN2Mg2jxWQdaRhIK5JuLkDAaG2sbUxEaSkFnOdapkjtAVHvSoRk8S
utwgcYrSCZhVRduISySR/1o6v6nAGbRV9VPf3icJX3Zz/8cHXCBdMMJotpAE
03gIX15MBb+Enn8m+Tbi5HmG0a+ABrZciSks0kbkh4i4AeV0eHf+tVKttBH8
jVHyUDUDjtYOhZedtRGytHBqVAUTUosbkyKf2QgLrl8lbXSFNe7eOmOonRDZ
77eqG9yg65aU4BfbiRAFh7hWuQyGq9Ub9AN2Qlk+nmjVusPkjHFpIeQDcSHh
9/2noz2gLrOh26r9QER/ZngceccDkhhx5ddoFNhmvpmeu8sTPhl6cUgnoYBO
+Ln65yFPOBZ/mS87ToH6lrnSnXtZcLGiY712ngKjvc482j0WrFud2JsV6wCX
gjOObN7nBZuy47/MuOwAzOSepw5TXsBs0894rMGgxat8cSCNDa/uGorZ7Rgs
CCpvuU+zYYJa90Af4wgVnfPb0zI5YNJwXeXTyJzU0ZWTHHiye6mkq8EJggdd
hVVybzillMuUyc7AcxJyTSZvyCmz0LmhLtCiPXyvN8cHnlgSRIkiKpybHT4R
tOADHjr8z9pVNHh/W+NSl8sF6pXTPdlb6TCLadeXWLjQ4zMkhB8YEHb1DSe7
kAcbOb7jhSYmGKP3v5uc44Ern7HDUeIG4kC3M+NFfGiaS5YX25bBTZX/m7FX
fKhJKY9uTPEA+hcH3ZNLfCE2PHnPUakn6EqCh58u+YJs5u6OAwdZcLx8Svey
0A+slXqhROsFa/9+Ii61+kFyfSEhmmXDir4IKeuwP7xlVRa27PSGi9Zn6eIP
/hDLjdn94q0PtJN1sn7VctiwJfRG7wAP7JU6dpZDADyM7L1Lb/KF2Uxztbo6
AMI28KSqKX/wlklGUxwFkBcjbqvnCyDHJp5eHSGACXNWUXwqevnqb4/iVAJY
qP01lmsKhPT++yvMfQLI0HQxH5eIwG5pSvjDRQjLx1T2wUwcAvOO5N9Bjl+c
3kWT4bD1eZz6AXJubUhzNLJmfLF/GrkL9iZdRw7siVhPpQohTQR9BjkO0VUT
AduQ05cyei5k4dDA48wNIovez6cfU+DQoZ2hjyAvnasevoc8xjTgRmSzxHGL
Vy7as0szXiAPFOhDNcgdU62jDJoQaCcUzjV5qH827nIs8lx9jqn0IA6kSPBw
F7KvRfSVAVmoX1xMQV75Xa/pHXK2RhemQFaE6Z8fLkB95cwvamSJj8VaUIiD
4OWV7h+RT316tawVOerrBuMp5EsaBW0euT5pLbsFuWl1Hl9RhEP7CH1lJ3Jr
ad+ZZuSHsRM7upGtftZwMzJ5ozW7H9mbwzIEK9H+JlXVbeSTB9xi5Mj/AQs/
Exk=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[10], 1.7833957759124819`}, {2.302585092994046, 1.7833957759124819`}],
  
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"R1[Ohm]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{9.210340371976184, 
       FormBox[
        InterpretationBox[
         RowBox[{"1", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{1, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        InterpretationBox[
         RowBox[{"5", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{5, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{9.210340371976184, 
       FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->NCache[{{9.210340371976184, 10.819778284410283`, 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
      4.0943445622221, 4.248495242049359, 4.382026634673881, 
      4.499809670330265, 5.298317366548036, 5.703782474656201, 
      5.991464547107982, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.699514748210191, 
      8.85366542803745, 8.987196820661973, 9.104979856318357, 
      9.903487552536127, 10.308952660644293`, 10.596634733096073`}, 
     Automatic}, {{9.210340371976184, 10.819778284410283`, 2.302585092994046, 
     3.912023005428146, 4.605170185988092, 6.214608098422191, 
     6.907755278982137, 8.517193191416238, 2.995732273553991, 
     3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.396929655216146, 6.551080335043404, 6.684611727667927, 
     6.802394763324311, 7.600902459542082, 8.006367567650246, 
     8.294049640102028, 8.699514748210191, 8.85366542803745, 
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
     10.308952660644293`, 10.596634733096073`}, Automatic}],
  Method->{},
  PlotRange->NCache[{{
      Log[10], 
      Log[5000]}, {1.7833957759124819`, 11.227342875373145`}}, {{
    2.302585092994046, 8.517193191416238}, {1.7833957759124819`, 
    11.227342875373145`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{9.210340371976184, 
      FormBox[
       InterpretationBox[
        RowBox[{"1", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{1, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       InterpretationBox[
        RowBox[{"5", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{5, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.4481982427668753`*^9, 3.4481982590793753`*^9}, 
   3.4483096848137503`*^9, 3.4483097978606253`*^9, 3.4483098614075003`*^9, 
   3.4483099192200003`*^9, 3.4483102347043753`*^9, 3.4483102693606253`*^9, 
   3.4483108259543753`*^9, 3.4483121575950003`*^9, 3.4483126388918753`*^9, 
   3.44837532903125*^9, 3.448375447640625*^9, {3.44837992403125*^9, 
   3.448379935828125*^9}, 3.448398807421875*^9, 3.448398865875*^9, 
   3.44945180584375*^9, 3.44949318251475*^9, 3.44949708970225*^9, 
   3.4494975344835*^9, 3.4495453759171968`*^9, 3.4495460139015713`*^9, 
   3.449579697119625*^9, 3.449581381369625*^9, 3.449582930796875*^9, 
   3.44959338675*^9, 3.449599377328125*^9, 3.449603933953125*^9, 
   3.4496894875*^9, 3.449689577609375*^9, 3.449689627359375*^9, 
   3.449689763265625*^9, 3.44969144575*^9, 3.449692440359375*^9, 
   3.44969248775*^9, 3.44969274021875*^9, 3.44969281725*^9, 
   3.4496930130625*^9, 3.44970597959375*^9, 3.4501367748736415`*^9, 
   3.45018654664925*^9, 3.45018901414925*^9, 3.4502936635625*^9, 
   3.450455272977375*^9}]
}, Open  ]],

Cell["\<\
Inverting configuration: input noise w/ gain of 10 as function of r1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1*^9", 
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "r", ",", 
       RowBox[{"10", "r"}], ",", "en", ",", "in"}], "]"}]}], "/.", 
    RowBox[{"AD829", "[", "1000", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "10", ",", "5000"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<R1[Ohm]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4481982691731253`*^9, 3.4481982730168753`*^9}, 
   3.44949711470225*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVyn0w1HkAx/Hd33pam+ddzw+762mXuoYulxz7kcLFuU5HE1I2m04Pm9rz
cMdFWNJqpZuUXLnRpfLcYe5Kcg1dEk30wEYPHNmGFNKI7H3vj8985jXz5oml
4RKKRqOFkf3/Mv71ew17KGxLKHHgSzSiFnWs5RkpBYfmcq8MYq0GKj7zEIXK
Jt+0fuKToo0LYT9RCMjKyVLu0oiuxgwIJwooDMZnl2sSNKK3pz7IXa5QSMyM
cBtP1Ij2sj73PztO4bZurUZ1QCOSzFY35UgYYJzJ3hmaoRGV7nMURsu0cO/S
TuVcqUYkfS+e8kvSRu/+hC8jrmlENuwrHcu/18G3FcMH5wY1IpbqBxf7ZF0c
Dtji38ig4Wytvso2SQ8K45I6jjUNUjcnS4csJjZF+LAyV9Ng7bthl7tCH7TU
VWWM72iQxK7U3ZDLgrP3Fk9zGQ2zLuc8xSeXISRdeiHoLA1OS4/qFUoDCA+7
r8tsp8FtL0f0t9wQ1Z2Vg23vaJBlDWyZLzaCu0RVNiKgoy78j7jzgcYQp0we
+E1MR+CalsGAHmMkNAelPb1ER7D6zvZ9m02wUfieFTdHRylvreLX+yZIF3MX
BEEUjtdMZnwTaYroB75vaZcp9LVpW+k9NMUZD4b9mCEDf7nuSFsXY4bnfsFq
WgEDrKjWl/RhM+we/aJl0VgLNWZZM//EsuFJG/ZuK9PCO678rtEYG43LKtJ7
1msjt2lqY2w8B0Psa4qL08ScbX0eLziwS8r2E9fqwLVzGS9vlzkqmT+mOyp1
YaXFsxwZMYd8auu/icl6qClOedi2xwKxHqFH6wqYqJ54cNrxnQXSuqxihM36
WOgu0incZwnDj1WxdDULE1Sxd+qsJZI85+blkQZYcfMDJ/GgFbRzqdCwbkOo
AuM+vpi0Ql661KZgpTGEfIMLA4es0TXv2lVib4I7OXYf+t9ao3FqqCLczBRM
nwNGUak2SOuYR6OXGUpTXR+8nLOBu1ebojeOjZKs4dI3B21xt/LVgF0FB17P
ngsz5m1hEDCan8S3gPMtf7Fpih2cp111lNWWaJ4f3S7U2GHTm/15n7KtcXWx
UNKRYw853UHmnmuLJXkpezfdAfkjRoXSU/aYiFfnK/IdMB3TdnrtUS7MJWF9
0QwuEqgVEZpeHvZ8Eo6t8ucipaOgxsDbESduXnwamsOFhsmOlqudsL3jkbP6
FhdGYRXBXVUuWJr9Pfy2Dg9mm8ULbd0C8PenSXuIK/8sd9PpESDoVajiMXF7
zUBUCHHRwEzHGHFypE/rI2J+q7+3ri4PL0xai17fFyAwb8ghmHhNQ3s8u1cA
pRVnspO4+vT0nd2PBWgsHmf2EtfXFVjUEvezWlxUxGGP7RJmiPlL4h2viQvF
q5k/PyH9cH2fvh4P1Cvh1pP9pK8KvRZC/BV/uaBVJcCiE/fJZuLz7BQ546kA
vHMzM9HEnZE3RoOJE4tKV+wlVqp8KvuIF2Xj5Qri8E10L/WgANw312/8Qizz
cC37bEiADQlKVRnxsSPBDBnx8a1e7BritJyMh0vEV3uZHk3EUb4n/NY/E+BJ
yNDXN4h9k8svHyVebK9P7CC2W1XFuU/M9cvJ6yaeS2k4wn4uwH8eagvD
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[10], 1.9621907457389718`}, {2.302585092994046, 1.9621907457389718`}],
  
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"R1[Ohm]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{9.210340371976184, 
       FormBox[
        InterpretationBox[
         RowBox[{"1", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{1, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        InterpretationBox[
         RowBox[{"5", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{5, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{9.210340371976184, 
       FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->NCache[{{9.210340371976184, 10.819778284410283`, 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
      4.0943445622221, 4.248495242049359, 4.382026634673881, 
      4.499809670330265, 5.298317366548036, 5.703782474656201, 
      5.991464547107982, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.699514748210191, 
      8.85366542803745, 8.987196820661973, 9.104979856318357, 
      9.903487552536127, 10.308952660644293`, 10.596634733096073`}, 
     Automatic}, {{9.210340371976184, 10.819778284410283`, 2.302585092994046, 
     3.912023005428146, 4.605170185988092, 6.214608098422191, 
     6.907755278982137, 8.517193191416238, 2.995732273553991, 
     3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.396929655216146, 6.551080335043404, 6.684611727667927, 
     6.802394763324311, 7.600902459542082, 8.006367567650246, 
     8.294049640102028, 8.699514748210191, 8.85366542803745, 
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
     10.308952660644293`, 10.596634733096073`}, Automatic}],
  Method->{},
  PlotRange->NCache[{{
      Log[10], 
      Log[5000]}, {1.9621907457389718`, 12.4357033578526}}, {{
    2.302585092994046, 8.517193191416238}, {1.9621907457389718`, 
    12.4357033578526}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{9.210340371976184, 
      FormBox[
       InterpretationBox[
        RowBox[{"1", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{1, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       InterpretationBox[
        RowBox[{"5", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{5, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.4481982734543753`*^9, 3.4483096849231253`*^9, 3.4483097979543753`*^9, 
   3.4483098615012503`*^9, 3.4483099193293753`*^9, 3.4483102348137503`*^9, 
   3.4483102694543753`*^9, 3.4483108260325003`*^9, 3.4483121577043753`*^9, 
   3.4483126389856253`*^9, 3.448375329125*^9, 3.4483754476875*^9, {
   3.44837992409375*^9, 3.448379935890625*^9}, 3.448398807484375*^9, 
   3.4483988659375*^9, 3.4494518075625*^9, 3.449493182655375*^9, 
   3.449497115546*^9, 3.4495453759953213`*^9, 3.4495460139640713`*^9, 
   3.449579697213375*^9, 3.449581381463375*^9, 3.449582930875*^9, 
   3.449593386890625*^9, 3.44959937740625*^9, 3.449603934*^9, 
   3.44968948759375*^9, 3.449689577671875*^9, 3.449689627453125*^9, 
   3.449689763359375*^9, 3.44969144584375*^9, 3.4496924404375*^9, 
   3.44969248784375*^9, 3.4496927403125*^9, 3.44969281734375*^9, 
   3.44969301315625*^9, 3.449705979671875*^9, 3.4501367749361415`*^9, 
   3.450186546758625*^9, 3.45018901427425*^9, 3.450293663671875*^9, 
   3.450455273102375*^9}]
}, Open  ]],

Cell["Input voltage noise with flicker.", "Text",
 CellChangeTimes->{{3.44949515751475*^9, 3.44949517195225*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1*^9", " ", "en"}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "5"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk4lN0bB3CGZG8a6zDD7IiSUr2WOnfZ8tolpUgLspYUiixJEhIhS0Jo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[10], 0}, {2.302585092994046, 0}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
    9.210340371976184, 11.512925464970229`, 2.995732273553991, 
    3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
    4.0943445622221, 4.248495242049359, 4.382026634673881, 4.499809670330265, 
    5.298317366548036, 5.703782474656201, 5.991464547107982, 
    6.214608098422191, 6.396929655216146, 6.551080335043404, 
    6.684611727667927, 6.802394763324311, 7.600902459542082, 
    8.006367567650246, 8.294049640102028, 8.517193191416238, 
    8.699514748210191, 8.85366542803745, 8.987196820661973, 9.104979856318357,
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
    10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
    11.289781913656018`, 11.407564949312402`}, Automatic},
  Method->{},
  PlotRange->NCache[{{
      Log[10], 
      Log[100000]}, {0, 5}}, {{2.302585092994046, 11.512925464970229`}, {0, 
     5}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.449493323405375*^9, 3.449493421030375*^9}, {
   3.44949346370225*^9, 3.44949348395225*^9}, 3.4494935161085*^9, {
   3.44949358451475*^9, 3.449493610671*^9}, 3.449494255280375*^9, {
   3.449495184030375*^9, 3.4494952107335*^9}, {3.44949552801475*^9, 
   3.449495539374125*^9}, 3.44949640288975*^9, 3.4494966933585*^9, {
   3.44949673288975*^9, 3.449496749686625*^9}, {3.449496860561625*^9, 
   3.449496915546*^9}, {3.449496988686625*^9, 3.449497002436625*^9}, 
   3.4495453760890713`*^9, 3.4495460140578213`*^9, 3.449579697307125*^9, 
   3.449581381557125*^9, 3.44958293096875*^9, 3.449593387*^9, 
   3.449599377515625*^9, 3.44960393409375*^9, 3.4496894876875*^9, 
   3.449689577734375*^9, 3.4496896275625*^9, 3.44968976346875*^9, 
   3.449691445953125*^9, 3.449692440546875*^9, 3.4496924879375*^9, 
   3.449692740421875*^9, 3.4496928174375*^9, 3.449693013265625*^9, 
   3.449705979765625*^9, 3.4501367750142665`*^9, 3.45018654689925*^9, 
   3.450189014414875*^9, 3.450293663765625*^9, 3.450455273243*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series Product of OpAmps", "Subsubtitle"],

Cell["\<\
Computes the transfer function of several OpAmps circuits in series.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OpAmpProduct", "[", 
   RowBox[{"t_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"t", "[", "i", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
Computes the equivalent input noise of several OpAmps circuits in series.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NoiseSum", "[", 
   RowBox[{"prev_", ",", 
    RowBox[{"{", 
     RowBox[{"t_", ",", "n_"}], "}"}]}], "]"}], ":=", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["prev", "2"], "+", 
     SuperscriptBox["n", "2"]}]], 
   RowBox[{"Abs", "[", "t", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoiseProduct", "[", 
   RowBox[{"t_", ",", "n_", ",", "m_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"Fold", "[", 
    RowBox[{"NoiseSum", ",", "0", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t", "[", "i", "]"}], ",", 
         RowBox[{"n", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], "]"}], 
   RowBox[{"Abs", "[", 
    RowBox[{"OpAmpProduct", "[", 
     RowBox[{"t", ",", "m"}], "]"}], "]"}]]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spectrum Math", "Subsubtitle"],

Cell["Propagate noise spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SpecProp", "[", 
   RowBox[{"prev_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"t", "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2.", "\[Pi]", 
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]}], 
        "]"}], 
       RowBox[{
       "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], "}"}],
     "&"}], "/@", "prev"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SpecProp", "[", 
   RowBox[{"noise_", ",", "t_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"SpecProp", ",", "noise", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"t", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], "]"}]}]}], "Input"],

Cell["RMS of spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "SpecRMS", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SpecRMS", "[", 
   RowBox[{"l_List", "?", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"MatrixQ", "[", 
       RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"sqr", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"sqr", "+=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"i", "+", "1"}], ",", "1"}], "\[RightDoubleBracket]"}], 
           "-", 
           RowBox[{"l", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"l", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
             RowBox[{"l", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "2"}], 
              "\[RightDoubleBracket]"}]}], "2"], ")"}], "2"]}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     SqrtBox["sqr"]}]}], "]"}]}]}], "Input"],

Cell["Integrated RMS spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "RMSSpec", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RMSSpec", "[", 
   RowBox[{
    RowBox[{"l_List", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"MatrixQ", "[", 
        RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], ",", 
    RowBox[{"dir_:", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"sqr", "=", "0"}], ",", 
      RowBox[{"r", "=", 
       RowBox[{"N", "[", "l", "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dir", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "l", "]"}]}], ",", 
         RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"r", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "-", "1"}], ",", "2"}], "\[RightDoubleBracket]"}],
              "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"r", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "2"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"i", "-", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}]}], ")"}]}]}]]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], "-", "2"}]}], ",", 
         RowBox[{"i", ">=", "1"}], ",", 
         RowBox[{"--", "i"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"r", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "2"}], "\[RightDoubleBracket]"}],
              "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"r", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "2"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"i", "+", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}], "-", 
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], 
              ")"}]}]}]]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "r"}]}], "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shottky Diode Model", "Subsubtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}}],

Cell["\<\
We are using the noise model of a HSMS-281K. See data sheet and application \
note 956-3.\
\>", "Text",
 CellChangeTimes->{{3.449451286359375*^9, 3.449451327296875*^9}, {
  3.449451663734375*^9, 3.449451684625*^9}}],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}, {
  3.4494530511875*^9, 3.44945305815625*^9}, {3.449453104125*^9, 
  3.449453126109375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HSMS281Param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"BV", "\[Rule]", "25"}], ",", 
     RowBox[{"CJ", "\[Rule]", "1.1*^-12"}], ",", 
     RowBox[{"EG", "\[Rule]", "0.69"}], ",", 
     RowBox[{"IBV", "\[Rule]", "1*^-5"}], ",", 
     RowBox[{"IS", "\[Rule]", "4.8*^-9"}], ",", 
     RowBox[{"n", "\[Rule]", "1.08"}], ",", 
     RowBox[{"RS", "\[Rule]", "10"}], ",", 
     RowBox[{"T", "\[Rule]", 
      RowBox[{"273.15", "+", "25"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ShottkyParam", "=", "HSMS281Param"}], ";"}]}], "Input",
 CellChangeTimes->{{3.44945313*^9, 3.44945328021875*^9}, {3.4494533601875*^9, 
  3.44945336228125*^9}, {3.449453394796875*^9, 3.449453396921875*^9}, {
  3.449497593342875*^9, 3.44949762026475*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"8.33*^-5", " ", "n", " ", "T"}], "/.", "HSMS281Param"}]], "Input",
 CellChangeTimes->{{3.4495071223585*^9, 3.4495071232335*^9}}],

Cell[BoxData["0.026822766600000002`"], "Output",
 CellChangeTimes->{3.449507123796*^9, 3.4495453761671968`*^9, 
  3.4495460141359468`*^9, 3.44957969738525*^9, 3.449581381650875*^9, 
  3.449582931078125*^9, 3.449593387125*^9, 3.44959937759375*^9, 
  3.449603934140625*^9, 3.44961758934375*^9, 3.44968910871875*^9, 
  3.4496892955*^9, 3.4496893714375*^9, 3.44968948778125*^9, 
  3.449689577796875*^9, 3.449689627640625*^9, 3.4496897635625*^9, 
  3.449690850234375*^9, 3.449691446046875*^9, 3.449692440625*^9, 
  3.449692488015625*^9, 3.449692700390625*^9, 3.449692740515625*^9, 
  3.44969281753125*^9, 3.449693013359375*^9, 3.44970597984375*^9, 
  3.4501367750611415`*^9, 3.450186547008625*^9, 3.4501890145555*^9, 
  3.45029366384375*^9, 3.450455273352375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resistance Model", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}, {
   3.4494530511875*^9, 3.44945305815625*^9}, {3.449453113234375*^9, 
   3.44945312328125*^9}, 3.449454382921875*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RJ", "[", "i_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"8.33*^-5", " ", "n", " ", "T"}], 
    RowBox[{"IS", "+", "i"}]], "/.", 
   "ShottkyParam"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RV", "[", "i_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"RJ", "[", "i", "]"}], "+", "RS"}], "/.", 
   "ShottkyParam"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ZShottky", "[", 
   RowBox[{"i_", ",", "f_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"ser", "[", 
    RowBox[{"RS", ",", 
     RowBox[{"par", "[", 
      RowBox[{
       RowBox[{"RJ", "[", "i", "]"}], ",", 
       FractionBox["1", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f", " ", "CJ"}]]}], 
      "]"}]}], "]"}], "/.", "ShottkyParam"}]}]}], "Input",
 CellChangeTimes->{{3.44945306590625*^9, 3.449453073640625*^9}, {
   3.44945334284375*^9, 3.44945335565625*^9}, {3.449453408109375*^9, 
   3.449453507421875*^9}, 3.449453636390625*^9, {3.449453690515625*^9, 
   3.449453717015625*^9}, {3.44949759901475*^9, 3.44949761420225*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Abs", "[", 
  RowBox[{"RJ", "[", "30*^-6", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"RJ", "[", "100*^-6", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"RJ", "[", "300*^-6", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"RJ", "[", "1000*^-6", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4494536105*^9, 3.44945361296875*^9}, {
   3.44945365140625*^9, 3.449453679265625*^9}, {3.449454272140625*^9, 
   3.449454334453125*^9}, {3.449509684546*^9, 3.449509688030375*^9}, 
   3.44950979338975*^9}],

Cell[BoxData["893.9491881298992`"], "Output",
 CellChangeTimes->{{3.4494536163125*^9, 3.449453679875*^9}, 
   3.449454275890625*^9, {3.449454314046875*^9, 3.449454334859375*^9}, 
   3.449493182749125*^9, 3.449497625561625*^9, 3.449509688671*^9, 
   3.4495453761984468`*^9, 3.4495460141671968`*^9, 3.4495796974165*^9, 
   3.449581381682125*^9, 3.44958293109375*^9, 3.449593387171875*^9, 
   3.449599377625*^9, 3.449603934171875*^9, 3.449617589375*^9, 
   3.44968910875*^9, 3.44968929553125*^9, 3.44968937146875*^9, 
   3.449689487828125*^9, 3.4496895778125*^9, 3.449689627671875*^9, 
   3.449689763609375*^9, 3.44969085028125*^9, 3.449691446078125*^9, 
   3.449692440671875*^9, 3.44969248803125*^9, 3.449692700421875*^9, 
   3.449692740546875*^9, 3.4496928175625*^9, 3.44969301340625*^9, 
   3.449705979875*^9, 3.4501367750923915`*^9, 3.450186547039875*^9, 
   3.450189014602375*^9, 3.450293663859375*^9, 3.450455273383625*^9}],

Cell[BoxData["268.21479168999895`"], "Output",
 CellChangeTimes->{{3.4494536163125*^9, 3.449453679875*^9}, 
   3.449454275890625*^9, {3.449454314046875*^9, 3.449454334859375*^9}, 
   3.449493182749125*^9, 3.449497625561625*^9, 3.449509688671*^9, 
   3.4495453761984468`*^9, 3.4495460141671968`*^9, 3.4495796974165*^9, 
   3.449581381682125*^9, 3.44958293109375*^9, 3.449593387171875*^9, 
   3.449599377625*^9, 3.449603934171875*^9, 3.449617589375*^9, 
   3.44968910875*^9, 3.44968929553125*^9, 3.44968937146875*^9, 
   3.449689487828125*^9, 3.4496895778125*^9, 3.449689627671875*^9, 
   3.449689763609375*^9, 3.44969085028125*^9, 3.449691446078125*^9, 
   3.449692440671875*^9, 3.44969248803125*^9, 3.449692700421875*^9, 
   3.449692740546875*^9, 3.4496928175625*^9, 3.44969301340625*^9, 
   3.449705979875*^9, 3.4501367750923915`*^9, 3.450186547039875*^9, 
   3.450189014602375*^9, 3.450293663859375*^9, 3.450455273383625*^9}],

Cell[BoxData["89.40779147533642`"], "Output",
 CellChangeTimes->{{3.4494536163125*^9, 3.449453679875*^9}, 
   3.449454275890625*^9, {3.449454314046875*^9, 3.449454334859375*^9}, 
   3.449493182749125*^9, 3.449497625561625*^9, 3.449509688671*^9, 
   3.4495453761984468`*^9, 3.4495460141671968`*^9, 3.4495796974165*^9, 
   3.449581381682125*^9, 3.44958293109375*^9, 3.449593387171875*^9, 
   3.449599377625*^9, 3.449603934171875*^9, 3.449617589375*^9, 
   3.44968910875*^9, 3.44968929553125*^9, 3.44968937146875*^9, 
   3.449689487828125*^9, 3.4496895778125*^9, 3.449689627671875*^9, 
   3.449689763609375*^9, 3.44969085028125*^9, 3.449691446078125*^9, 
   3.449692440671875*^9, 3.44969248803125*^9, 3.449692700421875*^9, 
   3.449692740546875*^9, 3.4496928175625*^9, 3.44969301340625*^9, 
   3.449705979875*^9, 3.4501367750923915`*^9, 3.450186547039875*^9, 
   3.450189014602375*^9, 3.450293663859375*^9, 3.45045527339925*^9}],

Cell[BoxData["26.822637851338317`"], "Output",
 CellChangeTimes->{{3.4494536163125*^9, 3.449453679875*^9}, 
   3.449454275890625*^9, {3.449454314046875*^9, 3.449454334859375*^9}, 
   3.449493182749125*^9, 3.449497625561625*^9, 3.449509688671*^9, 
   3.4495453761984468`*^9, 3.4495460141671968`*^9, 3.4495796974165*^9, 
   3.449581381682125*^9, 3.44958293109375*^9, 3.449593387171875*^9, 
   3.449599377625*^9, 3.449603934171875*^9, 3.449617589375*^9, 
   3.44968910875*^9, 3.44968929553125*^9, 3.44968937146875*^9, 
   3.449689487828125*^9, 3.4496895778125*^9, 3.449689627671875*^9, 
   3.449689763609375*^9, 3.44969085028125*^9, 3.449691446078125*^9, 
   3.449692440671875*^9, 3.44969248803125*^9, 3.449692700421875*^9, 
   3.449692740546875*^9, 3.4496928175625*^9, 3.44969301340625*^9, 
   3.449705979875*^9, 3.4501367750923915`*^9, 3.450186547039875*^9, 
   3.450189014602375*^9, 3.450293663859375*^9, 3.45045527339925*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"ZShottky", "[", 
          RowBox[{"i", ",", "10*^6"}], "]"}], "]"}], ",", 
        RowBox[{"Abs", "[", 
         RowBox[{"ZShottky", "[", 
          RowBox[{"i", ",", "100*^6"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1*^-6", ",", "1*^-2"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Current[A]\>\"", ",", "\"\<Impedance[\[CapitalOmega]]\>\""}], 
        "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"10", ",", "2*^4"}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.65", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10MHz\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100MHz\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "11"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.9", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.4", ",", "0.2"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "3"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449451982625*^9, 3.449452067796875*^9}, {
   3.4494520994375*^9, 3.449452153796875*^9}, 3.449452209578125*^9, {
   3.4494522891875*^9, 3.44945233740625*^9}, {3.449452957203125*^9, 
   3.449452965546875*^9}, {3.449453535828125*^9, 3.449453598734375*^9}, {
   3.44945372646875*^9, 3.449453851234375*^9}, {3.449453891890625*^9, 
   3.449453987515625*^9}, {3.44945402134375*^9, 3.449454249*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVz3801Pkex3EjSg1h0MxEzHyM5PtlVy43O628/Uh2rWpNjVI3WWfUTX6G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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV03k0VX0XB3AyZI5rds8l5J47pIcbJRl+NBCPChEhKlQkQ1EkY0XKrCIy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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->
      NCache[{-Log[1000000], 2.302585092994046}, {-13.815510557964274`, 
       2.302585092994046}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Current[A]\"", TraditionalForm], 
       FormBox["\"Impedance[\[CapitalOmega]]\"", TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{9.210340371976184, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          10.819778284410283`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          2.302585092994046, 
           FormBox["10", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{-13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "5"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {-11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{9.210340371976184, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          10.819778284410283`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          2.302585092994046, 
           FormBox["10", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{-13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "5"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {-11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{-13.815510557964274`, -11.512925464970229`, \
-9.210340371976182, -6.907755278982137, -4.605170185988091, \
-13.122363377404328`, -12.716898269296165`, -12.429216196844383`, \
-12.206072645530174`, -12.02375108873622, -11.86960040890896, \
-11.736069016284437`, -11.618285980628055`, -10.819778284410283`, \
-10.414313176302118`, -10.126631103850338`, -9.903487552536127, \
-9.721165995742174, -9.567015315914915, -9.433483923290392, \
-9.315700887634009, -8.517193191416238, -8.111728083308073, \
-7.824046010856292, -7.600902459542082, -7.418580902748127, \
-7.264430222920869, -7.1308988302963465`, -7.013115794639964, \
-6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.298317366548036, -5.115995809754082, -4.961845129926823, \
-4.8283137373023015`, -4.710530701645918}, {
        9.210340371976184, 10.819778284410283`, 
         Log[10], 
         Log[50], 
         Log[100], 
         Log[500], 
         Log[1000], 
         Log[5000], 2.995732273553991, 3.4011973816621555`, 
         3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
         4.382026634673881, 4.499809670330265, 5.298317366548036, 
         5.703782474656201, 5.991464547107982, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         7.600902459542082, 8.006367567650246, 8.294049640102028, 
         8.699514748210191, 8.85366542803745, 8.987196820661973, 
         9.104979856318357, 9.903487552536127, 10.308952660644293`, 
         10.596634733096073`}}, {{-13.815510557964274`, -11.512925464970229`, \
-9.210340371976182, -6.907755278982137, -4.605170185988091, \
-13.122363377404328`, -12.716898269296165`, -12.429216196844383`, \
-12.206072645530174`, -12.02375108873622, -11.86960040890896, \
-11.736069016284437`, -11.618285980628055`, -10.819778284410283`, \
-10.414313176302118`, -10.126631103850338`, -9.903487552536127, \
-9.721165995742174, -9.567015315914915, -9.433483923290392, \
-9.315700887634009, -8.517193191416238, -8.111728083308073, \
-7.824046010856292, -7.600902459542082, -7.418580902748127, \
-7.264430222920869, -7.1308988302963465`, -7.013115794639964, \
-6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.298317366548036, -5.115995809754082, -4.961845129926823, \
-4.8283137373023015`, -4.710530701645918}, {9.210340371976184, 
        10.819778284410283`, 2.302585092994046, 3.912023005428146, 
        4.605170185988092, 6.214608098422191, 6.907755278982137, 
        8.517193191416238, 2.995732273553991, 3.4011973816621555`, 
        3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
        4.382026634673881, 4.499809670330265, 5.298317366548036, 
        5.703782474656201, 5.991464547107982, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.699514748210191, 8.85366542803745, 8.987196820661973, 
        9.104979856318357, 9.903487552536127, 10.308952660644293`, 
        10.596634733096073`}}],
     ImageSize->Scaled[0.65],
     Method->{},
     PlotRange->
      NCache[{{-Log[1000000], -Log[100]}, {2.302585092994046, 
        9.903487552536127}}, {{-13.815510557964274`, -4.605170185988092}, {
       2.302585092994046, 9.903487552536127}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{-13.815510557964274`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "5"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-13.122363377404328`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.716898269296165`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.429216196844383`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.206072645530174`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.02375108873622, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.86960040890896, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.736069016284437`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.618285980628055`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-10.414313176302118`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-10.126631103850338`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.721165995742174, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.567015315914915, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.433483923290392, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.315700887634009, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{9.210340371976184, 
         FormBox[
          InterpretationBox[
           RowBox[{"1", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{1, 
             Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
        10.819778284410283`, 
         FormBox[
          InterpretationBox[
           RowBox[{"5", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{5, 
             Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {
         NCache[
          Log[1000], 6.907755278982137], 
         FormBox["1000", TraditionalForm]}, {
         NCache[
          Log[5000], 8.517193191416238], 
         FormBox["5000", TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100MHz\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10MHz\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}}, {}},
     AspectRatio->0.5,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 11},
     PlotRange->{{-0.1, 4.26}, {-0.1, 2.42}}], {0.9, 0.}, {
    Left, Bottom}, {0.4, 0.2}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.65],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.449453567421875*^9, 3.449453626828125*^9}, {
   3.4494537308125*^9, 3.449453852640625*^9}, {3.44945389375*^9, 
   3.44945390940625*^9}, {3.449453943859375*^9, 3.44945398903125*^9}, {
   3.449454030453125*^9, 3.44945410325*^9}, {3.449454141828125*^9, 
   3.449454214796875*^9}, 3.4494542496875*^9, 3.449493183061625*^9, 
   3.449497627217875*^9, 3.4495453763859468`*^9, 3.4495460143390713`*^9, 
   3.449579697604*^9, 3.44958138188525*^9, 3.44958293146875*^9, 
   3.449593387984375*^9, 3.449599377953125*^9, 3.44960393434375*^9, 
   3.4496175895625*^9, 3.449689108953125*^9, 3.449689295734375*^9, 
   3.449689371640625*^9, 3.449689488015625*^9, 3.449689577984375*^9, 
   3.449689627875*^9, 3.4496897638125*^9, 3.4496908505*^9, 
   3.449691446296875*^9, 3.449692440875*^9, 3.449692488234375*^9, 
   3.449692700609375*^9, 3.449692740734375*^9, 3.449692817796875*^9, 
   3.449693013640625*^9, 3.44970598009375*^9, 3.4501367759205165`*^9, 
   3.450186547414875*^9, 3.450189014883625*^9, 3.450293664265625*^9, 
   3.4504552738055*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Noise Temperature Ratio", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ShottkyNTRLevel", "[", "f_", "]"}], ":=", 
  SuperscriptBox["10", 
   RowBox[{
    RowBox[{"-", "1.5"}], "/", "20."}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ShottkyNTRFlicker", "[", "f_", "]"}], ":=", 
   RowBox[{
    SqrtBox[
     FractionBox["0.8*^2", "f"]], "+", 
    RowBox[{
     FractionBox["1", "3"], 
     RadicalBox[
      FractionBox["1*^2", "f"], "10"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"fudge", " ", "a", " ", "little", " ", "bit"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ShottkyNTR", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"ShottkyNTRLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"ShottkyNTRFlicker", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.449451749296875*^9, 3.449451767484375*^9}, 
   3.449451822984375*^9, {3.449451889875*^9, 3.449451917015625*^9}, {
   3.449451957265625*^9, 3.44945196390625*^9}, {3.44945200121875*^9, 
   3.449452044171875*^9}, {3.44945218328125*^9, 3.449452205703125*^9}, {
   3.449452245890625*^9, 3.449452274671875*^9}, {3.44945237615625*^9, 
   3.449452378734375*^9}, 3.449452416390625*^9, 3.44945245590625*^9, {
   3.449452491984375*^9, 3.44945272434375*^9}, {3.449452772640625*^9, 
   3.449452920359375*^9}, {3.449452992359375*^9, 3.449453003984375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"ShottkyNTR", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "10", ",", "100000"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", "\"\<Noise Temperature Ratio[dB]\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449451982625*^9, 3.449452067796875*^9}, {
   3.4494520994375*^9, 3.449452153796875*^9}, 3.449452209578125*^9, {
   3.4494522891875*^9, 3.44945233740625*^9}, {3.449452957203125*^9, 
   3.449452965546875*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVyX8w1Hkcx/H1pUV+LGuxaLO7dm1Mlzb2Bql9l4i0bTmEJf2wOJST/Mgk
e371y0g/zERkxbRd+iWuXBqfExlOLvRbifzcWqVdq86Py33uj9c85zEv1t6k
QClBIpG24f1fxeOpZ3UJBNzjWuqm6XMh+rP8eWYyAVVRt2guBBeYZoEvvNMJ
kN1vzlMucKDsp4aXz3MIcEjrkEVoOFDUn9E/W0rA+nzJpN8AB9KUOkMbOgjw
K/S87VrPAR89mqqXowtrykqGd0RxYGStu45mQBcsi/d2NzY6gFnXkDIkaQmM
yOIrOcFsEKkH/dnjZMg/HOeiMGNBMb/o9LlgA9gSLqYfbLCH1jPlxU6jhmC5
6VDHNS4DyCd0jBxDjeB80MrQwue24Clvh80qYwg8vXSEHk+HQ72eEtN0Uxib
fn9sgWUFzaVLptYqKcDM3VgyZk2DBaDbb35gBnu/OawZmDeHKlJYrkO6OThf
3TDoyTADf5H6deAqKiw75lO8q8UYPvzmUUSboYKt/Os3J4EhmAf+kH3ipgVQ
9wgjJHZk4C/t7S5Op8GwLz/j8CwBQeLHpiovSygzTs0gWCRYHDxY+I/WEq4d
EfoKwueF1bLO2AsPrCAl4LbRj6lfhX8ndmWr0qxhfsurhnW+GqEmLmumB+iA
Npb3WvhNCm00BZGG+jawtaX0Ut6nUWFH+1piBtnAtmh1P/vnAWFSrVwv5bgt
JOpQg54IeoWX3tz2rvG2A/OsXX9NPGwS9lygp66Yt4OYK1OMlq1VaE66Wk/4
cBms8C2vV9i0o+tHp58YHGGARt/EyVXWh3YqYmajfZZDmbs1ear5NdKL5FvS
jOzhpH11Ms9kCHnsUuxPa7WHfUXZeefvDqOGe+NnfvdhAmOlxbd+0RiixIhP
GVYz4X6DW+vuwxNI1T/yb8F3Jlxu6qupjv6A2nZur+zewwKpa8V+ySYV2pNJ
HdzfzIJJysXTXi8n0VzNddFLNhvajoo6Lu/+jHamloeXydhgXdinf7d2CgmM
G4cK3rIh8RQ1eTHuC6LU1pZ4gQO8i7BRZ85+QTemtMqACgeYTyoqu5qiRn5e
VgkcggNBbs+c21VqFC3eF+Mo5cD5A6Xj8hAN2mRAJuW0cEB/MdEoq06DmJ2y
jitcLjxheVQkGE2jP112uHBzuaDk/PGGFzqN3keIKN3vuEB3LpFvq5hGi2dY
y9dvdIQwyUG6+zD+EwO6DCodIUJw87iEoUVILFKU6/JAOZu9KA3VojvxG25c
xV56y7M1EbsmX1DfgL3aerQgBftkEwM9xpbq6Jr+ih3C+/xiAfuBd7JdOfan
70XkSD0efKyjuPZh293skTKW8IDZFhy8PkyLTDvbEpywrf0mrHywSaONyQJs
fkHsqwDscZuqLBF2M99NEoZ9Jz+5JAs7aOv3qEPY/pHURwPYopbgmGvYXhnk
rg/Y3sRTxzrsVefmemawP5KEE/ewaZ3Db03IPPB0H4l9hD3kVq9dh21eEhE3
hP1UrJjzxx7rFK+YwG6Pv0gKwV7ZzFd+wr4uzzU+gG013hI7j13ZlE7NxHa2
/YVHhGvR2RcJ9ALsi6YmEwbYeeqo5Wexa1svXKFgpxsHcS5h53hYxFhh/wcQ
xDJC
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{2.302585280960176, -1.2719940173443267`},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox["\"Noise Temperature Ratio[dB]\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
    9.210340371976184, 11.512925464970229`, 2.995732273553991, 
    3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
    4.0943445622221, 4.248495242049359, 4.382026634673881, 4.499809670330265, 
    5.298317366548036, 5.703782474656201, 5.991464547107982, 
    6.214608098422191, 6.396929655216146, 6.551080335043404, 
    6.684611727667927, 6.802394763324311, 7.600902459542082, 
    8.006367567650246, 8.294049640102028, 8.517193191416238, 
    8.699514748210191, 8.85366542803745, 8.987196820661973, 9.104979856318357,
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
    10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
    11.289781913656018`, 11.407564949312402`}, Automatic},
  Method->{},
  PlotRange->{{2.302585280960176, 11.512925277004099`}, {-1.2719940173443267`,
    10.514572235423527`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.44945203434375*^9, 3.449452068296875*^9}, {
   3.449452100234375*^9, 3.449452119421875*^9}, 3.449452154578125*^9, 
   3.44945221028125*^9, {3.449452260859375*^9, 3.449452337953125*^9}, 
   3.449452381984375*^9, 3.449452421140625*^9, 3.4494524595*^9, 
   3.44945249871875*^9, {3.44945256690625*^9, 3.4494525835*^9}, {
   3.44945263959375*^9, 3.449452727671875*^9}, {3.44945277596875*^9, 
   3.449452782625*^9}, {3.449452827859375*^9, 3.44945292271875*^9}, {
   3.449452959265625*^9, 3.44945301559375*^9}, 3.44949318338975*^9, 
   3.4495453765265713`*^9, 3.4495460144953213`*^9, 3.449579697775875*^9, 
   3.449581382057125*^9, 3.449582931703125*^9, 3.449593388328125*^9, 
   3.44959937815625*^9, 3.449603934484375*^9, 3.44961758975*^9, 
   3.449689109125*^9, 3.44968929590625*^9, 3.449689371796875*^9, 
   3.4496894881875*^9, 3.449689578125*^9, 3.449689628046875*^9, 
   3.449689764015625*^9, 3.4496908506875*^9, 3.44969144646875*^9, 
   3.449692441046875*^9, 3.449692488390625*^9, 3.44969270078125*^9, 
   3.44969274090625*^9, 3.44969281796875*^9, 3.4496930138125*^9, 
   3.44970598025*^9, 3.4501367762955165`*^9, 3.450186547743*^9, 
   3.450189015227375*^9, 3.450293664484375*^9, 3.45045527414925*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Detection chain", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}, {
  3.449497639374125*^9, 3.449497642436625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"detParam", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Rbias", "\[Rule]", "100*^3"}], ",", 
     RowBox[{"ibias", "\[Rule]", "240*^-6"}], ",", 
     RowBox[{"Cclamp1", "\[Rule]", "330*^-12"}], ",", 
     RowBox[{"Cclamp2", "\[Rule]", "150*^-12"}], ",", 
     RowBox[{"Cbias", "\[Rule]", "20*^-6"}], ",", 
     RowBox[{"Rdrv", "\[Rule]", "2000"}], ",", 
     RowBox[{"Rterm", "\[Rule]", "50"}], ",", 
     RowBox[{"TransformerRatio", "\[Rule]", "2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zdet", "=", 
   RowBox[{"par", "[", 
    RowBox[{"Rbias", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "Cclamp2"}]], ",", 
     RowBox[{"ser", "[", 
      RowBox[{
       RowBox[{"ZShottky", "[", 
        RowBox[{"ibias", ",", "f"}], "]"}], ",", 
       RowBox[{"par", "[", 
        RowBox[{
         RowBox[{"ZShottky", "[", 
          RowBox[{"ibias", ",", "f"}], "]"}], ",", 
         RowBox[{"ser", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["TransformerRatio", "2"], "Rterm"}], ",", 
           FractionBox["1", 
            RowBox[{"s", " ", "Cclamp1"}]]}], "]"}]}], "]"}]}], "]"}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449497724421*^9, 3.449497744030375*^9}, {
   3.449497774780375*^9, 3.44949795345225*^9}, {3.44949802245225*^9, 
   3.449498148546*^9}, {3.449498294124125*^9, 3.4494983412335*^9}, {
   3.44949840970225*^9, 3.44949844920225*^9}, 3.44951007345225*^9, 
   3.449511477421*^9, 3.449511507749125*^9, {3.44951337782725*^9, 
   3.44951338351475*^9}, {3.4495453670109468`*^9, 3.4495453677921968`*^9}, {
   3.4495788622915*^9, 3.44957887751025*^9}, {3.4495794345415*^9, 
   3.4495794366665*^9}, {3.44959332384375*^9, 3.449593358390625*^9}, {
   3.449599340546875*^9, 3.449599355078125*^9}, {3.449616041359375*^9, 
   3.449616064515625*^9}, {3.4496164016875*^9, 3.449616402140625*^9}, {
   3.449617149265625*^9, 3.449617151546875*^9}, {3.44961737428125*^9, 
   3.449617377*^9}, {3.449617574234375*^9, 3.44961757753125*^9}, {
   3.449689665859375*^9, 3.44968969459375*^9}, 3.449690711203125*^9, {
   3.44969083340625*^9, 3.449690833515625*^9}, 3.449692697359375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "zdet", "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1*^3", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", "\"\<Impedance[\[CapitalOmega]]\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"10", ",", "1000"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4494981693585*^9, 3.449498277671*^9}, {
  3.4495454966671968`*^9, 3.4495454971984468`*^9}, {3.449616326828125*^9, 
  3.4496163340625*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd13k4lk0XAHBRkpA1JTz7iiIi+5ElsoYQZalISmSJkC0RhZRsiRKyhDai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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[1000], 2.302585092994046}, {6.907755278982137, 2.302585092994046}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox["\"Impedance[\[CapitalOmega]]\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {2.995732273553991, 
        FormBox["20", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {5.298317366548036, 
        FormBox["200", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {7.600902459542082, 
        FormBox["2000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{2.302585092994046, 
        FormBox["10", TraditionalForm]}, {2.995732273553991, 
        FormBox["20", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {5.298317366548036, 
        FormBox["200", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {7.600902459542082, 
        FormBox["2000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->
   NCache[{{6.907755278982137, 9.210340371976184, 11.512925464970229`, 
     13.815510557964274`, 16.11809565095832, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
     12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
     13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
     13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
     14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
     15.60727002719233, 15.761420707019587`, 15.89495209964411, 
     16.012735135300492`}, {
      Log[10], 
      Log[20], 
      Log[50], 
      Log[100], 
      Log[200], 
      Log[500], 
      Log[1000], 
      Log[2000], 
      Log[5000], 3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
      6.551080335043404, 6.684611727667927, 6.802394763324311, 
      8.006367567650246, 8.294049640102028}}, {{6.907755278982137, 
     9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
     16.11809565095832, 7.600902459542082, 8.006367567650246, 
     8.294049640102028, 8.517193191416238, 8.699514748210191, 
     8.85366542803745, 8.987196820661973, 9.104979856318357, 
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
     10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
     11.289781913656018`, 11.407564949312402`, 12.206072645530174`, 
     12.611537753638338`, 12.89921982609012, 13.122363377404328`, 
     13.304684934198283`, 13.458835614025542`, 13.592367006650065`, 
     13.710150042306449`, 14.508657738524219`, 14.914122846632385`, 
     15.201804919084164`, 15.424948470398375`, 15.60727002719233, 
     15.761420707019587`, 15.89495209964411, 16.012735135300492`}, {
     2.302585092994046, 2.995732273553991, 3.912023005428146, 
     4.605170185988092, 5.298317366548036, 6.214608098422191, 
     6.907755278982137, 7.600902459542082, 8.517193191416238, 
     3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.703782474656201, 5.991464547107982, 6.396929655216146, 
     6.551080335043404, 6.684611727667927, 6.802394763324311, 
     8.006367567650246, 8.294049640102028}}],
  Method->{},
  PlotRange->NCache[{{
      Log[1000], 
      Log[10000000]}, {2.302585092994046, 6.907755278982137}}, {{
    6.907755278982137, 16.11809565095832}, {2.302585092994046, 
    6.907755278982137}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[20], 2.995732273553991], 
      FormBox["20", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[200], 5.298317366548036], 
      FormBox["200", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[2000], 7.600902459542082], 
      FormBox["2000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.44949817051475*^9, {3.449498225342875*^9, 3.449498344046*^9}, {
   3.449498416436625*^9, 3.44949845395225*^9}, {3.449510069530375*^9, 
   3.449510077311625*^9}, 3.4495114797335*^9, {3.4495453766203213`*^9, 
   3.4495454001671968`*^9}, 3.4495454982296968`*^9, 3.4495460146359468`*^9, 
   3.44957944326025*^9, 3.4495796979165*^9, 3.449581382213375*^9, 
   3.44958293184375*^9, 3.449593388484375*^9, 3.4495993783125*^9, 
   3.449603934625*^9, {3.449616327921875*^9, 3.449616334484375*^9}, 
   3.449617589890625*^9, 3.44968910928125*^9, 3.4496892960625*^9, 
   3.44968937196875*^9, 3.44968948834375*^9, 3.449689578265625*^9, 
   3.449689628203125*^9, 3.449689764171875*^9, 3.449690714734375*^9, 
   3.449690850875*^9, 3.449691446625*^9, 3.44969244121875*^9, 
   3.449692488546875*^9, 3.4496927009375*^9, 3.4496927410625*^9, 
   3.449692818109375*^9, 3.449693013984375*^9, 3.44970598040625*^9, 
   3.4501367764673915`*^9, 3.450186548008625*^9, 3.450189015477375*^9, 
   3.45029366465625*^9, 3.450455274414875*^9}]
}, Open  ]],

Cell["\<\
Only valid when the resistance of the bias resistor is larger than the diode \
junction resistance because the flicker noise is applied to the parallel \
arrangement as a whole.\
\>", "Text",
 CellChangeTimes->{{3.449451286359375*^9, 3.449451327296875*^9}, {
  3.449451663734375*^9, 3.449451684625*^9}, {3.44951233688975*^9, 
  3.44951238807725*^9}, {3.449512519342875*^9, 3.449512539936625*^9}, {
  3.44959348609375*^9, 3.449593496703125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"diodenoise", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"ShottkyNTR", "[", "f", "]"}], 
     SqrtBox[
      RowBox[{"FourKT", " ", 
       RowBox[{"Abs", "[", "zdet", "]"}]}]]}], "/.", "detParam"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.449511610921*^9, 3.44951161145225*^9}, {
  3.449511655061625*^9, 3.449511658671*^9}, {3.449519390467875*^9, 
  3.449519392780375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"diodenoisebias", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ShottkyNTR", "[", "f", "]"}], 
       SqrtBox[
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", "zdet", "]"}]}]]}], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.449511318342875*^9, 3.44951132588975*^9}, {
   3.449511358905375*^9, 3.449511385061625*^9}, {3.449511511467875*^9, 
   3.44951162120225*^9}, {3.449511693280375*^9, 3.4495117199835*^9}, 
   3.449511917811625*^9, {3.449513967296*^9, 3.44951396776475*^9}, {
   3.449519394999125*^9, 3.449519397671*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"diodenoisebias", "[", 
           RowBox[{"0", ",", "1*^-5"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"diodenoisebias", "[", 
           RowBox[{"0", ",", "1*^-4"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"diodenoisebias", "[", 
           RowBox[{"0", ",", "1*^-3"}], "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.9", ",", "30"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.44951141238975*^9, 3.44951143451475*^9}, {
   3.4495115288585*^9, 3.449511554624125*^9}, {3.44951166888975*^9, 
   3.449511669561625*^9}, {3.44951173332725*^9, 3.449511787405375*^9}, {
   3.449511931405375*^9, 3.449512001874125*^9}, {3.4495120389835*^9, 
   3.4495120768585*^9}, 3.449512117967875*^9, {3.44951215576475*^9, 
   3.449512279546*^9}, {3.449512593467875*^9, 3.449512600624125*^9}, {
   3.449513969999125*^9, 3.449513974624125*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV0nk41dkfB/Bzr+tmizKUSPfG93ulpiLtlu+7jC3JkqUYaUGyFCFlEn4o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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVy3881HccB/CvL27K5XSdIsnduTvpIaalhVufd8zMw6RoSttlyY/qmFBO
FkJdKQ8lq8nvw9wWFdJi/f5NzlFCSbFIyrpf7hA6++yP9+P1eL5ejzcrLDYw
giQIYj2+/1MqUz6tE5Lwut60nLaPhHBFWVdyHAnZmrx0STwJTPPAbi8RCXuN
irK/2ENCQVBDT1cGCewPQu4W/JfTm9T78Szu37TtqNhOQuKIwcC6ZhLybG+z
PNeT4G3EGH3MMQR5yn6GxJ6EQY81BpqXhpC660zCSK8BmLcOjATHGkP8q/Ho
ZV8agL+635c9TAGKxcqsJgkBJ11yTuR9bwIF3wmc79EJuJtbdNJhaA4UaIXT
+gk9omQZmPK2mILz9aTaDW8/IfeyB+AzSoVP5Xt51EczaO9j9x/MRGYgbMrS
zrs+jW6cNVZ6jNCAs7Uur1Q2hWbA0tbnmjk8nNjZ86HzI5IQIZl2ovnw6C/J
sYyJSeTrr34e6ESHvuZJ6qPlk+jdn245DB0dmDPM9nMhE2h+4Iq0rAsLgHXR
8f3r8nHkMvdx20kRA2ay8kj0Xoc2BcjMRvkW0OVxvSXDU4dm++OzJ7UWkHRH
zlXUaVHFwZao/GsLwbL2fHwNS4vk0a1po4mLYKuMVhlaNYY0O1N0HWAJWtkw
67jjGLLSiAVzPrMCv3J2reMtDWp+4EHqblpBKLt2QXK4BsVWlxklHF0MYp+q
9F/nalDJi1qvSi9reLtiUDJyQ4068i33LZu2Bt5vIsvuX9RoKuJzI3RnCRRO
xEeGuKtRTepYu8kBG3BoHOUmGKrRZmnkx3DvpbBtsWeZuVyFjAQuFgxTWyDd
yla6laqQ2zZpTOJdW6j4271aL1KhhivDuZe9mXD/xBl++0YVokUGHJ9TwQRl
oTSo00WFRnsHP4n1TCgneE+zLFTo3uYNpW3bWTBwNDb3yZgSbU+m98fcYMEi
gdObqPtKNFVZ49/DZgPKyayk5SvR5n1FWwsOsqFjVVBIf5wSuVIbB8R9bIhZ
3dc1GKBEtOrq03ywA0lGJzXRSYnOK7UjfsV2ELHWyWsJXYm+5S8UckgODDNc
k63HFSg8YEckL4IDz5r4RcRLBfrahEJk3OaA99p8l6iHCsRsOdhcxeVCld5m
sLROgW45b3TmZnJh6MXlK2klCvTPj/60tld4Ly4RH8lWoNlc1tK1njwY8vW7
s2c/3qP9Wk1KefCkvdVEFKVANwP8pUWG9rDEN3iWCFKg+t3rzv+BvSvNOUEf
qECVh10vNWDLZom309jHrtrclGGL+7Ll49jB9oruGewUnU/xv9gf9DkUgZE9
ONj5uT3Dtr7QEWFjbA87Q9KFF7HNWu4JHbCf14W9qsEmhhrjXLGvreNvPIc9
bCVJ8cdONX62+nfs+sNxp1Owy6n1BoXYvgL6/ZfY0WeUp8XY/CRK6ztsue0m
k0PYTnlTHTpsv57a5HRsRsvrvnkUe1guDww9gD2w6pL2K2zH1jXL4rE7A6RT
vth9DdsKYrEf7C4kgrGVDw9QY7BryjKpP2OroySqKOzSqyJ6MnbTmDQsAvtU
t9BSjH2kquppGPYhdejSU9iytOJvfsIWUTdxSrDHU7MbBdj/AX7/PoM=
        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwVzns803scx/GZmWHN2lmdSe6bhRIe6RCd70fpIq2VU7pIFwedk+HBcTvK
IUpJZ5aO0uVsiprarFx6lEN+mZI9EDouh1LrKGGnsObRyZHOtz/ej9fj+d/b
ISI+JIpMIpE24X2pvG28uzKGDBFITtvZbECR70p60hPI4Nd459HhRgOyZ4b0
rk4lw7k3jwZL6g3ownc1fT3ZZGA1HLAcqzIg8UDawMfzZIitdTuVJTOglBEj
bUALGSZWsWgNaQa0hsLWdXGNQbIk5+0hNwMa8vMx0g8aQ1PcPYV54XvEbNWO
hMabgCY/U3pygx4JJl8EOQ5TIfvih16l3SSSeIoLzmyjAXfHZie10QRqOn1J
4vLKDNQK86yE8reImmdk4bzDAioWuo+xj+vQipJmWKejgzrfuzd/4yhK6loR
xkhlADUqJbHA6w1qOG8y7jdiCe67Xt2q2vIazQDHbl09EwYXHPUR7htCl0k7
c5xS54LV1W9kafKXKEgw2R/izgLj6lVlpgwtGr3uK2ZPsYCEgkMK+56huSFL
MvNUXwFDbno/caYfeZp3tUtS2TBnA4c7ZNWHtgrbGDr/ecDbtilQn96NPr9I
PPWvYR5w/oqslfk8QaVZmgPF9fOhYu3UiOd4B3osas3UpXwNrjcrT7Sy25D+
h4ypTuDARrVrMX9tC7LS54abmVoBWS72XTb0ALU0+5GnCCuocN53VmaiRvGK
EspPJxZA1eKWvmFRA5I+vbW6bLU16B8aTbpU1aLOYk7yov+sQRTXoSUfuY2m
ozwoSL0QlrMrF634sRIpf3nfQTtsA4GjHZqqKQXaLo/+GLnGFgI/kONEQVcR
JdxzHtvCDhZ61yVaD0qR7x55bEqTHeytqfW6wihCNXeGT99eYw9XsqbD5lCP
I8toYb5ZqT28ft1018ZJhHQDQ59yZ+3h8fL+IguRiHiwfbOsfb8DMN0jah6O
HiX2p7NexDY4wKxPH80rQEJMlykFfY6OIHiSy7k4VkRsT76060KWI1wbtvgj
TnWB8Kbf1eY+cwTmI4WfekxKWCoURf7gBEOCgnsteZeJinHDSPDvTiCRd3cx
NpYS6/3nx3DJXIhyczV/Qr1KRAq/j3aO4sLk848zPZJrRCCNSspu5MKBxMwi
ulZO2GuyWq7xeHBua7WH7eLrxP2lW5bycnhQr0q+3bvuBvFyt8Cy/TkP6Drf
Q7T1CuLzaQfbb1c5w9k9M1K39UripSi4lSZzhkbKbzcX8CoIQiiQXzLmgyji
xj9Jxiqi6mBARTl27M+5+WLssmPe1TXYAi8313Lsk3U2RNsXix9HP8UO5b/r
ncEuY2YMBlBUxNtZMTWcwofFwvT7DBMVYa3qjLIx4UOBx+zucqqKYGgexLhg
n++fMDRik17dTfDGdglWnnqKPWx1OUOAbfJrRh3DFP85llCUgT2jzJufjB0U
zno4iM2LDVIH0FSEfxq1dRRb76EJDcN2PzPdOYUt6ZyrS8Jma/5+NofKh8ry
T6xybO2yasNKbMfnaB/DTEX8KZRPB2FLS6nv+djNBy+SQrHvbTp7LABbWZJD
j8NeGca8kYQtq0tlpWOrGqb9xNiFvTGcXOxiuqpdjn10cq9tIXbeWte9jdip
9K1cKbZ3bPzEAPb/vjc2vQ==
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], -0.10536051565782628`}, {
       2.302585092994046, -0.10536051565782628`}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
        0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
         0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
         3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
         1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
         0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
         0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
         0.6418538861723948, 
         Log[4], 
         Log[6], 2.0794415416798357`, 2.1972245773362196`, 
         2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
         2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
         2.8903717578961645`, 2.9444389791664403`, 
         Log[40], 
         Log[60]}}, {{2.302585092994046, 4.605170185988092, 6.907755278982137,
         9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {0., 2.302585092994046, 1.6094379124341003`, 
        3.912023005428146, 0.6931471805599453, 2.995732273553991, 
        1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
        2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
        0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
        0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
        0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
        1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
        2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
        2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
        2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
        4.0943445622221}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {-0.10536051565782628`, 3.4011973816621555`}}, {{
       2.302585092994046, 11.512925464970229`}, {-0.10536051565782628`, 
       3.4011973816621555`}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.0986122886681098`, 
         FormBox[
          TagBox[
           InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.4011973816621555`, 
         FormBox[
          TagBox[
           InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.4054651081081644, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.70805020110221, 
         FormBox[
          TagBox[
           InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.9459101490553132`, 
         FormBox[
          TagBox[
           InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {4.248495242049359, 
         FormBox[
          TagBox[
           InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.09531017980432493, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[4], 1.3862943611198906`], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[6], 1.791759469228055], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[40], 3.6888794541139363`], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[60], 4.0943445622221], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1,
          0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.449512124061625*^9, {3.449512157342875*^9, 3.449512250624125*^9}, 
   3.4495122817335*^9, {3.4495125956085*^9, 3.449512602686625*^9}, {
   3.449513975467875*^9, 3.449513981546*^9}, 3.44951940013975*^9, 
   3.4495453769171968`*^9, 3.4495460149484468`*^9, 3.449579446979*^9, 
   3.44957969826025*^9, 3.44958138257275*^9, 3.44958293221875*^9, 
   3.44959338884375*^9, 3.449599378640625*^9, 3.4496039350625*^9, 
   3.449617590234375*^9, 3.449689109640625*^9, 3.4496892964375*^9, 
   3.449689372328125*^9, 3.449689488734375*^9, 3.44968957859375*^9, 
   3.4496896285625*^9, 3.449689764515625*^9, 3.44969071509375*^9, 
   3.449690851265625*^9, 3.449691447015625*^9, 3.449692441609375*^9, 
   3.44969248890625*^9, 3.449692701265625*^9, 3.44969274140625*^9, 
   3.44969281846875*^9, 3.4496930145625*^9, 3.449705980796875*^9, 
   3.4501367768111415`*^9, 3.450186548696125*^9, 3.450189015977375*^9, 
   3.45029366509375*^9, 3.450455274946125*^9}]
}, Open  ]],

Cell["\<\
Noise of the 50\[CapitalOmega] termination resistor is added twice because we \
fold the two audio sidebands of the carrier on top of each other. They also \
have a gain of 2 \[Times] transformer ratio.\
\>", "Text",
 CellChangeTimes->{{3.449451286359375*^9, 3.449451327296875*^9}, {
  3.449451663734375*^9, 3.449451684625*^9}, {3.44951233688975*^9, 
  3.44951238807725*^9}, {3.449512519342875*^9, 3.449512539936625*^9}, {
  3.449512817342875*^9, 3.449512880967875*^9}, {3.4495456795890713`*^9, 
  3.4495456999328213`*^9}, {3.44957926376025*^9, 3.44957930994775*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"detnoise", "[", "0", "]"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"diodenoise", "[", "0", "]"}], "2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "TransformerRatio"}], ")"}], "2"], " ", "FourKT", " ", 
       "Rterm"}]}]], "/.", "detParam"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"detnoisebias", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"diodenoisebias", "[", 
          RowBox[{"0", ",", "ib"}], "]"}], "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "TransformerRatio"}], ")"}], "2"], " ", "FourKT", " ",
          "Rterm"}]}]], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.44951289438975*^9, 3.44951295026475*^9}, {
   3.44951305526475*^9, 3.449513089405375*^9}, {3.4495139154835*^9, 
   3.449513915811625*^9}, {3.4495140286085*^9, 3.449514028936625*^9}, {
   3.4495457054953213`*^9, 3.4495457104953213`*^9}, {3.4495458378859468`*^9, 
   3.4495458384640713`*^9}, {3.44957890188525*^9, 3.44957895307275*^9}, 
   3.449579037775875*^9, {3.44957907401025*^9, 3.44957913094775*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"0", ",", "1*^-5"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"0", ",", "1*^-4"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"0", ",", "1*^-3"}], "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"1*^9", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"2", "TransformerRatio"}], ")"}], "2"], " ", "FourKT", 
            " ", "50"}]]}], "/.", "detParam"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "30"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<50\[CapitalOmega] input\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495457525109468`*^9, 
   3.4495457580109468`*^9}, {3.4495457980265713`*^9, 
   3.4495457986046968`*^9}, {3.4495458750421968`*^9, 
   3.4495459371828213`*^9}, {3.4495459986828213`*^9, 
   3.4495460021359468`*^9}, {3.449578972854*^9, 3.4495789986665*^9}, {
   3.44957910294775*^9, 3.449579225369625*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV03k0ldsbB3DvcRznIFNOkYy97zncBmPdyvRNw1XIGI1SN/RDpUu5V5qQ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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVzn881HccB/C777lDzMn8OOFw7lzqEVEWYZ933QyPdlnmx/KzH2jzI0xc
6ZdlPFIxp/VL8uMRWetq7dyUsTO04iHFGm0Kl/O4KY1lPBbf7519vn+8Hq/H
8/F+//Fy3ZMVkUIwGIztOHQ3PZz9/Yd0AvJq0idESSxInqkbKsghwChukdiU
wAIXy4hhiYwAQ1RjUWgcC6o+UT0dOkEAee37xowYFpSPHBxZvETAA+U/+1vD
WZA/xdRs6SEg0onnkQIsCDaynh4UskBTKxlkC1igDfBjzo2yQO5yOzdbR4Bl
n2YqOosNv9mv4remESB9Mx4m0HGA59ir32BgQoV3+ddno0xACTW18iomdMur
KzwmTUFftKT0fI8JnFKmmfunZiDPe0Kpxxmwue4+hEybw50Wxa6/ShlwYHBz
nIXMAojBpq1JQQxQX2LPBkxxQbKc7bZjcRlRwHMOabeErMu7Mv8oWEb1jJ1F
brKVoHh2Lpq7chmFSd/8GeFpBfVx/dk8lQG9vO5fbr1gBW2F1x1iYg1oZcS6
46W33oX8xos1QksD8l4x2F8hs4ZtnZV6Ua8eRYY/tJgOtAHx6rYTJmf0aHn8
izNv521g7at1x17s1KOrhb37Lrbbgu2I9ip/jR49yug7Pp1vBzHdbdVclh7N
fXZ0YQB4EOt4Psh4jEL2cyUJpsb2kG2nvhKvplDP/QBiocMenOcLxg43UCjr
Rp1R7slVcL20TPfyNIVqnt2WNEgcIPJCZfKQjEIDF3l5q0kHaPRX/3wklUJL
KeuNUJcjMOL9JPNRFFIc+/exyREncM3iF6SEUiimKXUxOZgPA/+FeB0KoJBR
greNtZkzPDn8pTZmPYX8E5sy87udQeVmolwrppDqjk7+Y7ALdErLtIl8CnFT
w0+bXnWBmZnEZp4dhaZHtPoSgwvYTrTua7ek0L2Yj2v7d7uCrDF69PwKCu0u
sBrPVLtCWuxCyyE23tegkD4VCOABVz1TzMB78qpjqwoFkFRr17KHIpGv+V1N
yXMBfJR+q+GntyTi3rhxLhDcQLXVoku8QKKbs/NT2664QW61OEc4R6LQQNt0
ISEE1z08lecsiZLD96a6pwjBdJVg5NRrEn1gwmGc6BRChlauD3lFIpfewp5r
IhGwFa3dxBSJfvHa4SUqEoHSYncsR0eiF/FSbv+YCF5XWe9dM0miZbkr//2t
7nClYfIbnwl8z9jWZ1LrDsdsIkZ3akjUES5tqmaJYfsFbc+WMRIp07bc/BZb
sy6khHZDsW+zCvtD1ncS2qfanDoe0v9pmWrAjhbPDFPYSvF0M8L+21DOSTAS
w92IrpogbIdbAylObDH4Mcdz/bEteu+le2AHRa3xps2YvJvji71Jd2DGD1tn
X39Uit2vNv6ctrI459xRbE2oMHETdliC1a+j2Ceb/UJ9sQMPcvpeYg89lrFp
e55dGljAFq9u6dqIbd078fwdjhiqz6wPoq3Z2DwfhO3j5uizAftJeNNSGDbB
j5r1wb6fdpkRjZ0UWaagragrMt+PXZxLutOubZNZFWB7xntPemNXDqfzSrA9
ClPraX/1JolfiZ06XpVIW2YeKazBHjr0yIH2/yGbNKc=
        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwVzn8w1Hkcx/G1uxy1t1hkN7fYtezVoDSn64e7z9vvc2bbbf3oB6sUKhT6
tWVyKWypZi/iBvmxHWPdZd0pNzklXcVxKFJIdVzKaIjx606f3dV9vn+85z2P
ef3zFOxJkcfTaTTaFnLU13ZNP61PokPKf4xHT3YbUdyU5ll6Gh0MHutrVu8y
Imcreb+/kg4yfVtIlsKISsIaBp6dpUOjgf96/U4jUg+dGPpQTIeYW7JYbZgR
HR83GfFtpwO3gL5PF2REgUzbiV4RA2iV5QuhHkY0unmDyewrBnyrzOe1GQzI
qnNkPDLFFJJnmgtkZQYkmRkOEY6ZgXvWY3GE1IAue6m/vxJhDi7aRedwlgE9
yCu9vOqNBbSHKX2duvXILNdkudv25TB2sWp+WYkebdK0QfAEC+wYqdUBiXp0
tHdTFFvJhnOtjgPWfnp0t9h0evO4JcRnpOX+KdAjA3Cdgu9YgaTRpLuOoUfX
aDuyXJTW8Hyd4kbBBEYhkpnnck8OPO9rmPQcwOjdTxvVtgscmDfUt61+iJG1
3ON0bp0N4KdWH6cbMPJa1tt9WWkL90TKzNZqjMKlXewJHztA9qzM0RKMPg4f
vrQ4bwcb7Q9E7cjDqDKzY1/RnRVwZEmxPfU8Ro+SO09PHLeHhBbZeNAZjGb3
Zyz0ABe+tPL864d0jHizKoXFJzyofcRonz2KUXvbZvpCCw/cBz0kcakYpVzX
MI+cXwmX+ib/dUjGqPzFr/5V/g7Akdkwq/Zj1FPEPfa53gGmso40/xyPEY5f
y0T3PwP2Wlv+0B6Mar+be2x+ig8rdYGt6t0YbdMmfIgLdIQZXuhUbAxGTIWX
ne1yJ8ieDKzPjsZoY4z24PEHTqDc18cw7sSo4dZY3m+BzqCL8vtRtQMjywTp
RYtKZ+jZoFkn347RxNCoUbXkDElxZ4ICt2H0cJusojtWAAKdnOcXiVFsOmf4
4F0BWOawTZMiSF9VrWRAKISmsWC4Gk56jpXuLMkUgvemed5UGEberMYR1Ush
lPZ5noogtrx+vdAHXKCJP9t5T46Rbnp+PLTMBV71dc35E3/jsyJJRBeB9PDA
UsdWjOKkexPc4kUgYtKFMcQB5ma0s3+IgOv44QWd2Lkjs73a1RVCgn55XSPD
6N6arWtcs1yh2J0bHU38T7TEsvtvV7D0OnzenvhjnsDxaz83qGx20z+Rkj05
tNO8wg3mCo3sIuIWqURbyhBDlEQ1F018I9FXV0N8t/L3ScpVOd43G4hPWbx/
S/nCbX5LFzGDET5IOVI81W8gRnXCZsrvl9RmCqYYbN7eV1F2qOuJ55uKYbCX
vZIyu+Nh0irKnAAbyrQ3jWnexOK9J1mUx3jXMiTE9V5vlqKonpy0wgziQ6qm
UcohCk7rK2JgJ+oo+5ww63xHzArQVFP2vIJ7FoiFuf0VlG07Xr/81EwMq3z9
8ymPfHFz/itizX6+knKfVItDiOu54amU2xKv0iKJLQYvHKBcq8liHSJWZy9G
Ua64reSkEzelrYmgnN+fxFURux9K2EI5e2aXYz7x6MmyYMpKVrionHi44ClQ
/h/X0TTw
        "]]}, 
      {GrayLevel[0], Thickness[0.007], 
       LineBox[{{2.302585280960176, 1.627507435742037}, {2.39297851233326, 
        1.627507435742037}, {2.483371743706344, 1.627507435742037}, {
        2.679364985809464, 1.627507435742037}, {2.862370087763486, 
        1.627507435742037}, {3.0417853560704273`, 1.627507435742037}, {
        3.23640740373432, 1.627507435742037}, {3.418041311249115, 
        1.627507435742037}, {3.614881998120862, 1.627507435742037}, {
        3.808132851345528, 1.627507435742037}, {3.988395564421096, 
        1.627507435742037}, {4.183865056853616, 1.627507435742037}, {
        4.366346409137038, 1.627507435742037}, {4.545237927773379, 
        1.627507435742037}, {4.739336225766672, 1.627507435742037}, {
        4.920446383610867, 1.627507435742037}, {5.116763320812013, 
        1.627507435742037}, {5.3094904243660785`, 1.627507435742037}, {
        5.489229387771046, 1.627507435742037}, {5.684175130532966, 
        1.627507435742037}, {5.866132733145788, 1.627507435742037}, {
        6.063297115115562, 1.627507435742037}, {6.256871663438255, 
        1.627507435742037}, {6.43745807161185, 1.627507435742037}, {
        6.633251259142397, 1.627507435742037}, {6.816056306523846, 
        1.627507435742037}, {6.995271520258214, 1.627507435742037}, {
        7.189693513349534, 1.627507435742037}, {7.371127366291756, 
        1.627507435742037}, {7.56776799859093, 1.627507435742037}, {
        7.760818797243022, 1.627507435742037}, {7.940881455746017, 
        1.627507435742037}, {8.136150893605965, 1.627507435742037}, {
        8.318432191316814, 1.627507435742037}, {8.497123655380582, 
        1.627507435742037}, {8.691021898801303, 1.627507435742037}, {
        8.871932002072926, 1.627507435742037}, {9.0680488847015, 
        1.627507435742037}, {9.251177627180978, 1.627507435742037}, {
        9.430716536013373, 1.627507435742037}, {9.62546222420272, 
        1.627507435742037}, {9.807219772242968, 1.627507435742037}, {
        10.00418409964017, 1.627507435742037}, {10.19755859339029, 
        1.627507435742037}, {10.377944946991313`, 1.627507435742037}, {
        10.573538079949287`, 1.627507435742037}, {10.756143072758164`, 
        1.627507435742037}, {10.935158231919958`, 1.627507435742037}, {
        11.129380170438706`, 1.627507435742037}, {11.310613968808356`, 
        1.627507435742037}, {11.507054546534958`, 1.627507435742037}, {
        11.509989911769528`, 1.627507435742037}, {11.512925277004099`, 
        1.627507435742037}}]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 0.}, {2.302585092994046, 0.}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
        0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
         0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
         3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
         1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
         0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
         0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
         0.6418538861723948, 
         Log[4], 
         Log[6], 2.0794415416798357`, 2.1972245773362196`, 
         2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
         2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
         2.8903717578961645`, 2.9444389791664403`, 
         Log[40], 
         Log[60]}}, {{2.302585092994046, 4.605170185988092, 6.907755278982137,
         9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {0., 2.302585092994046, 1.6094379124341003`, 
        3.912023005428146, 0.6931471805599453, 2.995732273553991, 
        1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
        2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
        0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
        0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
        0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
        1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
        2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
        2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
        2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
        4.0943445622221}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {0., 3.4011973816621555`}}, {{2.302585092994046, 
       11.512925464970229`}, {0., 3.4011973816621555`}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.0986122886681098`, 
         FormBox[
          TagBox[
           InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.4011973816621555`, 
         FormBox[
          TagBox[
           InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.4054651081081644, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.70805020110221, 
         FormBox[
          TagBox[
           InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.9459101490553132`, 
         FormBox[
          TagBox[
           InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {4.248495242049359, 
         FormBox[
          TagBox[
           InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.09531017980432493, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[4], 1.3862943611198906`], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[6], 1.791759469228055], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[40], 3.6888794541139363`], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {
         NCache[
          Log[60], 4.0943445622221], 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"50\[CapitalOmega] input\"\>", {1.21, 0.58}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 1.24}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 4.0600000000000005`}, {-1, 0},
          Automatic, {1, 0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 4.739999999999999}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.44951300326475*^9, {3.44951303695225*^9, 3.449513041671*^9}, {
   3.44951310138975*^9, 3.44951316095225*^9}, {3.449513677421*^9, 
   3.44951371870225*^9}, {3.449514048421*^9, 3.4495140521085*^9}, 
   3.44951940576475*^9, 3.4495453772140713`*^9, 3.4495457168546968`*^9, 
   3.4495457595890713`*^9, 3.4495457995421968`*^9, 3.4495458406046968`*^9, {
   3.4495458762921968`*^9, 3.4495459017765713`*^9}, 3.4495459379015713`*^9, {
   3.4495459997296968`*^9, 3.4495460152765713`*^9}, {3.4495789591665*^9, 
   3.449579000369625*^9}, {3.44957903094775*^9, 3.44957904119775*^9}, {
   3.449579094213375*^9, 3.4495791064165*^9}, {3.449579145963375*^9, 
   3.449579226338375*^9}, 3.449579452775875*^9, 3.44957969857275*^9, 
   3.449581382900875*^9, 3.44958293253125*^9, 3.449593389125*^9, 
   3.44959937890625*^9, 3.449603935359375*^9, 3.4496175905625*^9, 
   3.449689109984375*^9, 3.44968929678125*^9, 3.4496893726875*^9, 
   3.449689489046875*^9, 3.449689578890625*^9, 3.449689629203125*^9, 
   3.4496897648125*^9, 3.449690715359375*^9, 3.449690851625*^9, 
   3.449691447328125*^9, 3.449692441921875*^9, 3.449692489234375*^9, 
   3.449692701546875*^9, 3.44969274171875*^9, 3.44969281878125*^9, 
   3.449693014859375*^9, 3.44970598109375*^9, 3.4501367781236415`*^9, 
   3.450186549243*^9, 3.4501890164305*^9, 3.450293665359375*^9, 
   3.45045527539925*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bias chain", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}, {
   3.449497639374125*^9, 3.449497642436625*^9}, {3.44951326432725*^9, 
   3.44951326488975*^9}, 3.449609321875*^9, 3.449688592984375*^9}],

Cell["Resistor ans Shottky noise in bias chain:", "Text",
 CellChangeTimes->{{3.449614161984375*^9, 3.449614184890625*^9}, 
   3.449688592984375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"zbias", "=", 
   RowBox[{"par", "[", 
    RowBox[{"Rbias", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "Cbias"}]], ",", 
     RowBox[{"ser", "[", 
      RowBox[{
       RowBox[{"ZShottky", "[", 
        RowBox[{"ibias", ",", "f"}], "]"}], ",", 
       RowBox[{"ZShottky", "[", 
        RowBox[{"ibias", ",", "f"}], "]"}], ",", "Rdrv"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.449497724421*^9, 3.449497744030375*^9}, {
   3.449497774780375*^9, 3.44949795345225*^9}, {3.44949802245225*^9, 
   3.449498148546*^9}, {3.449498294124125*^9, 3.4494983412335*^9}, {
   3.44949840970225*^9, 3.44949844920225*^9}, 3.44951007345225*^9, 
   3.449511477421*^9, 3.449511507749125*^9, {3.44951329776475*^9, 
   3.449513324717875*^9}, {3.449513360749125*^9, 3.449513370405375*^9}, {
   3.4495993220625*^9, 3.44959932646875*^9}, 3.449609321875*^9, 
   3.449688592984375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NTRratio", "=", 
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ShottkyNTR", "[", "f", "]"}], "-", "1"}], ")"}], 
     RowBox[{"Abs", "[", 
      FractionBox[
       RowBox[{"ser", "[", 
        RowBox[{
         RowBox[{"ZShottky", "[", 
          RowBox[{"ibias", ",", "f"}], "]"}], ",", 
         RowBox[{"ZShottky", "[", 
          RowBox[{"ibias", ",", "f"}], "]"}]}], "]"}], "Rdrv"], "]"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.44968923465625*^9, 3.44968927928125*^9}, {
  3.4496893626875*^9, 3.449689368078125*^9}, {3.44969140396875*^9, 
  3.449691415421875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"diodenoise", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"NTRratio", 
      SqrtBox[
       RowBox[{"FourKT", " ", 
        RowBox[{"Abs", "[", "zbias", "]"}]}]]}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"diodenoisebias", "[", 
    RowBox[{"1", ",", "ib_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"NTRratio", 
       SqrtBox[
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", "zbias", "]"}]}]]}], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4495134094835*^9, 3.449513446405375*^9}, {
   3.449513959155375*^9, 3.449513961999125*^9}, {3.44951400676475*^9, 
   3.4495140243585*^9}, 3.449514058280375*^9, {3.44951935301475*^9, 
   3.449519362030375*^9}, 3.449609321875*^9, {3.4496143395625*^9, 
   3.44961434015625*^9}, {3.449615120875*^9, 3.4496151238125*^9}, {
   3.449688345015625*^9, 3.449688348421875*^9}, {3.449688479515625*^9, 
   3.449688481609375*^9}, 3.449688592984375*^9, {3.449689286484375*^9, 
   3.4496892894375*^9}, {3.449691300875*^9, 3.449691306109375*^9}, {
   3.44969141296875*^9, 3.449691441265625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "zbias", "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1*^0", ",", "1*^3"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", "\"\<Impedance[\[CapitalOmega]]\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"10", ",", "3000"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4494981693585*^9, 3.449498277671*^9}, {
   3.4495454966671968`*^9, 3.4495454971984468`*^9}, 3.449616250390625*^9, {
   3.449616350390625*^9, 3.44961636253125*^9}, 3.449688593*^9, {
   3.449690730578125*^9, 3.449690740984375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV0nk81PkfB3BmjLsxjsFgPqjkiE45ZuX9RpslqnXtahxltQi52pQrcpQt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 2.302585092994046},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox["\"Impedance[\[CapitalOmega]]\"", TraditionalForm]},
  FrameTicks->{{{{
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[20], 2.995732273553991], 
       FormBox["20", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[200], 5.298317366548036], 
       FormBox["200", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[2000], 7.600902459542082], 
       FormBox["2000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[20], 2.995732273553991], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[200], 5.298317366548036], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[2000], 7.600902459542082], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{0, 
       FormBox["1", TraditionalForm]}, {
       NCache[
        Log[5], 1.6094379124341003`], 
       FormBox["5", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0, 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5], 1.6094379124341003`], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->NCache[{{0, 
      Log[5], 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`,
       1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
      4.382026634673881, 4.499809670330265, 5.298317366548036, 
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
      6.551080335043404, 6.684611727667927, 6.802394763324311, 
      7.600902459542082, 8.006367567650246, 8.294049640102028}, {
      Log[10], 
      Log[20], 
      Log[50], 
      Log[100], 
      Log[200], 
      Log[500], 
      Log[1000], 
      Log[2000], 
      Log[5000], 3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
      6.551080335043404, 6.684611727667927, 6.802394763324311, 
      8.006367567650246, 8.294049640102028}}, {{
     0, 1.6094379124341003`, 2.302585092994046, 3.912023005428146, 
      4.605170185988092, 6.214608098422191, 6.907755278982137, 
      8.517193191416238, 0.6931471805599453, 1.0986122886681098`, 
      1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
      2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
      3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.396929655216146, 6.551080335043404, 6.684611727667927, 
      6.802394763324311, 7.600902459542082, 8.006367567650246, 
      8.294049640102028}, {2.302585092994046, 2.995732273553991, 
     3.912023005428146, 4.605170185988092, 5.298317366548036, 
     6.214608098422191, 6.907755278982137, 7.600902459542082, 
     8.517193191416238, 3.4011973816621555`, 3.6888794541139363`, 
     4.0943445622221, 4.248495242049359, 4.382026634673881, 4.499809670330265,
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
     6.551080335043404, 6.684611727667927, 6.802394763324311, 
     8.006367567650246, 8.294049640102028}}],
  Method->{},
  PlotRange->NCache[{{0, 
      Log[1000]}, {2.302585092994046, 8.006367567650246}}, {{
     0, 6.907755278982137}, {2.302585092994046, 8.006367567650246}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0, 
      FormBox["1", TraditionalForm]}, {
      NCache[
       Log[5], 1.6094379124341003`], 
      FormBox["5", TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[20], 2.995732273553991], 
      FormBox["20", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[200], 5.298317366548036], 
      FormBox["200", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[2000], 7.600902459542082], 
      FormBox["2000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.44968911021875*^9, 3.449689297078125*^9, 3.44968937296875*^9, 
   3.44968948928125*^9, 3.449689579078125*^9, 3.449689629609375*^9, 
   3.44968976503125*^9, {3.44969072140625*^9, 3.44969074175*^9}, 
   3.44969085184375*^9, 3.4496914475*^9, 3.449692442109375*^9, 
   3.449692489421875*^9, 3.44969270175*^9, 3.44969274190625*^9, 
   3.449692818953125*^9, 3.449693015046875*^9, 3.44970598128125*^9, 
   3.4501367782955165`*^9, 3.450186549633625*^9, 3.45018901671175*^9, 
   3.4502936655625*^9, 3.45045527564925*^9}]
}, Open  ]],

Cell[TextData[{
 "Bias driver and supply noise:\nAssume <",
 Cell[BoxData[
  FormBox[
   RowBox[{"100", 
    FractionBox["nV", 
     SqrtBox["Hz"]]}], TraditionalForm]]],
 "noise on the BIAS drive at f > 10Hz.\nAssume <",
 Cell[BoxData[
  FormBox[
   RowBox[{"200", 
    FractionBox["nV", 
     SqrtBox["Hz"]]}], TraditionalForm]]],
 "noise on the 24V supply side at f > 10Hz."
}], "Text",
 CellChangeTimes->{{3.44959945890625*^9, 3.44959946053125*^9}, {
   3.449603163859375*^9, 3.44960316615625*^9}, {3.44960863359375*^9, 
   3.44960867696875*^9}, {3.449608708703125*^9, 3.4496087974375*^9}, {
   3.449609223765625*^9, 3.44960922440625*^9}, {3.4496092929375*^9, 
   3.449609321875*^9}, 3.4496141883125*^9, {3.449614634390625*^9, 
   3.4496146379375*^9}, 3.449688593*^9, 3.44969247875*^9, {
   3.449692780328125*^9, 3.44969278121875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"zDrv", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cDrv", "=", "20*^-6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"driveNoise", "[", "0", "]"}], "=", "100*^-9"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supplyNoise", "[", "0", "]"}], "=", "200*^-9"}], ";"}]}], "Input",\

 CellChangeTimes->{{3.44961467309375*^9, 3.449614701875*^9}, {
   3.449617964125*^9, 3.44961799040625*^9}, {3.449618045046875*^9, 
   3.449618045875*^9}, {3.4496854995*^9, 3.449685508765625*^9}, 
   3.449685563078125*^9, 3.449685700046875*^9, {3.4496858043125*^9, 
   3.449685804796875*^9}, {3.4496875771875*^9, 3.44968757846875*^9}, {
   3.4496877293125*^9, 3.44968772984375*^9}, 3.449688593*^9, 
   3.449692482546875*^9, {3.449692736203125*^9, 3.449692736921875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"splyDrv", "[", "0", "]"}], "=", 
   FractionBox[
    RowBox[{"par", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", 
        RowBox[{"ZShottky", "[", 
         RowBox[{"ibias", ",", "f"}], "]"}]}], "+", "Rdrv"}], ",", 
      FractionBox["1", 
       RowBox[{"s", " ", "Cbias"}]]}], "]"}], 
    RowBox[{
     RowBox[{"par", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         RowBox[{"ZShottky", "[", 
          RowBox[{"ibias", ",", "f"}], "]"}]}], "+", "Rdrv"}], ",", 
       FractionBox["1", 
        RowBox[{"s", " ", "Cbias"}]]}], "]"}], "+", "Rbias"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"splyNoise", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"splyDrv", "[", "0", "]"}], "]"}], 
       RowBox[{"supplyNoise", "[", "0", "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"splyNoise", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"splyNoise", "[", 
      RowBox[{"0", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.449599470796875*^9, 3.44959949940625*^9}, {
   3.44959953396875*^9, 3.449599619640625*^9}, {3.4495996873125*^9, 
   3.449599799703125*^9}, {3.449600014671875*^9, 3.44960007425*^9}, {
   3.44960013784375*^9, 3.449600241109375*^9}, {3.449600276015625*^9, 
   3.44960031625*^9}, {3.449602844078125*^9, 3.449602900546875*^9}, {
   3.449602930578125*^9, 3.44960308375*^9}, {3.449603131359375*^9, 
   3.4496032285625*^9}, {3.44960326071875*^9, 3.4496032773125*^9}, {
   3.449603333640625*^9, 3.44960337340625*^9}, {3.449603409578125*^9, 
   3.449603417578125*^9}, {3.449604005265625*^9, 3.4496040256875*^9}, 
   3.44960406165625*^9, 3.449604146203125*^9, 3.4496041873125*^9, {
   3.4496044195*^9, 3.4496044434375*^9}, {3.44960453496875*^9, 
   3.449604567359375*^9}, {3.449604603875*^9, 3.449604605109375*^9}, {
   3.4496048100625*^9, 3.44960482634375*^9}, {3.449604865140625*^9, 
   3.4496048695625*^9}, {3.449606219890625*^9, 3.44960622196875*^9}, {
   3.449607096328125*^9, 3.4496071039375*^9}, {3.4496071363125*^9, 
   3.44960714859375*^9}, {3.449607292984375*^9, 3.449607293671875*^9}, {
   3.44960732603125*^9, 3.449607341734375*^9}, {3.44960880553125*^9, 
   3.449608864828125*^9}, {3.449608907328125*^9, 3.44960905565625*^9}, {
   3.44960923190625*^9, 3.449609275578125*^9}, 3.449609321890625*^9, {
   3.449614642640625*^9, 3.449614669640625*^9}, 3.449688593*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"biasDrv", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"par", "[", 
      RowBox[{"Rbias", ",", 
       FractionBox["1", 
        RowBox[{"s", " ", "Cbias"}]]}], "]"}], 
     RowBox[{
      RowBox[{"par", "[", 
       RowBox[{"Rbias", ",", 
        FractionBox["1", 
         RowBox[{"s", " ", "Cbias"}]]}], "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"ZShottky", "[", 
        RowBox[{"ibias", ",", "f"}], "]"}]}], "+", "Rdrv"}]], "/.", 
    RowBox[{"{", 
     RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"biasDrv", "[", "0", "]"}], "=", 
   RowBox[{"biasDrv", "[", 
    RowBox[{"0", ",", "ibias"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpDrv", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"biasDrv", "[", "0", "]"}], 
       RowBox[{"OpAmp", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "zDrv", ",", 
         RowBox[{"par", "[", 
          RowBox[{"zDrv", ",", 
           FractionBox["1", 
            RowBox[{"s", " ", "cDrv"}]]}], "]"}]}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpDrv", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpDrv", "[", 
      RowBox[{"0", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpDrv", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "zDrv", ",", 
      RowBox[{"par", "[", 
       RowBox[{"zDrv", ",", 
        FractionBox["1", 
         RowBox[{"s", " ", "cDrv"}]]}], "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpDrv", "[", "2", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"1", ",", "\[Infinity]", ",", "1"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"OpAmpNoiseDrv", "[", 
    RowBox[{"1", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OpAmpNoise", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "zDrv", ",", 
         RowBox[{"par", "[", 
          RowBox[{"zDrv", ",", 
           FractionBox["1", 
            RowBox[{"s", " ", "cDrv"}]]}], "]"}], ",", "en", ",", "in"}], 
        "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.",
      
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"OP27", "[", "f", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpNoiseDrv", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoiseDrv", "[", 
      RowBox[{"1", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpNoiseDrv", "[", 
    RowBox[{"2", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"OpAmpNoise", "[", 
            RowBox[{"1", ",", "\[Infinity]", ",", "0", ",", "en", ",", "in"}],
             "]"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["in", "2"], 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"par", "[", 
              RowBox[{"zDrv", ",", 
               FractionBox["1", 
                RowBox[{"s", " ", "cDrv"}]]}], "]"}], "]"}], "2"]}], "+", 
          RowBox[{"FourKT", " ", 
           RowBox[{"Abs", "[", 
            RowBox[{"par", "[", 
             RowBox[{"zDrv", ",", 
              FractionBox["1", 
               RowBox[{"s", " ", "cDrv"}]]}], "]"}], "]"}]}]}], ")"}]}], "/.",
        
       RowBox[{"{", 
        RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.",
      
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"OP27", "[", "f", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OpAmpNoiseDrv", "[", "2", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"OpAmpNoiseDrv", "[", 
       RowBox[{"2", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "averaged", " ", "output", " ", "noise", " ", "through", " ", "bais", " ", 
    "network"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpNoiseDrv", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"biasDrv", "[", 
      RowBox[{"0", ",", "ib"}], "]"}], "]"}], 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{"OpAmpDrv", "[", "1", "]"}], "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"OpAmpNoiseDrv", "[", 
            RowBox[{"1", ",", "ib"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{"OpAmpDrv", "[", "2", "]"}], "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"OpAmpNoiseDrv", "[", 
            RowBox[{"2", ",", "ib"}], "]"}], "2"]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OpAmpNoiseDrv", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoiseDrv", "[", 
      RowBox[{"0", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.449686200796875*^9, {3.4496862525*^9, 3.44968627890625*^9}, {
   3.449686544890625*^9, 3.449686571921875*^9}, {3.449686842671875*^9, 
   3.4496869538125*^9}, {3.4496869965*^9, 3.449687000625*^9}, {
   3.449687065078125*^9, 3.44968706978125*^9}, {3.449687179671875*^9, 
   3.449687216140625*^9}, {3.449687294953125*^9, 3.449687349984375*^9}, 
   3.449687469203125*^9, {3.449687702734375*^9, 3.449687705578125*^9}, 
   3.449688593*^9, {3.44969060846875*^9, 3.4496906158125*^9}, {
   3.44969196015625*^9, 3.449692005734375*^9}, {3.449692085703125*^9, 
   3.4496921389375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"drvNoise", "[", 
    RowBox[{"0", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"driveNoise", "[", "0", "]"}], 
    RowBox[{"Abs", "[", 
     RowBox[{"OpAmpDrv", "[", 
      RowBox[{"0", ",", "ib"}], "]"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"drvNoise", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"driveNoise", "[", "0", "]"}], 
    RowBox[{"Abs", "[", 
     RowBox[{"OpAmpDrv", "[", "0", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.44961468575*^9, 3.449614777484375*^9}, 
   3.449688593015625*^9, {3.44969215290625*^9, 3.44969217434375*^9}}],

Cell["Total noise is bias chain:", "Text",
 CellChangeTimes->{{3.449609368*^9, 3.44960943965625*^9}, {3.4496143554375*^9,
    3.44961436746875*^9}, 3.449688593015625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"detnoise", "[", "1", "]"}], "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"diodenoise", "[", "1", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"OpAmpNoiseDrv", "[", "0", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"splyNoise", "[", "0", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"drvNoise", "[", "0", "]"}], "2"]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"detnoisebias", "[", 
    RowBox[{"1", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"diodenoisebias", "[", 
           RowBox[{"1", ",", "ib"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"OpAmpNoiseDrv", "[", 
           RowBox[{"0", ",", "ib"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"splyNoise", "[", 
           RowBox[{"0", ",", "ib"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"drvNoise", "[", 
           RowBox[{"0", ",", "ib"}], "]"}], "2"]}], ")"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.", 
    
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.449614513578125*^9, 3.449614516359375*^9}, 
   3.449614988640625*^9, {3.44961556675*^9, 3.449615618765625*^9}, 
   3.449688593015625*^9, 3.449691874203125*^9, {3.449692195703125*^9, 
   3.449692214375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", 
         RowBox[{"diodenoise", "[", "1", "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"OpAmpNoiseDrv", "[", "0", "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"splyNoise", "[", "0", "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"drvNoise", "[", "0", "]"}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"detnoise", "[", "1", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "100000"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.01", ",", "20"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Brown"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Shottky and resistor\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<OpAmp\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Supply at 200nV/\!\(\*SqrtBox[\(Hz\)]\)\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Bias at 100nV/\!\(\*SqrtBox[\(Hz\)]\)\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Brown", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Total\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.87", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.4"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449599627578125*^9, 3.44959963575*^9}, {
   3.44959982346875*^9, 3.449599827*^9}, {3.44959986284375*^9, 
   3.449599896078125*^9}, {3.44960008040625*^9, 3.44960011303125*^9}, {
   3.449600249640625*^9, 3.44960025421875*^9}, {3.44960030175*^9, 
   3.449600303859375*^9}, {3.4496003510625*^9, 3.44960035678125*^9}, {
   3.449603241671875*^9, 3.449603250625*^9}, {3.44960328478125*^9, 
   3.449603291234375*^9}, {3.449603438546875*^9, 3.4496034441875*^9}, {
   3.44960350015625*^9, 3.449603578265625*^9}, {3.449603768328125*^9, 
   3.449603798828125*^9}, 3.449603919875*^9, {3.4496041328125*^9, 
   3.4496041344375*^9}, {3.44960428653125*^9, 3.44960430171875*^9}, 
   3.44960445925*^9, {3.44960462078125*^9, 3.449604620984375*^9}, {
   3.449604691078125*^9, 3.449604740078125*^9}, {3.449604881984375*^9, 
   3.449604895453125*^9}, {3.449607744859375*^9, 3.4496077720625*^9}, {
   3.449609067953125*^9, 3.44960907578125*^9}, 3.449609321890625*^9, {
   3.449614789671875*^9, 3.4496149653125*^9}, {3.44961500265625*^9, 
   3.4496150133125*^9}, 3.449615077703125*^9, {3.44961513703125*^9, 
   3.449615141859375*^9}, {3.44961517521875*^9, 3.449615363421875*^9}, {
   3.449615411140625*^9, 3.44961550421875*^9}, {3.449615633859375*^9, 
   3.44961575540625*^9}, {3.44961731671875*^9, 3.4496173423125*^9}, 
   3.449617471359375*^9, 3.44968606715625*^9, 3.449686207984375*^9, {
   3.44968736740625*^9, 3.44968738265625*^9}, 3.4496876244375*^9, 
   3.449688593015625*^9, {3.44969172609375*^9, 3.44969180046875*^9}, {
   3.449691830859375*^9, 3.4496918361875*^9}, {3.449692238265625*^9, 
   3.449692272859375*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVzns01GkcBvC5MJkJg4ZMNsZl0FXK7Mml/X1lkdpJqahcSmvUpmg2USop
Nbq4Zm0XYjpsaklJRZH3V8qOhshGh4joDFY1jUyTcdu3P57znM85zx+P9Y6Y
ABGNQqGsxfnexY3KV+VRNJgT0pbPndIQEZ+kbQliGsRItsSKNRqCZxTQ7hVP
A7M/3LtknzXE5Q13X7edoEGC4K/IuH4Nkd55sHPsEg3GdR8mNso0RNwgtddT
RoMulTJRlK0hvHU4wy/t6PA6QlO+zlFD9Lsvp4500+HLb25Gruu/Ekby3sHA
GF1YcERfzj0ySghVPX42CgYwIyiW7U9HiEzn9IzsTXpQmmtW+9ZMRdRl5WXO
e88E8YmQMp+0TwTjDHWm/eaZ8Ejk6ZK7ZJhwk9aD77A+HNo2TovOHiBiX7oF
G8YbwmFvepeI/Z6ovaSrdB9kQ3HH9n2xzb3EBJhb+dYYgcGGBQ0OhZ3EVcqW
ZNt4Y+hPnk31WfSK8BOqOgIWmwCzgl//9bmcGLrhms5Rm8BJwY0zF9NqCOOA
RcfOlM2Cji8NHczlqYQz62VTZjwHPhqzspZFVqKN/o2Gwx6moFqm+7amVYam
e35P/TZqCuF9G1OcEltRYVLDzos1ZlCWsNp6TL8DvdgjPzYcNxv+PswpvGTb
g0Z2HVW3gDnkhQgLHDv7EHdEEsqcwYU/s8OI42wFktW709SICy2ranfVs4ZQ
TIlUZ//pOXDMt7si2usDyn9z26vIywLk1UsF31YqUctF8wOO4xaQmvNL6z1z
FdKKlugQT34AaRDVoL5sBJUmfmnWOzIXRrZNVvY6jqKg4sixCG9LcDkbIOx5
rEY6oc6mnJlWoHXJaL0VoEGuYcV74+qsYLXhrZixf76hu5WKrHvePFCsD5MS
IVrEjvQ/xyzkwYVyRqtT2zga7uyflEzx4AmP77LJZxI9DVpX0BRuDXc+jwan
tE+h8ASTnr211tC6vfnZCz6F1BaVCl/b2EAdKu/sU1LIoAN5Wy8n2cCFD1Kj
uFIqKdCv6pV02UBV+fUdK0Q0kl1SkuMBtlDZ8mYoaxGdvKkcHVxzxRbEPDfm
gUE6ucrDLMqOZgfqNFGB4o4OGeH/a6S9yA72+fTsyjmkS/6sx6CceGwHF2IF
x7uXMkheQ5LsGp8PSSL/effHGSTptN6Jn8yH8GX5TQsrZ5DvQoTsprd8kHJ9
7f+L1iOns6wtf1ppD0Vgscb1Ryb5bs8auV6BPRhevsJe+JlJIn9hcR7dAeYn
TypuP2CRd3Z73ryOXTcrY1KGXXRKUHEXu+A0j/MO+2z1XNT4fW/l5Wn8kEUG
Onxqn8A+Ny3JFWN/nEpnhOo4wPM05rql1SzSoqxFNFfXARr7xqoqalikYcPT
qHnYlRMpzXJsyvsqsQBbpTVV9GMruFePCrGDi5xncR7hP6fEOUexGSU798Zi
+4WaPOvGZp1+YS2oZZEeBxnyIez5A1uXC7EXZ2tb1Nj58wfWirA5DX1dBgwH
yAybPpyD3etSMboC+3zC4nY19r/+xVo/7JiJBx8MEIus351LCcS+tsObbo9d
Kk3Wj8a26QpeEohdUB1vkoC9U6nwicY+3x5lLsHWGxCHSrBPqrZZnsem1k3s
z8eO199ol4+9OTnl7H3s/wG0IUQr
        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], 
       LineBox[{{2.302585280960176, 0.5385823841025805}, {2.305410069440585, 
        0.5349704506048223}, {2.3082348579209935`, 0.5313589886846024}, {
        2.3138844348818113`, 0.5241374887428063}, {2.325183588803447, 
        0.5097002483702783}, {2.347781896646718, 0.48084931317428464`}, {
        2.39297851233326, 0.42324561960509344`}, {2.483371743706344, 
        0.308461729129595}, {2.679364985809464, 0.06179153365360037}, {
        2.862370087763486, -0.16541486319244958`}, {
        3.0417853560704273`, -0.38492688937807334`}, {
        3.23640740373432, -0.6192206176889747}, {
        3.418041311249115, -0.8342297247559405}, {
        3.614881998120862, -1.0633184296841889`}, {
        3.808132851345528, -1.2844183815871228`}, {
        3.988395564421096, -1.48745964287574}, {
        4.183865056853616, -1.7044105112788517`}, {
        4.366346409137038, -1.9041966996723345`}, {
        4.545237927773379, -2.0977394013687714`}, {
        4.739336225766672, -2.3054348329279093`}, {
        4.920446383610867, -2.497334745939396}, {
        5.116763320812013, -2.7035518693292637`}, {
        5.3094904243660785`, -2.9044328522779588`}, {
        5.489229387771046, -3.090579888953777}, {
        5.684175130532966, -3.2913641863219567`}, {
        5.866132733145788, -3.4778837254258588`}, {
        6.063297115115562, -3.6791759582600427`}, {
        6.256871663438255, -3.8761098918266637`}, {
        6.43745807161185, -4.059311246269947}, {
        6.633251259142397, -4.257465988392765}, {
        6.816056306523846, -4.442103275859488}, {
        6.977766148682797, -4.605170185988091}}]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[{{2.302585280960176, 0.40292683543435637`}, {2.305410069440585,
         0.40042956255578943`}, {2.3082348579209935`, 0.397930657431925}, {
        2.3138844348818113`, 0.3929279787417438}, {2.325183588803447, 
        0.3829033445130063}, {2.347781896646718, 0.3627785269201072}, {
        2.39297851233326, 0.32223888418314417`}, {2.483371743706344, 
        0.24009257599795839`}, {2.679364985809464, 0.05789590653650682}, {
        2.862370087763486, -0.11609440326595492`}, {
        3.0417853560704273`, -0.2892652699220781}, {
        3.23640740373432, -0.4791715430975546}, {
        3.418041311249115, -0.6577633801386991}, {
        3.614881998120862, -0.8523318927932305}, {
        3.808132851345528, -1.0440671701787028`}, {
        3.988395564421096, -1.223355166203093}, {
        4.183865056853616, -1.418096836509715}, {
        4.366346409137038, -1.600112402482107}, {
        4.545237927773379, -1.778685602103105}, {
        4.739336225766672, -1.9725456909455326`}, {
        4.920446383610867, -2.153503181355604}, {
        5.116763320812013, -2.349706518917461}, {
        5.3094904243660785`, -2.5423580465206688`}, {
        5.489229387771046, -2.722048477986095}, {
        5.684175130532966, -2.916957994451807}, {
        5.866132733145788, -3.098892419615019}, {
        6.063297115115562, -3.2960395945056153`}, {
        6.256871663438255, -3.489602715561913}, {
        6.43745807161185, -3.67018179649699}, {
        6.633251259142397, -3.8659695262965847`}, {
        6.816056306523846, -4.048771086866997}, {
        6.995271520258214, -4.227983921020942}, {
        7.189693513349534, -4.422404135773722}, {
        7.371127366291756, -4.603836850029887}, {
        7.3724607079891085`, -4.605170185988091}}]}, 
      {GrayLevel[0], Thickness[0.007], 
       LineBox[{{2.302585280960176, 0.9727236732048242}, {2.305410069440585, 
        0.9674193376521126}, {2.3082348579209935`, 0.9621132706162785}, {
        2.3138844348818113`, 0.951495972594103}, {2.325183588803447, 
        0.9302409329381573}, {2.347781896646718, 0.8876507570989065}, {
        2.39297851233326, 0.8021631270309542}, {2.483371743706344, 
        0.6300585331481576}, {2.679364985809464, 0.2525812253558068}, {
        2.862370087763486, -0.1039585428128641}, {
        3.0417853560704273`, -0.456233604057605}, {
        3.23640740373432, -0.8405294369558675}, {
        3.418041311249115, -1.2006063098044297`}, {
        3.614881998120862, -1.5919048752363119`}, {
        3.808132851345528, -1.9768174766523123`}, {
        3.988395564421096, -2.3363210086240596`}, {
        4.183865056853616, -2.726497001188901}, {
        4.366346409137038, -3.090971437047036}, {
        4.545237927773379, -3.448420802264491}, {
        4.739336225766672, -3.836367705972607}, {
        4.920446383610867, -4.1984279974670065`}, {
        5.116763320812013, -4.590942799461744}, {
        5.12387847633928, -4.605170185988091}}]}, 
      {RGBColor[0.6, 0.4, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwVzns803scx/GZWTaL0nRIGWszCqUHexTq93GcnVzOWumi27q4dSQ5VFZK
CemoOOhUdIhV5yyhxznRIRzfnxMhrdZlHEWULuuhzBYnNnS+54/34/V4/vd2
Co8PjaJSKJRVeP9XcV/79I9YKuhUZ9TMdiMROVSqTk6gQtcnXRa30Ug4zgjt
DJBRIVsU6L+iykhcXFvdpU6jgrzMr+p4sZHIeXbw2XghFX5l2x5ZmmgkkjQm
/f5tVFhXV/hd5FwjIaKxBx/xTKH2coh92T4DMeC71ETfawp1mhrhIfdxYkZH
v2ZDvBmE68xODxT8S4h1fUHct3Tw5JjGeOwYIXI9c346u94c7CqafNPW64k7
eUW5rq8ZIBNmXOf4DRP0LBML540W8G3XwjnBNR8In9K7sHKQBcOWH8P72jTE
/kc+WyxllsCappVkm78hGgvNtL4aK+A+XhjcVPSSmABbzsqGGTBVcKo4TP+c
kFM2pc+XzYS1hEo6HKAmgsS67lAPa+hPb23eX6wk3pcty2GPWoObieP7glxE
zAx1P5Z1YxbU/Kwfe+dVQHgyHylzZWwo2b7Vhb36FlonuW856GcDtt3l3vzR
VvSlL/HM2IgNnNzsFmvj9BhdSW3fVdAwG7Lc7jW8Rv+gB3s6jg0mfQVEn1XU
1KsXSP99yqgKbKH8AUOQgl4hO32mlDHNDrYpcymx429Q211f6iiyg4Qfqob8
xzQovryUtu/HORCn37Kf5/UBXXr+e8DVAHvI4yydvlioRaoC2wMuRns4S+Gh
TbN0yBC1mEb8PReI2eGqjdf1qOLop4fmR+ZB2NChCTf+CApTRI9HihyANbar
9nHjKKJJPW3YFhyIGGcqF6z+jJZtU8Ql3eFAoqS7rLdlDFXXvM27JXKENoOw
OW2zAVlFS04zrjhCCbMpteGJEQ0+G5jMnHIEfptE6CCaRM1hq0uUO53g5G3l
00z1FNqZbN0X1+gElUdziiL4FNJwtULcxeWCvDui8pSWQoYdKNp8MZUL1fKH
+W4VJqQ3q7Y/s4cLy4ITB79EUkmr8vJzfjAfOkWiwO3upmSldkQTUjwftB6u
94I1pmSg3+xYHpUHjAnFuzs3aWSkJCLaOYoHdRaBrQcPmZHfmNMpaU08OD2L
f75lCZ10bE9t+43PB1pB+OHLRjpJLlqziJ/OB3GMInpuzTTy5VaxlfIFH2wy
nfb27DUnv+Q5Oaz42hlSG1om3YUM8uWekA7zEmdYUs2Uc4cZJJKIFUWmAlB+
kDqX3WaSN3f7V17DTjJ1WN6EffWEd1U1dshk79pu7FP189B97BMXpccZdUxy
g2CocwJ70eEtPTHYH6dy6FKaAOrVa/IX1DNJ+xuqqHlmAojXu0yVNzBJy/bm
WFfsC/Fv2M3YlNe1Cd7Ynx/KF/Zgv7WTp4ix43zmbGL9hf+cSDiXgi34k1G9
BztIat3Si+0SNBDj3sgk/Q7SO95j8w3FqSJsj7MG1Sh2eM7GC1Jsdvurnul0
Ach3KJuzsfu9qkaWY/tU3OIMYT+RKAxB2IGyeCEdMcm7u3+hbMAu5LuKHbAr
StNZe7EZbkXJq7BL6mXWydguGevzorHzO2NtM7GzkeW1o9gZuu0O+dheL1ob
z2PLWOt4l7D5/anqG9j/AYZEPqI=
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], -4.605170185988091}, {
       2.302585092994046, -4.605170185988091}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.00\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.00\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.00\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.00\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 2.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {0, -Log[2], 
         Log[5], -Log[10], 
         Log[10], -Log[20], 
         Log[50], -
         Log[100], -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`, 
         1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
         2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
         3.6888794541139363`}}, {{2.302585092994046, 4.605170185988092, 
        6.907755278982137, 9.210340371976184, 11.512925464970229`, 
        2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
        3.912023005428146, 4.0943445622221, 4.248495242049359, 
        4.382026634673881, 4.499809670330265, 5.298317366548036, 
        5.703782474656201, 5.991464547107982, 6.214608098422191, 
        6.396929655216146, 6.551080335043404, 6.684611727667927, 
        6.802394763324311, 7.600902459542082, 8.006367567650246, 
        8.294049640102028, 8.517193191416238, 8.699514748210191, 
        8.85366542803745, 8.987196820661973, 9.104979856318357, 
        9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
        10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
        11.289781913656018`, 11.407564949312402`}, {
        0, -0.6931471805599453, 1.6094379124341003`, -2.302585092994046, 
         2.302585092994046, -2.995732273553991, 
         3.912023005428146, -4.605170185988092, -3.912023005428146, \
-3.506557897319982, -3.2188758248682006`, -2.8134107167600364`, \
-2.6592600369327783`, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 0.6931471805599453, 1.0986122886681098`, 
         1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
         3.4011973816621555`, 3.6888794541139363`}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {-4.605170185988091, 2.995732273553991}}, {{
       2.302585092994046, 11.512925464970229`}, {-4.605170185988091, 
       2.995732273553991}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[2], -0.6931471805599453], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox[
          TagBox[
           InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[10], -2.302585092994046], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox[
          TagBox[
           InterpretationBox["\"10.00\"", 10., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[20], -2.995732273553991], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox[
          TagBox[
           InterpretationBox["\"50.00\"", 50., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[100], -4.605170185988092], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.6592600369327783`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.4, 0.2], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Total\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Bias at 100nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)\"\>", \
{1.21, 1.74}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 2.4}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Supply at 200nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)\"\>", \
{1.21, 2.9}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"OpAmp\"\>", {1.21, 4.0600000000000005`}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 4.72}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Shottky and resistor\"\>", {1.21, 5.22}, {-1, 0}, 
         Automatic, {1, 0}]}}, {}},
     AspectRatio->0.4,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 5.8999999999999995`}}], {0.87, 0.}, {
    Left, Bottom}, {1, 0.4}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.44969177875*^9, 3.449691801453125*^9}, {
   3.449692242625*^9, 3.449692274234375*^9}, 3.449692442765625*^9, 
   3.449692490015625*^9, 3.44969270234375*^9, 3.4496927425*^9, 
   3.4496928195625*^9, 3.449693015734375*^9, 3.449705981921875*^9, 
   3.4501367793736415`*^9, 3.450186555039875*^9, 3.45018901764925*^9, 
   3.450293666171875*^9, 3.450455276571125*^9}]
}, Open  ]],

Cell["Bias chain transfer function", "Text",
 CellChangeTimes->{{3.449705905015625*^9, 3.44970591278125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"comp", "[", "f_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "f"}], "+", "0.7"}], 
    RowBox[{"\[ImaginaryI]", " ", "f"}]], 
   FractionBox[
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "f"}], "+", "0.2"}], 
    RowBox[{"\[ImaginaryI]", " ", "f"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dB", "[", 
   RowBox[{"OpAmpDrv", "[", "0", "]"}], "]"}], "/.", 
  RowBox[{"f", "\[Rule]", "1"}]}]}], "Input",
 CellChangeTimes->{{3.449706048375*^9, 3.449706131328125*^9}, 
   3.449716022328125*^9, {3.44971638471875*^9, 3.4497163950625*^9}}],

Cell[BoxData[
 RowBox[{"-", "4.625719056768488`"}]], "Output",
 CellChangeTimes->{3.449716418203125*^9, 3.4501367795142665`*^9, 
  3.450186555289875*^9, 3.450189017868*^9, 3.4502936663125*^9, 
  3.450455276743*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"OpAmpDrv", "[", "0", "]"}], 
    RowBox[{"comp", "[", "f", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "0.01", ",", "100"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Brown"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449705918796875*^9, 3.449705921109375*^9}, {
  3.44970595365625*^9, 3.449705968125*^9}, {3.449706005171875*^9, 
  3.449706005609375*^9}, {3.449706089390625*^9, 3.44970610134375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwl1OlTU1cABfDIKkQivFFaIghxoQ4KSETBJb4riyQEEiN0Kogg1AQQWRQk
QkOCLBaxLIlYqnYUQRNZAghGhBrfVWtBJ9gaia06ILK5gKxBBTH0dvrhzJnf
H3AOLSZ5N9+IRCJxUP7rYLuvG64lYPCUYJN/VyQXJBUQbp1xGMzJTPu2eA8X
lH4U1L/hY9DjjjyOuZsLunQqpeN+DC6a/VR+y58LwmUhdUWhGKTMaqhX1nGB
gFxSHc/AYPx9iip9lgPEX0wv0xZj8Gi5S4T9zxzQ8GrqF2mTDQybpxYd6QwG
duccV798aw1jXcTC89Qg8NmsIi3DzRqKXh6eM+QFguZOadXx9xR4urgqcOgj
E2Qn5lYOR1rBvc6qaXJgAGCkL18z9o4M3w8ca/iqzR9YRIVNdn5nCe1Mr7eW
WPqBP10H/zbTLITtG4F5Ld8H5POpfs/CzWG9Vplf2gtAYNaY/sRDU6jMbsX1
ku2AZEhc9yjUBBaUV/6lzd0KGg8wJMlDRpD1LsL4gcIbJNfW2Y7sWQCzIn4i
rZRvBNtuFMabaOYJh03TQKqng1bdZ7fXijniQiG/ccp1PVh3h7JWLJshKuJt
a69uXQvE4jRPZtMHIomhYjvccQajn+3aO05PETZljLHrXivAdjYWK6oZJ1jV
i8ei8+xBuKrMqdN0mHBxzRpyT10CaIeYvRZdA0TkmdoNg68sAK/I92iYXQ9R
o2A852g+4c98pjkZ0sdE4Ba1vtrhEVEw3yE8k9FCxHDSfeu3GQjzYOe+9Ngb
uPaikaBvwyI4wjer2UnW4oflJR+5+5ZC2wkvQb+iG19BIT1OOGAP+xkqg3b5
ID5osvm8rccKuHvYspsdNIxntpBqM8OdYXbmvl0NP47j5VE2R02yXOBmYnpN
jmIK579grDYEuEMb+lY9TfYBZ6u/oZ01p0P9Pz0FVkkzuNpQdZic6wnbCJ8y
n4I5XEFXSqrCvGBFV4jML3EebyH0v3c6bIHXy2TGTOYCkHSq3C3HmwHXPOV5
hRJGoPuBxMrXDsBLHpBr5m4CxlNoLQNndkCysnhlt9oUXI26q6309oX5RHMK
lW4Ormir8dR7fnB8wjtDdH8haAyeoUYf2QmjtycK8niWYPKFiKhaxoR9tE+a
ybtkkPbSPuFaNQuGrO4fzQ+xAuLpUXlIOBt2EasKJQ8o4O0HJ/7QaBB0bbPM
X2xvDVJWPqHqf+DAuFXNlRN91iCHLPY/uXQXXPvc7MuJX20AN0bFetizC76+
aKmq52NAmkvzNG7lQY1uEv6B7Kzcw3ZAbiK/0PQgCxeVxnghi4W1AxQBBgIO
zZcmIC/hBi1JRmY39r5/ggwMRanusRi4F6BUXG7jwXMRNvTGOAzoKpOW7bzF
g9myGUYHsqOkjr4fmd/xitWL3FX6jpWJvN6zKdo6HgMZobHH6pHbySHSFOS4
iO91tmoe1LeVja8/iIG6Q/yS18jPx0VzTOTiC3L5gts8SDjzF0YjN5u+US9D
LpRtdJIiw9SEES4y7eBT7gTypUdprJvIZhW391okYCCypmW/FnlEJ4+lIQf9
NiscQb65QyjhITeKjsudCB68IIw6FY/s6HpfvQU5VxlQfhxZhVnoQpHj+t2r
ziInuwaPJCFz/v8ztGup8UnkfwG9plUf
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-4.605169998021961, -70.99273766715956},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{{-4.605170185988091, -2.3025850929940455`, 0, 
         2.302585092994046, 
         4.605170185988092, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.995732273553991, -2.8134107167600364`, \
-2.659260036932778, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.6931471805599453, -0.5108256237659905, -0.3566749439387323, \
-0.2231435513142097, -0.10536051565782628`, 0.6931471805599453, 
         1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
         1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
         2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
         3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
         4.248495242049359, 4.382026634673881, 4.499809670330265}, Automatic},
      
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{-4.605169998021961, 
       4.605169998021962}, {-70.99273766715956, 62.74085297733571}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwl2Hk4Vd33APDIPF6SojdlqLwZQlGpnEOSDFFU0rnmc1GmIiLJlJQmUyHR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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-4.605169998021961, -177.9827565689206},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{{-4.605170185988091, -2.3025850929940455`, 0, 
         2.302585092994046, 
         4.605170185988092, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.995732273553991, -2.8134107167600364`, \
-2.659260036932778, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.6931471805599453, -0.5108256237659905, -0.3566749439387323, \
-0.2231435513142097, -0.10536051565782628`, 0.6931471805599453, 
         1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
         1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
         2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
         3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
         4.248495242049359, 4.382026634673881, 4.499809670330265}, Automatic},
      
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{-4.605169998021961, 
       4.605169998021962}, {-177.9827565689206, -112.78762653520842`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{416.8000000000002, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.449705968703125*^9, 3.449706006203125*^9}, {
   3.44970609525*^9, 3.449706102265625*^9}, 3.4497061396875*^9, 
   3.4501367800142665`*^9, 3.450186561539875*^9, 3.450189018039875*^9, 
   3.450293666484375*^9, 3.450455276946125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sum of Detector and Bias chain", "Subsection",
 CellChangeTimes->{{3.44945162678125*^9, 3.449451643796875*^9}, {
  3.449497639374125*^9, 3.449497642436625*^9}, {3.44951326432725*^9, 
  3.44951326488975*^9}, {3.449513755624125*^9, 3.449513761217875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"detnoise", "[", "3", "]"}], "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"detnoise", "[", "0", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"detnoise", "[", "1", "]"}], "2"]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"detnoisebias", "[", 
    RowBox[{"3", ",", "ib_"}], "]"}], "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"detnoisebias", "[", 
       RowBox[{"0", ",", "ib"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"detnoisebias", "[", 
       RowBox[{"1", ",", "ib"}], "]"}], "2"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.44951377995225*^9, 3.449513856671*^9}, {
  3.44951388938975*^9, 3.44951391157725*^9}, {3.449514073999125*^9, 
  3.4495140787335*^9}, {3.4496890460625*^9, 3.449689056734375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"3", ",", "1*^-5"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"3", ",", "1*^-4"}], "]"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"detnoisebias", "[", 
           RowBox[{"3", ",", "1*^-3"}], "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "50"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV02k4lVsbB3DPY9vHnGTMmJ5n79KrIh0y1F+GKDITlSLkRNHESYqiSS9v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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV0n00lHkUwPGZZ6ZZE4sm2ZH1NmZMdVpRaRXrd4VFGqxkdresVGatl0ph
ymabQybKisrpXXo5yZJT0arNwealsdSScJoS4kxjlGGiLc8z7O/54557Puf+
8/3jOm3fHRFHMBiMUDz0LuvQP7udSIAwNFE2VsCGneOlPRkpBAhsy08vy2eD
o2VEr5+cgH26ba8S8thwblNNX08WAYEvZeXj2WwoUO9XfzpLQESAmYB1gA3p
Wuagr4qA6htMImYHGwLYVmNdQhbcqc5v6vdkw7CXJ9PQz4KVooH+bg0LLNsH
tVG754Fha8mNeF8WSCYHggUaDlir/hpvqiGg0L3g+MnNJhA5/rTy2BoCmoou
FC4d4cLH+bktVfeZwMljmrp8bwpZJRN+D8OYsK60FQLHzMAy/4ryxRsGpHat
22IuN4dwhuuQdz4D6s/O03tpLUAanyc9iBhAAd8hsM4S7i+77+Ojm0OXGT9k
O8sXQN9ypbR71xwKlkw+j3DlwRGt7lcBaw6Nlq8tsJrmQa14ymro/CxaEPHV
obyqhdBqnJBaB84i9/ldjwvlViD7JZa7/4MRRYZ1mI95LwLevkctittGNDew
N//j1CJAGZkXvQ4Y0VVF289n6qwhwT50bsLPiJ4ktR8aS/8C6qNmhk/zjcgQ
nzndCXzYLnCoqNFTyMagjOZ+ZgN13HTrtx0UUrV6EdMNNiDiPrh3+RaFdleU
svflLoYT5UXqkWIKlby45XfNzxYmDHy1s4JCnWf4aUtIW1DwR98kJVNoJs6N
jR5+CbqWRmn5FgpV/vb+X5ODdtDz7r9lYgmFpGWyTzsD7EG8wa1qG6IQO9p9
kZWpA4RU/hN0fBWF1v5Ulpze5AAajut79VIK1dRqiu4GOEIPq/H5SUcKWcjC
jnGvOoJuuM1Hz6fQmHrYqJx1hLv6hfUBPAo1S8MvPY51As/kvdVqUwrFZvAG
kuudYNPp1b1HOLjvWqWkTyCAPU+qnu9g4p60Cz+eUwhAqvg6ydZIIg+ze4PK
lwKQMbmGyE8ksqioKPYGZ3Bq2PXn9WkS3dRPaUMuOkPeh1j/AgOJgrytE4WE
ENI9nhXn6Em0M2yHzCVOCO3+z/Y8fUsifxMOI+tvIeSmHWzM1pHIsU2hui4S
4T87p1mlJVHjiu9WiLJFYGJZGLRCQ6KhrRKLx69EEDHkfn7jCInmipzsfda7
QKpt3sPQ1/ieFNJucskFmoavxKQMkqghTFJ2gSWG371Uize/ItGdBN+bN7C1
vbV9kdjXcjyqa7C7qq+fon30gV1DBzZvZZY57SjxeC+FXenjRmzCfjdbwIlm
i8HlWPxoOLZtVWec3TwxLM8Nrt2Ibd7WnLgU29/TKZU2Y+Reigc2d8lHN9oa
m8uZEuzY1qt/hNA9OSnFmdhl1OTFDdjB0byWfuyo9QmHg7C993PaR7F9NR6+
tF1PznROY+tUjNlAbKu21y8/54hhzYZTctqDq6unvsHme91J+Ba7O6xsJhg7
qFsupt2acJ4RhV1X7j0SgF1Zmm22C9tjQXM07UsP5LwMbLsrysW0T/Qm8pXY
ZilBff7Yhydj7E9gT2dyT9GWm0UKS7AfqdrCaf8PXiRAHA==
        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwVzns4lAkbx/GnmTFGTqUhUjLOFKlWkex9U1YSI6RUbJNDW06v0yhRqKXo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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 0.}, {2.302585092994046, 0.}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {0, 
         Log[2], 
         Log[5], 
         Log[10], 
         Log[20], 
         Log[50], 
         Log[100], 
         Log[200], 
         Log[500], 1.0986122886681098`, 1.3862943611198906`, 
         1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
         2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982}}, {{
        2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
        0, 0.6931471805599453, 1.6094379124341003`, 2.302585092994046, 
         2.995732273553991, 3.912023005428146, 4.605170185988092, 
         5.298317366548036, 6.214608098422191, 1.0986122886681098`, 
         1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 3.4011973816621555`, 
         3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
         4.382026634673881, 4.499809670330265, 5.703782474656201, 
         5.991464547107982}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {0., 3.912023005428146}}, {{2.302585092994046, 
       11.512925464970229`}, {0., 3.912023005428146}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0, 
         FormBox["1", TraditionalForm]}, {
         NCache[
          Log[2], 0.6931471805599453], 
         FormBox["2", TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox["5", TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1,
          0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.4495140942335*^9, 3.449514175686625*^9}, 
   3.449519367046*^9, 3.449519413217875*^9, 3.4495453775265713`*^9, 
   3.4495460155890713`*^9, 3.449579014150875*^9, 3.449579232729*^9, {
   3.44957934851025*^9, 3.449579369775875*^9}, 3.449579460025875*^9, 
   3.4495796989165*^9, 3.449581383244625*^9, 3.44958293296875*^9, 
   3.449593389515625*^9, 3.44959937925*^9, 3.44960393596875*^9, 
   3.44961585371875*^9, 3.449617592125*^9, {3.449689048796875*^9, 
   3.449689111515625*^9}, 3.44968929825*^9, 3.44968937415625*^9, 
   3.44968949053125*^9, 3.449689580234375*^9, 3.4496896316875*^9, 
   3.44968976634375*^9, 3.44969085309375*^9, 3.449691448796875*^9, 
   3.44969170915625*^9, 3.4496922799375*^9, {3.449692435234375*^9, 
   3.449692443390625*^9}, 3.4496924905625*^9, 3.449692702859375*^9, 
   3.449692743015625*^9, 3.449692820078125*^9, 3.44969301628125*^9, 
   3.449705982734375*^9, 3.4501367820767665`*^9, 3.450186562352375*^9, 
   3.450189018758625*^9, 3.4502936669375*^9, 3.450455277664875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instrumentation Amp", "Subsubtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "1", "]"}], "=", 
   RowBox[{"par", "[", 
    RowBox[{"1000", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "150*^-12"}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "1", "]"}], "=", "110"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"half", " ", "middle", " ", "resistor"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"opamp", "[", "1", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"z1", "[", "1", "]"}], 
       RowBox[{"z2", "[", "1", "]"}]]}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], ";"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"differential", " ", "gain"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", 
    RowBox[{"1", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           SuperscriptBox["en", "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"in", " ", 
             RowBox[{"Abs", "[", "zdet", "]"}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"in", " ", 
             RowBox[{"Abs", "[", "zbias", "]"}]}], ")"}], "2"], "+", 
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"in", " ", 
              RowBox[{"Abs", "[", 
               RowBox[{"par", "[", 
                RowBox[{
                 RowBox[{"z1", "[", "1", "]"}], ",", 
                 RowBox[{"z2", "[", "1", "]"}]}], "]"}], "]"}]}], ")"}], 
            "2"]}], "+", 
          RowBox[{"2", "FourKT", " ", 
           RowBox[{"Abs", "[", " ", 
            RowBox[{"par", "[", 
             RowBox[{
              RowBox[{"z1", "[", "1", "]"}], ",", 
              RowBox[{"z2", "[", "1", "]"}]}], "]"}], "]"}], 
           RowBox[{"Abs", "[", 
            FractionBox["1", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"z1", "[", "1", "]"}], 
               RowBox[{"2", 
                RowBox[{"z2", "[", "1", "]"}]}]]}]], "]"}]}]}], ")"}]}], "/.",
        
       RowBox[{"{", 
        RowBox[{"ibias", "\[Rule]", "ib"}], "}"}]}], "/.", "detParam"}], "/.",
      
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"opampnoise", "[", 
      RowBox[{"1", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"totalnoise", "[", 
    RowBox[{"1", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"opamp", "[", "1", "]"}], "]"}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"opampnoise", "[", 
         RowBox[{"1", ",", "ib"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"detnoisebias", "[", 
         RowBox[{"3", ",", "ib"}], "]"}], "2"]}]]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"totalnoise", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"totalnoise", "[", 
      RowBox[{"1", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"totalnoise", "[", 
   RowBox[{"1", ",", "1*^-4"}], "]"}], "/.", 
  RowBox[{"f", "\[Rule]", "1000"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"opamp", "[", "1", "]"}], "]"}], 
   RowBox[{"opampnoise", "[", 
    RowBox[{"1", ",", "1*^-4"}], "]"}]}], "/.", 
  RowBox[{"f", "\[Rule]", "1000"}]}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.4495463302296968`*^9, 3.4495463473390713`*^9}, 3.449593379609375*^9}],

Cell[BoxData["6.581453682182118`*^-8"], "Output",
 CellChangeTimes->{{3.449519205280375*^9, 3.449519266671*^9}, {
   3.449519297374125*^9, 3.449519326124125*^9}, 3.44951938482725*^9, 
   3.4495194157335*^9, 3.449519481749125*^9, 3.4495195336085*^9, {
   3.449519573967875*^9, 3.449519593311625*^9}, 3.449519712499125*^9, {
   3.449519760217875*^9, 3.44951978476475*^9}, {3.44951996495225*^9, 
   3.449520069061625*^9}, 3.4495211617335*^9, 3.4495453776203213`*^9, 
   3.4495460156984468`*^9, {3.4495463314484468`*^9, 3.4495463482765713`*^9}, 
   3.4495793836665*^9, 3.4495794619165*^9, 3.449579699025875*^9, 
   3.449581383354*^9, 3.449582933109375*^9, 3.449593389640625*^9, 
   3.449599379359375*^9, 3.4496039360625*^9, 3.449689490671875*^9, 
   3.449689580328125*^9, 3.449689631796875*^9, 3.4496897664375*^9, 
   3.449691448890625*^9, 3.449692443515625*^9, 3.44969249065625*^9, 
   3.449692743109375*^9, 3.44969282021875*^9, 3.449693016421875*^9, 
   3.44970598284375*^9, 3.4501367825298915`*^9, 3.4501865625555*^9, 
   3.450189018946125*^9, 3.4502936670625*^9, 3.450455277821125*^9}],

Cell[BoxData["2.7551319142562374`*^-8"], "Output",
 CellChangeTimes->{{3.449519205280375*^9, 3.449519266671*^9}, {
   3.449519297374125*^9, 3.449519326124125*^9}, 3.44951938482725*^9, 
   3.4495194157335*^9, 3.449519481749125*^9, 3.4495195336085*^9, {
   3.449519573967875*^9, 3.449519593311625*^9}, 3.449519712499125*^9, {
   3.449519760217875*^9, 3.44951978476475*^9}, {3.44951996495225*^9, 
   3.449520069061625*^9}, 3.4495211617335*^9, 3.4495453776203213`*^9, 
   3.4495460156984468`*^9, {3.4495463314484468`*^9, 3.4495463482765713`*^9}, 
   3.4495793836665*^9, 3.4495794619165*^9, 3.449579699025875*^9, 
   3.449581383354*^9, 3.449582933109375*^9, 3.449593389640625*^9, 
   3.449599379359375*^9, 3.4496039360625*^9, 3.449689490671875*^9, 
   3.449689580328125*^9, 3.449689631796875*^9, 3.4496897664375*^9, 
   3.449691448890625*^9, 3.449692443515625*^9, 3.44969249065625*^9, 
   3.449692743109375*^9, 3.44969282021875*^9, 3.449693016421875*^9, 
   3.44970598284375*^9, 3.4501367825298915`*^9, 3.4501865625555*^9, 
   3.450189018946125*^9, 3.4502936670625*^9, 3.450455277821125*^9}]
}, Open  ]],

Cell["\<\
The noise of the OpAmp is dominated by the current noise through the source \
impedance for bias currents smaller than 100\[Mu]A.\
\>", "Text",
 CellChangeTimes->{{3.449519205280375*^9, 3.449519266671*^9}, {
   3.449519297374125*^9, 3.449519326124125*^9}, 3.44951938482725*^9, 
   3.4495194157335*^9, 3.449519481749125*^9, 3.4495195336085*^9, {
   3.449519573967875*^9, 3.449519593311625*^9}, 3.449519712499125*^9, {
   3.449519760217875*^9, 3.449519765155375*^9}, {3.449520239749125*^9, 
   3.449520299624125*^9}, {3.4495203368585*^9, 3.449520341749125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"opampnoise", "[", 
          RowBox[{"1", ",", "1*^-5"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"opampnoise", "[", 
          RowBox[{"1", ",", "1*^-4"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"opampnoise", "[", 
          RowBox[{"1", ",", "1*^-3"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "50"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520317342875*^9, 
   3.44952032938975*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xs8VNsXAPAzg8mrCQ15DuacM0gRReXRWUVFuISUFCUkehDRT14hlQrJ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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk41M8fAPB15iaEXdbufnZRCukSXzXvDkqSkiSSIyKUyLpCIooKOSoq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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwd1Hc8Vf8fB3BJZWWLa93h3qMi0viG8HmHUMhIJZGKIqkko4yU0BJJthBK
ZaRIKqWs7FVR9kpK914ZDRm/z/n9dR7Pxznn/Vnv14d+6KTNYV4eHp5Di3h4
yGd2A/fD42O88OD4k7+DGxeQCyf9o/8pXlgfN8aH1BcQTcym3dCPF8SsfnTc
JhZQ0s6ijo8hvFBjX/fJWWYBRXae6fybyAuvnK47iv+dR76ji/q31PBCaHk9
dbJ0Hm3lkxprZS6GJXvCfn40nkdDm7UWTfQsBmM7Q/M1znNIrL5/dPfJJfDP
nZi/mfIPWfzs28YYWQoHvvd+WsKYQTc0I6NidvHDL975uq8f/6CK6JQbq4YF
YDxM1dTw1m+09MoiIcJOCLp0PtXwXv6FdNKrwWRMGJprN9wQC51G3q06+0T8
RCBUkLK2On0KvU5cwt08KgrvZm4u8xiaRLMgSzUpFQN58ZMGdWqT6A7P3ovK
fuKwa1OS6p/YCbTN4udnG3UJcL4reIkhOYG+PdCOlJqWgIt6hj2P434icZs1
wVfyJSFBVPBtvOZPpCnY2njDTwrO7O0rq24bR7aWDSJjutKw48jCEfGL42ih
zyviz5Q0rKZMaFkbjqPM87WuCaUr4Irekb07+cdRk0d98JivDGjsThzQLOSi
1xsypCX9ZaDymDXvq8dc9Gj2TI5OkAwcn9q5clsBF92IIDquXJQBQ4GiCy55
XGSTe0F95Q0Z2KJmbZedzUUdY5t6XB7IQO8iDwHHFC7qd8/S6e2SgftnvqqF
hnPRhFvQdAvIQmzIa3aaIxetiFLs+GYoC4+UDxsfd+CizU9flfCayMKIz2rf
zfu4KHTRfMAGC1noHvlp12nHRTJJ53gT9spCn222AsOWi3Trg0WdvGTh6m5F
lc/buSh8TcgqdqYsDF6gPBjQ4iLKRLijwDIKWNyh6oEMF3lUUYTZAhQ4vvhC
lNUKvN6E3BctwhSIyLa4cFCai1xQm0yCBAX6ezO3hElyUX6EYhuhRAG9jNzV
H0S5yEilyNhoIwVuT4htj+LnIk+HAY1gZwoszuESZ2Y4qKZ6M+90GQXS7Iq0
efo5yN5+68yKCvz/pdIAZh8Hsdk7JrSqKWC1e8v+bb0cJCF9aDCwgQIrPggv
ju3mIEfny+V8nynQ9KWhbP1nDppY+BAiNUEB95Ha7Mg2DlLQPrF4A1MOPPmp
Fs+qOOhkTjrf6ctysGraM+pVHget/ZFS63RNDk45/fdZAntcLTHSPFIOBGMq
E9xyOcgrP1qWuCUHMnSBM9I5HOT9OETtc5ocrBvszve+z0H+z1xs0TM5mJ2J
eGmayUHhFSuzhEbwe5Nq062JHJTaVWCYZSgPzk/p/ufDOSjG39c2xFge9Ku9
qifDOOgyRffwgW3y8OVFi5cr9qk978IVLOVhXd3z75ahHGT0vqf2lr08NNf4
WLFCOOh7naBV2Cl5MGh9+mogiIM2vXBxOJImDz8CcvzSfDioJUHWZ+U/edCZ
LEqlH+Egvj+2zUbz8pDudlLkzmEO0t4TvergIgWYGVnRS8POkBbsTVymAEnu
cil0Fw7yufnPWEhKARysAq6pHOIguYheWY6aAhxo95412s9Bh4OzSgv3K4DB
qqbdlbs5aObwWj5UrgDVyct+VZvi8/ByUiWqFMBoo2KgM/abc5E2y2sU4NLg
hAkPdlj8j/SuRgV4c5ZeoGPCQWK19/XOfFYAM5brqydbOYhQo/s9HleAkbut
GY8MOGjnhPh3ZaoiyHgt29uly0G55yab+QMVQTnIsnlck4MszRJBPVgRzjDW
ucVhT8igxztDFOGDBctYF3vT46s3Uy8rwlN1z5bLazmofIi+a0OsImwq5qOw
NDiow9Sq0ylfEf5a8u5wV+MgXsm84eJ+RXj+xJTNUuGgPdlH/rpsVYKmiK3p
exQ5SL3t49MAUyVwIFL3iWDzzRl53TRTAuKRxo4qBQ56YqM8VmatBIO8+z6t
xxae7+uW268EZ+RdAyXl8fi2e9+0+CpB1G/b/m5ZXI/X/JLufSV4t0tnSbwU
rueoKS0lRAVuGVxJF+YggY0xqdPLqaCqzPztii2yfFqlQ4wKSuzpCA1smVcl
OkkrqHBq7S+NMiEOWq0IB2gMKmR3uFr1C3KQdc+OHDVtKgxc0h9aJYD70dFj
y1ZXKjRye2M/L8H9sD/7uG8FFdSiTaPvLrDRuV/BEFdNBaG0jWu8sMsj7SSL
a6lQeDd+XB/bvEzg+XQzFa75G7I/zbPRfpoHn083FaZF516IYIcOrk0+PU2F
/ZK7Ii/MspHbekeXEkkaBEh3mV38y0ZFz0ain26lQdyde9Sfk2x0wr5hYLUJ
DbTmtSNqsVXmHmumm9LgkAZIZ2AnGQS1XjWjwd/jtoE7sc83SoofsKbBlTn3
lGcTbGQ2BDcEHWkg+mRCIuwnGw2KJEc6edPA/rqJ9QYuG4kesbwmkEmDJcsE
5/q+4/fPKBf8smiwT9s1rgy7WGDY98tdGhyVzDZOw3bIO3Po7X0ahI1Eju3H
fjh1R/tsPg2CLhhs7fvGRsYXp76OPqdBQs2Z1cOjbBSUnmhU00KDbpXtVvMj
bDTWOTQXPk+D0A+JDZ5DbNQbcVRWiocOO3SX792J3abPXXdnER1MqEqzG7FL
MmZcX/LR4W7++7B/g2wU7i7exhWkwweVgruXsBkz+vfsZOhg0HmUP2uAjewo
STtWr6XDUOD2kR99bFS5xyqt8SAd8rOyI192s9GOA5Y0cKbDOVvJoSzsz247
7jxxoYPRryqTSGzOWfPMeFc6XPrUuuUgtmyKafbB43QodDD4vQz7WD88mj5D
B41fNx3tuthI4qhmmeINOqyZ/FXL18lGB/0l+o6/psPmYtn6Kx1sJDzUELpQ
RocpX3MjH+xis0uro9/S4RFPSOMBbEHFWZ+iSjoo0d+KamEXlX0R/ldHB/kw
LZuv7WzEv+S5zuUOOixT8Ko0xc6PcorLGKfDb09CSOYjG81k5Vp0MBgQYued
3dvGRrou/Xt3MBlgFHNtqAk7SFnqSBWLAVqhLNUybJ6MgHOFKxng6vWmOw17
adr2R1HqDPBdn1tzEFs8cVTMVIcBNFfd0q+tbLTyOvNDiTUDJOIDOv+1sNEe
nxT7pPMM8E/9amLYzEZPhoqEBUMYwLCccPsPW8Sm8fXZiwxo3Ls5ZhV2pfo8
Y284A6zCTiwWw1436jQmE8GAntNZ1j1N+Pt9yoGx8Qyo7nmWdha7Gh7evpHP
gJ2LittLGtloo3BJf3g3A1Jy9x2wamCjgs5rz6R7GXCgafaZEbbaA6fIrD4G
VCW/ktXGZhgv0y0fZIBKasg0HVvs/O74uVEGnN1oLz9Vz0Y/JqcsvKcZIL3O
WiIJO6NL8+VBEWXw7Fkc/KMO5yEnJ1YXlCHoeM7PB7W4XsuftoItypD2w2vR
HewN01vFWIbKkMvTIpOAbYf6ry43VgbbGC27cOyM91Lne82UIb7TUMUZ+7/Z
IPfze5Th5UqbGUXs/RZWqPKEMuR4Be5KqGGjPO7UqNltZZAI9p9KfcdG/d5z
2/tSlcHYjzMahy0xsyTPK10Z5OaHhiKxfflkTiVmKkPvLWCfwwaK9t+RB8qQ
1atj4YT9wSBIIKRYGRhWFH069kzsktUlzcrQOXm+4kE1G5nqrjjG5GXChU2b
3Buq2OiW5+LTBYuZ8CjNf6YKeyBr3F93CROW5M5ElWH7L6+/asuPv7fIqHuC
ndsb/DBUhAmZz1XPJWKLXvj2bViOCd5XJLpcsdurSt3urmfC6F8dW35sF0vn
I8RhJixzU4jaU4nH76z9EH+ECVIrpfNtsFUPrzUUcGOCZNP3FgvsCf856g93
Jtx9o8wwwj5/L/7zY08mCPhcn1iLnTJXb64XyITrvtbbhLA/5GxYbxvDhB7j
O2XlFWxkxL+UJ+QtE9hidCddbNNJlRiJCiaUV1iIamGb9W4jMiuZwJHzrFiP
bVN03bzyHRMSqNc3qWIfOCCduLSJCQYS7B1y2AElzHXXOpnQ6Xxa62857nc3
Q5dbk7j+tqLR59jFOw//Zk4zIeh+tmQx9nP9S1ef/mLCRba1wRPsN1L1Be1/
mWDNqnz4ELvpjc2cLA8L0AdOdjL2N9lDcbeFWXCkZsj6HDat9nzNPRYLTBqJ
vcbYLwQVyhVUWJB4gtA0xN5l/uzlzZUsKNTdJAzYV5vZ+edUWTD081K9NvbU
R/vY3Zos+GX27sQa7JrBDYeW6rHg9eo2Y2lsz9nRf4dtWbCoTO+/r2/x/aMf
Ot21iwWT0R4nhrHvBlO51ntYkNRz/cEAdifv7kE9exacLMha2Y1tJFBRI32A
Bc8ilm9vxZZdcTu26hiefwNBKcV+o2GtwbrIAoWKD0Mx2N601qaYUBZ06SuE
RWOvErc+wRvOghhF1qoo7JsTVnl9l1lwA509exXb5amValIkCw4aUjdfwObf
bKUimsSC7N9CBiexrYwtqX8LWPDOfrODBTbfpubXrk9Y8OnP4l1m2M9VLPe3
F7LAoTDUahs2Q8DydmExC/j58i23Yk/V75A/UcqC/t23T+hhJ1jvkBl6x4K7
5QPq6tgDDhaijb0sGCxc/Vwcuzjv8nv7fhZ8d7IbFsW+Ol8RPzrAgj8aLyVE
sNel69D4vrAg5Tj9rCB26JCK5uYxFozdPuuxGHulO+/OB79ZkGFfwJ5+w0az
L/RkNv1lgUayg/kUdqvQ2a7KGRaI3jPKn8D2z+M698+xQNyuLoCL3TDe7S3D
R8CmhlK9b9iefs/iwsQIcDRpdezBNqqZsJeUIGCbc/h4FzaFok69I0nA+s0h
4Z3Y5S+ysktXEPDHz7q0A1tqPrpkUoGAhFtHLNuwS0I9Og+uImCthL5UDXbE
x+xU7mo83nhDVzX2QWLoUJAaARKCT+5VYQvW7B1L0CDgjt9F4wpsByGT2eaN
BIT8cc5/jb0QTVfSNyAg860mrRjbXbvd9LEhAZ8Uh9WfYrf3Xz3N3ErAoe9R
UISdrzFVI2hKwEToJ48nZL3G6tMdFgQUelp+y8eu8Q5I3W6J5z/MESW9XmFt
7SsrAhqio7XzyPkcS1TK2klAVNWX2BxyPfwetZ578XwbOV73sZkFtKkhewLU
6Y2Ps7Gj9nxU2uNAwL6zzyfvYR+5p++t50SA9/e35++S+2MkThU8TEBTzouy
DHK/g4u9Mz3x+mLS225jdxPH0lZ4EUBnShqSNmmi1l05TYBlYG5xCraS4hWq
py8BGRb22cnk+b3YV6cbSEDfn7b8RGytQ2LTj4II8FfN1SKdKVBFVQ4mQH7t
i6oE8vzt1H0EQgioEwr8Fo+98hcPrf0SXm9C/Z447Fu3n27fdoUA43fB/2LJ
/TZy9ym9SkDAjF8G6faY93UZ1/H4h3RnbmEbbL48LR1FwNHbwjmk8wZ1aVdu
EJA8utKJdKjmPZ+TMQSc/GnRGoM9/sk+ffAWAcNd9lGk950Xrd8VR0Dw2lIr
0tUqldM18QTwSXhLk17XfIamm0iA3v3QnpvYqb5rzB4lEcChjt8nLag06MNI
wfUelviRHvAwq+dPI0Cp6yiVtIf3S7nkdAKs/ts0HY39J0DVfU0GAfYzvM2k
L15Mfl6WScBPyZZc0iLXhARs7hLww/dOJOmkmwF2w/cIsFDy9ybNShrL9r2P
8yDsuJ90wZ19v/kfErBnu4U5ad0H9cbJOTgf3yz0SdcUbI5bk4fnx3NoA+md
JTlfyvIJaCmIUCfdWya/0aaAgDJqqxpp93fXQocfEzAYsE6D9K+mf+99CwkY
mincSPpC+zFlgae43mc7IC3c2+WVXExAnCPTknTCF7PyNSUEbGyjHCLNZL8U
f/Mc5+ma7lnSj6ZUD9q8xPP9EnWLtM5scsFwKQGhBjJFpKsXC/P4vcb9LdLe
QdpGKNBS4A0B9140L5DukfiRmvyWgBfly9TI/XWTc+CsqcB5v3/BgfQUvUHv
TSUBrr8gmvT5VbrXbapxP+lvqyMtpJnbPfwO518udRl5vgyICBCoJ+CGku7/
+yHfZLYuuQHnKTPiM2ltSw859SYC3L21VpL9ZLXf/LlNK16PyOM20t2HS/m/
tBFA8QlTJ/vT9biand8HApBzZSTpc4HCv5M7CGj3iHYg+1swNNBY/TMBB91U
6kjHXvsR+6aTgJ6cTbpkHnKTGjZ86SFgQaVjDZkXrQzdUL8+fF+EnsgjXfEg
973AAAHRp25okvnqLInwUh8mgJsRapKEzd9hXuD3nQCVgayHZF5v9ZYuCPzA
eVhYaknmmTqiZpnCJuDZgPQf0v9NC3PejBNwusjMLg3bRbJRVfA3AZVjsdbk
/TAupxeQ8ocAH+iWz8QOYOTVqc8QcLtp8jvpm5rXj+6cI2DdxQfx5P1SZmmR
nbJYBcQ/PlV9gP3EfUvefeyF9s/rSGeFbSwsws6emdcmffWlYlkD9u5sc1PS
u1U47bPYIvHTLqTZ85FLHflU4FpHUCpp+fyWw4pLVKCF4ibxkMxLbeWxVdhG
LgUU0jzDJac2Yl9r/UsjPUK5E2SB/UzqhgbpJ2GnYoOww/XrzElvc5So6sFO
UPG5RFr3zNL6b9gemc2RpNVjZlqmsVMMVONIS9UOdi9fiscb+5JFun9D4ZQe
dtqIWznp95bZM9uwj55rqCVd7Z7Msxu7S1uzlXRu+kXhE9jt8vN9pNNe+kn4
Y3sZHPlK+mb7Mdlw7E8RzRzSoT+dlG5ii//T/kXaT9iWmYrNuH53jvT/AGQ1
ojw=
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 0.}, {2.302585092994046, 0.}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {0, 
         Log[2], 
         Log[5], 
         Log[10], 
         Log[20], 
         Log[50], 
         Log[100], 
         Log[200], 
         Log[500], 1.0986122886681098`, 1.3862943611198906`, 
         1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
         2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982}}, {{
        2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
        0, 0.6931471805599453, 1.6094379124341003`, 2.302585092994046, 
         2.995732273553991, 3.912023005428146, 4.605170185988092, 
         5.298317366548036, 6.214608098422191, 1.0986122886681098`, 
         1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 3.4011973816621555`, 
         3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
         4.382026634673881, 4.499809670330265, 5.703782474656201, 
         5.991464547107982}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {0., 3.912023005428146}}, {{2.302585092994046, 
       11.512925464970229`}, {0., 3.912023005428146}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0, 
         FormBox["1", TraditionalForm]}, {
         NCache[
          Log[2], 0.6931471805599453], 
         FormBox["2", TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox["5", TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {Left, Bottom}, 
    {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1,
          0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.449520324155375*^9, 3.449520331124125*^9}, 
   3.4495453782765713`*^9, 3.4495460163546968`*^9, {3.4495463348390713`*^9, 
   3.4495463529171968`*^9}, 3.44957938763525*^9, 3.44957946463525*^9, 
   3.44957969969775*^9, 3.449581384025875*^9, 3.449582933828125*^9, 
   3.449593390640625*^9, 3.449599380125*^9, 3.44960393696875*^9, 
   3.449689491421875*^9, 3.4496895815*^9, 3.449689632484375*^9, 
   3.44968976715625*^9, 3.4496914496875*^9, 3.449692444265625*^9, 
   3.449692491359375*^9, 3.4496927438125*^9, 3.449692820984375*^9, 
   3.449693017328125*^9, 3.44970598378125*^9, 3.4501367832486415`*^9, 
   3.450186563664875*^9, 3.45018902002425*^9, 3.450293667734375*^9, 
   3.450455278883625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"1", ",", "1*^-5"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"1", ",", "1*^-4"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"1", ",", "1*^-3"}], "]"}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{"opamp", "[", "1", "]"}], "]"}], 
         RowBox[{"opampnoise", "[", 
          RowBox[{"1", ",", "1*^-4"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"10", ",", "500"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<OpAmp 100\[Mu]A bias\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520365921*^9, 
   3.44952038451475*^9}, 3.449520934030375*^9}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hk4VWkcB3DZhizpnouLZLnnXCJJpc32LVGyi5QpyVxlEFeEkaJIUUmE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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVz3s81PkaB3DGJYzLb8aYDMm4/H7D2pTKtsXWx604mReprZNLe7TUhqIl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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV03k8lWkUB3CuJbvXDffKrvd9qSYRpnDVKVoMkpttuCqFylIibrQQEiqR
JPuSyESbSNkKhVCZKYpkb+jWNEUZTcyc+8fzeT7fz/k8v3POH4/urgNcX4aI
iMh1PMK7tPPTi1sBDPCP6F+V2MwEn78KXkYeZEDhvhefxh4yQYfg9ljzGbB6
dLhl3QMmZG270/syhgELZPxa5uuYkNx3uG82kwGxFmJy8dVMCJ8QHVrXxoCp
z/uc2suYsEFcWdBNikGmmbiWdioTRi1Xi34ZEIMX2VLWE7sw/23PhVVjYlAV
VrxrnzcTeNFhBsfei4GN5NMSwQ4m9LTcdpSaEQPz1oTMKR4T2hyW52kR4lBX
Vquk5MaE6zv0LO3Wi4OMyuSFE3ZMiIyVCysuEQfPD50sEzMmEB1DE64HJAD4
pFeZLBPKWn1UV4ZJwJVtZxbEyDBhfcuEtfwRCaiJG4nxlGbCofq/85rjJeCb
aM0ksYAJr26IuBjlScBRo998TzKYkH9B56F0lwRoOTXGXZhVAsPtOzPrlkrC
vku3hjdOKIHD50FbvXeSsNn9ge/rViVIMU4+l+YiBc+vhFs3nlOC5tSclCVj
0hAzv9bcgacEkomisrS7LER9sKw8aaIEFgWPYZNADow6T02+kleCQ90Wngp8
BTj+p5Xfnr8IaMiU+GQ5oQihksXRti8J+AFs7U11BNQ6swrn6wkoFPk1djFf
CQjRqqSQawTYOnx+zTVkwuwRrmh/NgGTZebJyl+ZwDF1vXrwLAFK3OVRidcX
gu3vHeslYwgwlunuSuErg7+lWUEinwBnx04FAUcF9AayfxraT8B/gyFn/plW
gRHzWw3Sewm4HN2+51KdKox3qfEeeRPwNLAjShDOggiVLfweHs5rWqSyMJIF
TQs//96EvvHj8DWLYyzQ083g3ECnnKF7E2NZ0D/aYp6A5pafMDRIYcGH7rQ+
C3SvYNWATxkLmCORFUWeBAz5F1u87WdBYliWy1EPAr7sPfb1ObDh3t9T5S7u
BKie0+ydtGaDj/Hc6Q1oy6r6GsYmNnzudgk3Q8eJzh8xdWDDnfMvA1XQrKzj
jEu/smHd65VDL90I4HREKe4IYYNDZ9prd3T88pglHy+zwW+SP+znSoDal3gv
6QVqsPZO2G+FzgS0PbZkfG1Ug9wTKry7TgQcuFYgHpqwCDJDlv4h50hAXv9N
62JrdVh7Ir11yp6A55fYYQb/qsOEzWl/UzsCvvsaia9t0oCh+sGmTFsCyo9P
PZM6qglbfNtyXDYT4FbqN+uzQQsSaMbGnzYRIO5lrKIsqw3VCaFLf95IgPn2
0qDwZm1wDF32PmQDAXfuvkut2qADr6bSzzXYEKDo53ha+rIOfDepnTNEC/pG
5+LndYBF+jZXWRPQ4rY1v8tbF1aE2CXaoL0jmYNBDbpwWuWs+eR6nK+43KFX
Tw8e8pJk09BuYTkeWdF64K++2toebSZXMxT/Rg8S6/vG5dGK166lc2AxnNrt
+OrZOgIqPk1P2OUuBjH1XwSX0Js5qgEkg4RR09Z6L7SP424/2peEPFYFT0dY
72t/keFHQm36qwBt9DJfI2vpvSQUf70QqYX+Ejmn/cGfBPeR2osa6OiSjNe3
gkn473VROxudM9dhb3WUBMPlL9hK6BfXTE2c00i4uCXEWRRtIyUpEvOQhG8+
rNlBwH5T+mnMZhLeBW3seIu2e2tLX24hoeJlSs4AmnvnrH1LKwkPGcGcfvTO
nSqZkk9JSBPTPdiDPlJDrjzdR4KiXnJ5J/r2XmufC1MkvB9meNWgq7f5zpBf
SciwvapwF31vzamkqm8kqJRSjVXoB8odN3tmSbgina9RiX76gDvHFqHASNuu
vQI9yd51MVeOAi9m6J9FaJ326LYSioJbCXnUGfR9GY0mDX0K5qKTHyehXezv
1p43oEAj/Ge/RHTSs4/Xjy+jQMC7UhiPnn7pke5qTIFCTqPUCXTbiOkuSSsK
AgoG08PQwT8m/vV1piBC+UuWF1pmTdzXfhcKcs/bK/DQV6K0Pzm5UbBNVSna
A93HcB2x8qDAJbFruxvaRrq5TWUnBU0dbVJOaLZqbvqjAArIUW85G+G+K5xW
ULEUfFit3mCAPqTT/TQtjoKxb8YMffQSJaf9jHjML9xnQ6HPf9laMZhAAf/5
imZdtE/V1mVZyRRs2tBctggtZblVXzGLgkF7V7YceutGR+3ZmxSsv9fm83Et
/pdVzxr23KbAjvjTT4C+p++4vaeSgs5HDX6TaD1px9zKagosDM7sGEdPd2xR
31+H7+stzAbQl5y2sEZbKcjaWx3UiR7mOSh2vcV+29P+uYqurkj4w2OIgncz
fodL0EnzzRkTwxTw8v6dvoxeWWChIz5OwXA2dywPHTeqb2wpoKDLQTv7AtrA
n7GtbIaCB4vcfaLQwfy7F08SNJi8LuNw0TZtXzwWMmlgymfZOqLV1Ay1CxfS
8NnqHNce3XS/uLROlQbWrf3uG9HK86k1Uxo0dAf/YmKBrokL7PNeQsPZpZna
uuj/UnW11qynIeN+aqFgDQH+5j2bb1nT0LZg1GsC3TOUFEpuoKFhckZlHH19
xXSbzGYavGW3RbxF87oeh/Y60PB9qbpcN7pGKrA9+FcaChVW86rQwVHVhy4H
05BaPxAeiX5DB+SrhtAQsbg0Lxy96an2k8RQGjzZbg9D0FqaidrB4TRwD9jP
+KM773s+4RzF/Lpq0hNt8E1Ep+cUDe6Hq45boIcD7Tqk8nH/Lfu+TVsREHio
dlF2AQ3S+bel/0b/c2SZ//IiGo71tqoI0AqnZaW5V2hIUDRgD6M5ZR0bs6/R
cJWKbOlEXxq3a1peQ4PAb/5mEXrrdvt73G4a8qxiYzaj3/jWSY3/TkOQyY2M
9eg9QT+581/Q4LZIuZiDPn5Ubia7l4bVRk5FRujyrE7T8QEaqmQUTdhoqV77
m/z3NNSxFmSOcwhodHQozRHTB82oBvkI9G3/dRVX0XKbvHsPo4tPmlXeQZ8t
FC0UOqlWs7ET3S1vaSq0q/5fPT/Qqx6kePDRH+eTJb3E9UEstLUkDK1+/bmv
poQ+tNl4W4WgFdpbApagc+lqSaFFxmoOmqF3Zkg9P4h+p1Z4zAHNoUp2CX37
5MH0Y2i1T82ngtG2XsxHA+gnuknd+9Gcw5Idk+iusbtZQhumfX/+Ff3edHS3
0MrtI2/kJfVh7sjKb0HoIdPKaSu0c1HlIqH/cCz9boueetI1Goh+7J8t4opu
ihovF7q8IFZuPzrirPxaofNr+cxINP1OU0ro8z0B7Hh08pNl3QHouM87tM6j
0yxWZQnNl3Mm89Csn2G30P8DIyhUww==
        "]]}, 
      {GrayLevel[0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk8VdsXAHBuiGPINeVyr3sv9x6ihFKJapUhnpkylahMzxQiUlKmhCdD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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 2.302585092994046}, {2.302585092994046, 2.302585092994046}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
         Log[10], 
         Log[20], 
         Log[50], 
         Log[100], 
         Log[200], 
         Log[500], 
         Log[1000], 
         Log[2000], 
         Log[5000], 3.4011973816621555`, 3.6888794541139363`, 4.0943445622221,
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
         5.703782474656201, 5.991464547107982, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         8.006367567650246, 8.294049640102028}}, {{2.302585092994046, 
        4.605170185988092, 6.907755278982137, 9.210340371976184, 
        11.512925464970229`, 2.995732273553991, 3.4011973816621555`, 
        3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.298317366548036, 5.703782474656201, 5.991464547107982, 
        6.214608098422191, 6.396929655216146, 6.551080335043404, 
        6.684611727667927, 6.802394763324311, 7.600902459542082, 
        8.006367567650246, 8.294049640102028, 8.517193191416238, 
        8.699514748210191, 8.85366542803745, 8.987196820661973, 
        9.104979856318357, 9.903487552536127, 10.308952660644293`, 
        10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
        11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
        2.302585092994046, 2.995732273553991, 3.912023005428146, 
        4.605170185988092, 5.298317366548036, 6.214608098422191, 
        6.907755278982137, 7.600902459542082, 8.517193191416238, 
        3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.703782474656201, 5.991464547107982, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        8.006367567650246, 8.294049640102028}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {2.302585092994046, 6.214608098422191}}, {{
       2.302585092994046, 11.512925464970229`}, {2.302585092994046, 
       6.214608098422191}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {
         NCache[
          Log[1000], 6.907755278982137], 
         FormBox["1000", TraditionalForm]}, {
         NCache[
          Log[2000], 7.600902459542082], 
         FormBox["2000", TraditionalForm]}, {
         NCache[
          Log[5000], 8.517193191416238], 
         FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"OpAmp 100\[Mu]A bias\"\>", {1.21, 0.58}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 1.24}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 4.0600000000000005`}, {-1, 0},
          Automatic, {1, 0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 4.739999999999999}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.44951946251475*^9, 3.4495195362335*^9, {3.4495195972335*^9, 
   3.449519608217875*^9}, {3.449519679546*^9, 3.44951974851475*^9}, {
   3.4495197899835*^9, 3.449519913842875*^9}, {3.449520107905375*^9, 
   3.44952021145225*^9}, 3.4495203867335*^9, 3.449520937436625*^9, 
   3.4495453824796968`*^9, 3.4495460177296968`*^9, 3.449579406244625*^9, 
   3.449579467729*^9, 3.4495797011665*^9, 3.44958138551025*^9, 
   3.449582935375*^9, 3.449593392140625*^9, 3.44959938190625*^9, 
   3.449603938765625*^9, 3.449689493125*^9, 3.4496895831875*^9, 
   3.44968963415625*^9, 3.449689768875*^9, 3.44969146140625*^9, 
   3.44969244696875*^9, 3.44969249390625*^9, 3.449692756015625*^9, 
   3.449692824375*^9, 3.4496930199375*^9, 3.44970598653125*^9, 
   3.4501367857955165`*^9, 3.450186567508625*^9, 3.450189023883625*^9, 
   3.45029367025*^9, 3.450455283039875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Amp", "Subsubtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}, {3.449520988499125*^9, 3.44952099113975*^9}}],

Cell["\<\
The 50\[CapitalOmega] termination noise is correlated between the two \
detector chains it has to be added coherently, whereas the shottky noise does \
not.\
\>", "Text",
 CellChangeTimes->{{3.449580849104*^9, 3.449580863854*^9}, {
  3.44958123801025*^9, 3.44958125501025*^9}, {3.44958133107275*^9, 
  3.44958135257275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "2", "]"}], "=", 
   FractionBox["3300", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "2", "]"}], "=", 
    RowBox[{"par", "[", 
     RowBox[{"3300", ",", 
      FractionBox["1", 
       RowBox[{"s", " ", "68*^-12"}]]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"opamp", "[", "2", "]"}], "=", 
    RowBox[{
     RowBox[{"OpAmp", "[", 
      RowBox[{"0", ",", 
       RowBox[{"z1", "[", "2", "]"}], ",", 
       RowBox[{"z2", "[", "2", "]"}]}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], ";"}], 
  " ", 
  RowBox[{"(*", " ", "gain", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{"0", ",", 
       RowBox[{"z1", "[", "2", "]"}], ",", 
       RowBox[{"z2", "[", "2", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"corrnoise", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"opamp", "[", "1", "]"}], "]"}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "TransformerRatio"}], ")"}], "2"], " ", "FourKT", " ", 
       "Rterm"}]]}], "/.", "detParam"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"totalnoise", "[", 
    RowBox[{"2", ",", "ib_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"opamp", "[", "2", "]"}], "]"}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"opampnoise", "[", "2", "]"}], "2"], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"totalnoise", "[", 
           RowBox[{"1", ",", "ib"}], "]"}], "2"], "+", 
         SuperscriptBox["corrnoise", "2"]}], "2"]}]]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"totalnoise", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"totalnoise", "[", 
      RowBox[{"2", ",", "ibias"}], "]"}], "/.", "detParam"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"totalnoise", "[", 
   RowBox[{"2", ",", "1*^-4"}], "]"}], "/.", 
  RowBox[{"f", "\[Rule]", "1000"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"opamp", "[", "2", "]"}], "]"}], 
   RowBox[{"opampnoise", "[", "2", "]"}]}], "/.", 
  RowBox[{"f", "\[Rule]", "1000"}]}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}}],

Cell[BoxData["1.0818686854183259`*^-7"], "Output",
 CellChangeTimes->{
  3.449521126999125*^9, 3.449521252092875*^9, {3.449521451811625*^9, 
   3.449521458967875*^9}, {3.449521561780375*^9, 3.449521565546*^9}, 
   3.4495453826515713`*^9, 3.4495460178390713`*^9, 3.449579473650875*^9, 
   3.449579701307125*^9, 3.449580626713375*^9, 3.4495806747915*^9, 
   3.449581084463375*^9, 3.44958114601025*^9, 3.449581318979*^9, {
   3.449581355713375*^9, 3.449581385650875*^9}, 3.44958293553125*^9, 
   3.44959339228125*^9, 3.44959938203125*^9, 3.449603938875*^9, 
   3.44968949325*^9, 3.449689583296875*^9, 3.44968963428125*^9, 
   3.449689768984375*^9, 3.449691461515625*^9, 3.449692447109375*^9, 
   3.44969249403125*^9, 3.449692756140625*^9, 3.4496928245*^9, 
   3.44969302009375*^9, 3.44970598678125*^9, 3.4501367859205165`*^9, 
   3.450186567696125*^9, 3.450189024071125*^9, 3.450293670359375*^9, 
   3.450455283196125*^9}],

Cell[BoxData["2.00493220135093`*^-8"], "Output",
 CellChangeTimes->{
  3.449521126999125*^9, 3.449521252092875*^9, {3.449521451811625*^9, 
   3.449521458967875*^9}, {3.449521561780375*^9, 3.449521565546*^9}, 
   3.4495453826515713`*^9, 3.4495460178390713`*^9, 3.449579473650875*^9, 
   3.449579701307125*^9, 3.449580626713375*^9, 3.4495806747915*^9, 
   3.449581084463375*^9, 3.44958114601025*^9, 3.449581318979*^9, {
   3.449581355713375*^9, 3.449581385650875*^9}, 3.44958293553125*^9, 
   3.44959339228125*^9, 3.44959938203125*^9, 3.449603938875*^9, 
   3.44968949325*^9, 3.449689583296875*^9, 3.44968963428125*^9, 
   3.449689768984375*^9, 3.449691461515625*^9, 3.449692447109375*^9, 
   3.44969249403125*^9, 3.449692756140625*^9, 3.4496928245*^9, 
   3.44969302009375*^9, 3.44970598678125*^9, 3.4501367859205165`*^9, 
   3.450186567696125*^9, 3.450189024071125*^9, 3.450293670359375*^9, 
   3.450455283196125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"2", ",", "1*^-5"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"2", ",", "1*^-4"}], "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", 
          RowBox[{"2", ",", "1*^-3"}], "]"}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{"opamp", "[", "2", "]"}], "]"}], 
         RowBox[{"opampnoise", "[", "2", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"10", ",", "500"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<OpAmp\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520365921*^9, 
   3.44952038451475*^9}, 3.449520934030375*^9, {3.449521483624125*^9, 
   3.449521503499125*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV03s0lVkYBnAjjFvktL+DUi7n+84pjUqhkdsTReUaooxqEjKoKHUaXRjJ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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hk0ldsbB/DTIR0q6T1Dxg5631eu5vC7Ij2lQaGjkylNyHTNjac0cAtF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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV1XlUzdsXAPDcurn1mnzvTTekdL/fm6mJCg3shPQqDTQYGjVo0HA1kCZN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        "]]}, 
      {GrayLevel[0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hk4FQ8XB3D7HbtwLxeXi3sHhVQkUh3ZSZaE+KEFCckWvVIiRErKvhRF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 2.302585092994046}, {2.302585092994046, 2.302585092994046}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
         Log[10], 
         Log[20], 
         Log[50], 
         Log[100], 
         Log[200], 
         Log[500], 
         Log[1000], 
         Log[2000], 
         Log[5000], 3.4011973816621555`, 3.6888794541139363`, 4.0943445622221,
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
         5.703782474656201, 5.991464547107982, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         8.006367567650246, 8.294049640102028}}, {{2.302585092994046, 
        4.605170185988092, 6.907755278982137, 9.210340371976184, 
        11.512925464970229`, 2.995732273553991, 3.4011973816621555`, 
        3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.298317366548036, 5.703782474656201, 5.991464547107982, 
        6.214608098422191, 6.396929655216146, 6.551080335043404, 
        6.684611727667927, 6.802394763324311, 7.600902459542082, 
        8.006367567650246, 8.294049640102028, 8.517193191416238, 
        8.699514748210191, 8.85366542803745, 8.987196820661973, 
        9.104979856318357, 9.903487552536127, 10.308952660644293`, 
        10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
        11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
        2.302585092994046, 2.995732273553991, 3.912023005428146, 
        4.605170185988092, 5.298317366548036, 6.214608098422191, 
        6.907755278982137, 7.600902459542082, 8.517193191416238, 
        3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.703782474656201, 5.991464547107982, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        8.006367567650246, 8.294049640102028}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {2.302585092994046, 6.214608098422191}}, {{
       2.302585092994046, 11.512925464970229`}, {2.302585092994046, 
       6.214608098422191}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {
         NCache[
          Log[1000], 6.907755278982137], 
         FormBox["1000", TraditionalForm]}, {
         NCache[
          Log[2000], 7.600902459542082], 
         FormBox["2000", TraditionalForm]}, {
         NCache[
          Log[5000], 8.517193191416238], 
         FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"OpAmp\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 1.24}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 4.0600000000000005`}, {-1, 0},
          Automatic, {1, 0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 4.739999999999999}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.44951946251475*^9, 3.4495195362335*^9, {3.4495195972335*^9, 
   3.449519608217875*^9}, {3.449519679546*^9, 3.44951974851475*^9}, {
   3.4495197899835*^9, 3.449519913842875*^9}, {3.449520107905375*^9, 
   3.44952021145225*^9}, 3.4495203867335*^9, 3.449520937436625*^9, 
   3.449521507546*^9, 3.449521570592875*^9, 3.4495453841828213`*^9, 
   3.4495460193859468`*^9, 3.44957947638525*^9, 3.449579702932125*^9, 
   3.4495806797915*^9, 3.44958115051025*^9, {3.449581358494625*^9, 
   3.449581387307125*^9}, 3.44958293721875*^9, 3.449593394078125*^9, 
   3.449599384109375*^9, 3.449603940890625*^9, 3.449689495203125*^9, 
   3.449689586171875*^9, 3.44968963621875*^9, 3.449689770984375*^9, 
   3.449691463703125*^9, 3.449692450609375*^9, 3.449692497453125*^9, 
   3.449692759609375*^9, 3.449692827921875*^9, 3.44969302371875*^9, 
   3.44970599021875*^9, 3.4501367892173915`*^9, 3.45018657271175*^9, 
   3.450189029133625*^9, 3.4502936736875*^9, 3.45045528939925*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Referred Noise", "Subsubtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}, {3.449520988499125*^9, 3.44952099113975*^9}, {
  3.449521640342875*^9, 3.4495216478585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"carrier", "=", 
    FractionBox["1", 
     SqrtBox["2"]]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"10", " ", "dBm"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loss", "=", 
   RowBox[{"FromdB", "[", 
    RowBox[{"-", "1."}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"detectorgain", "=", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"opamp", "[", "1", "]"}], 
       RowBox[{"opamp", "[", "2", "]"}]}], "/.", 
      RowBox[{"f", "\[Rule]", "0"}]}], "]"}], "TransformerRatio", " ", 
    "loss"}], "/.", "detParam"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"carriernoise", "[", "ib_", "]"}], ":=", 
  FractionBox[
   RowBox[{"totalnoise", "[", 
    RowBox[{"2", ",", "ib"}], "]"}], 
   RowBox[{"detectorgain", " ", "carrier"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FiftyOhm", "=", 
   FractionBox[
    SqrtBox[
     RowBox[{"2", "FourKT", " ", "50"}]], "carrier"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"noisefigure", "[", "ib_", "]"}], ":=", 
  FractionBox[
   RowBox[{"carriernoise", "[", "ib", "]"}], 
   "FiftyOhm"]}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{
   RowBox[{"carriernoise", "[", "1*^-4", "]"}], "/.", 
   RowBox[{"f", "\[Rule]", "1000"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", "FiftyOhm", "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.449521688686625*^9, 3.449521794374125*^9}, {
   3.44952183320225*^9, 3.449521843092875*^9}, {3.449521918155375*^9, 
   3.44952195676475*^9}, {3.4495466290734468`*^9, 3.4495466552921968`*^9}, {
   3.4495467054796968`*^9, 3.4495467122453213`*^9}, {3.4495468411671968`*^9, 
   3.4495469102453213`*^9}, {3.449579508088375*^9, 3.449579578119625*^9}, 
   3.449579624682125*^9, {3.449579795354*^9, 3.449579844729*^9}, {
   3.449580006244625*^9, 3.4495800076665*^9}, 3.4495814212915*^9}],

Cell[BoxData["71.94825755116055`"], "Output",
 CellChangeTimes->{{3.449521775999125*^9, 3.449521795186625*^9}, {
   3.4495218338585*^9, 3.4495218464835*^9}, {3.44952192382725*^9, 
   3.4495219569835*^9}, 3.4495453842921968`*^9, 3.4495460195109468`*^9, 
   3.4495466561984468`*^9, 3.4495467129640713`*^9, 3.4495468691984468`*^9, 
   3.4495469109953213`*^9, 3.4495794869165*^9, {3.449579571932125*^9, 
   3.449579578932125*^9}, 3.4495796251665*^9, 3.44957970307275*^9, {
   3.449579825182125*^9, 3.449579870229*^9}, {3.449580008104*^9, 
   3.44958001544775*^9}, 3.449580693494625*^9, 3.44958119213525*^9, 
   3.449581387432125*^9, 3.449581422244625*^9, 3.449582937359375*^9, 
   3.449593394203125*^9, 3.449599384234375*^9, 3.449603941015625*^9, 
   3.44968949534375*^9, 3.44968958628125*^9, 3.449689636375*^9, 
   3.44968977109375*^9, 3.44969146384375*^9, 3.449692450734375*^9, 
   3.449692497625*^9, 3.449692759734375*^9, 3.4496928280625*^9, 
   3.449693023875*^9, 3.44970599034375*^9, 3.4501367893580165`*^9, 
   3.45018657289925*^9, 3.450189029368*^9, 3.450293673828125*^9, 
   3.450455289602375*^9}],

Cell[BoxData[
 RowBox[{"-", "173.44661464847326`"}]], "Output",
 CellChangeTimes->{{3.449521775999125*^9, 3.449521795186625*^9}, {
   3.4495218338585*^9, 3.4495218464835*^9}, {3.44952192382725*^9, 
   3.4495219569835*^9}, 3.4495453842921968`*^9, 3.4495460195109468`*^9, 
   3.4495466561984468`*^9, 3.4495467129640713`*^9, 3.4495468691984468`*^9, 
   3.4495469109953213`*^9, 3.4495794869165*^9, {3.449579571932125*^9, 
   3.449579578932125*^9}, 3.4495796251665*^9, 3.44957970307275*^9, {
   3.449579825182125*^9, 3.449579870229*^9}, {3.449580008104*^9, 
   3.44958001544775*^9}, 3.449580693494625*^9, 3.44958119213525*^9, 
   3.449581387432125*^9, 3.449581422244625*^9, 3.449582937359375*^9, 
   3.449593394203125*^9, 3.449599384234375*^9, 3.449603941015625*^9, 
   3.44968949534375*^9, 3.44968958628125*^9, 3.449689636375*^9, 
   3.44968977109375*^9, 3.44969146384375*^9, 3.449692450734375*^9, 
   3.449692497625*^9, 3.449692759734375*^9, 3.4496928280625*^9, 
   3.449693023875*^9, 3.44970599034375*^9, 3.4501367893580165`*^9, 
   3.45018657289925*^9, 3.450189029368*^9, 3.450293673828125*^9, 
   3.450455289602375*^9}],

Cell[BoxData[
 RowBox[{"-", "174.89454989793387`"}]], "Output",
 CellChangeTimes->{{3.449521775999125*^9, 3.449521795186625*^9}, {
   3.4495218338585*^9, 3.4495218464835*^9}, {3.44952192382725*^9, 
   3.4495219569835*^9}, 3.4495453842921968`*^9, 3.4495460195109468`*^9, 
   3.4495466561984468`*^9, 3.4495467129640713`*^9, 3.4495468691984468`*^9, 
   3.4495469109953213`*^9, 3.4495794869165*^9, {3.449579571932125*^9, 
   3.449579578932125*^9}, 3.4495796251665*^9, 3.44957970307275*^9, {
   3.449579825182125*^9, 3.449579870229*^9}, {3.449580008104*^9, 
   3.44958001544775*^9}, 3.449580693494625*^9, 3.44958119213525*^9, 
   3.449581387432125*^9, 3.449581422244625*^9, 3.449582937359375*^9, 
   3.449593394203125*^9, 3.449599384234375*^9, 3.449603941015625*^9, 
   3.44968949534375*^9, 3.44968958628125*^9, 3.449689636375*^9, 
   3.44968977109375*^9, 3.44969146384375*^9, 3.449692450734375*^9, 
   3.449692497625*^9, 3.449692759734375*^9, 3.4496928280625*^9, 
   3.449693023875*^9, 3.44970599034375*^9, 3.4501367893580165`*^9, 
   3.45018657289925*^9, 3.450189029368*^9, 3.450293673828125*^9, 
   3.450455289602375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLinearPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"dB", "[", 
         RowBox[{"carriernoise", "[", "1*^-5", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"carriernoise", "[", "1*^-4", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"carriernoise", "[", "1*^-3", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{
          SqrtBox[
           RowBox[{"2", "FourKT", " ", "50"}]], "/", "carrier"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Frequency[Hz]\>\"", ",", "\"\<SSB Noise[dBc/Hz]\>\""}], 
        "}"}]}], ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", "\"\<Input Referred Noise / 10dBm signal\>\""}],
       ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "180"}], ",", 
         RowBox[{"-", "150"}]}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<50\[CapitalOmega]\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.75", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520317342875*^9, 
   3.44952032938975*^9}, {3.449521874921*^9, 3.449521911186625*^9}, {
   3.449521975217875*^9, 3.449522012374125*^9}, {3.449522126905375*^9, 
   3.449522181155375*^9}, {3.449522222671*^9, 3.449522254421*^9}, 
   3.4495460339953213`*^9, {3.4495467728859468`*^9, 3.4495468141515713`*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk8ldkbAHBde9kSslS4933v1R5ZslSPjBCiqyiS4r6NJGVvbsSoUTRj
RAuJFIVQVOo2NTpR5vaztzBjGpSla0zCWLL/nvnjfM7n+89znuVzzjH0P8pn
WFJSUoW4/tsL6r68LT/MApUFDhZ3iwKIYCD3nTCUBSyfVeuNbgcQAzV+i100
C8YTtmlcR1/xeND6LoEFvl9NEtOKA0hK2/G2iUwWbOA8N4ooDSBRknmdtmIW
WNU7HzIpDyD2Mhr9zZQ0nNii+9cVUQDpst4wb/gvaRD1pr/S+y2AqNV2SjyP
yoLY8sxuTk8AcR3qcGL3ykHvtYJNkXMBJNU45ef0XQog1gpMK18sINXnr6Yu
71aEq7cOeDiuExC5pHkLuLsXwKM31aF37QXEKrcGHPqVIDBHPQF8BCSi2cpH
JVoFuDFJ0u9CBKQyU/aLtUQVpIduWoviBGQatPUdnqrBUYPy5AupAnJdas8p
TvRCONl6aPm8awLi5Dr0B3+NOmxYle8+WiwgfUWWKRqj6mARK33uV5GALOSv
jku6swh0k3OKz1QLiPH85vrUaA0YzknhqTQIyE63OpV+G00YrW34yaFVQOY6
wn78OqIJMc+shGPtApIX/+rbjKdaIDrFc/brFZCG4Nq4/qjFsFF333cn/xGQ
4cDY0SbQhqru9kmvYQHRGU70VZTXAfb/XuT7jQuIuMaaNfpMB/Y4aq+PmxKQ
o8W5MuFndaFlPetE0JyA5PxZZpdvpwdVw4vrs1kMacrQjjSa0gNjw+BZP1mG
TDLrZDZXLYHdsz63Z+UZUnLy30aFmKXgt9dPjz2fIV4FBycE9svgvvLcuuVK
DJHxNdbUWKAPy+xMXvcoM8RyX8GRqGp9+Nqrc4WvypAHj3rPV9gbwA7xxI27
agxRPeh2TjHPAORCOIFNCxnS39Y1kzhrADnszIwGdYa88HK/Vn/AEJILPfeK
FzHkgFC940ilIWQ86BvI0cD88ktcW9lsCPk+oESoiflEXvW+Es8Gtk9OpJ0W
Q8yURJ2J79lQE+b8SWkxnldcfNEGOHDcQm3qK5rd9PV1mS0H2vZb5E2jTUft
1Wg7Dvi/dnGV0mbI7s2dycpbOVAIHgXy6BtvNOLbnTnw3uKbcC20+XRsULwX
B/Z1RoaYove5um9+EcKBnT7aC8PQpV9GJM7ZGI/1SG0U3Rkxs60jhwNmZ3Y/
mECrT8qWhuVyYEhS6DOLjpJZHJqZx4ENKWEV8joMAR3Lid4iDpR4h17SRb/d
EquY8JADEkOhhi168qLsClEjB7j9p8zOo1fpqfzo3MyBW2X7fS+h/XK1Btpf
c4BZ0ZmUhX5xm3dPtoUD1y0lgzfRKc+crDzec6B0TPbrL2jDvp+2DUg4ECPb
NdSDdrTROkyxKEg5m9e8WZchF45Jh5dJU3C77vgpe/SH/EGhjSwFaWGtVs5o
oXJt8k4FCpas2fWLJ7qkPe72aRUKhJX8mSNo1e/7+rp1KWDZxWRlo1tePg28
uZ4CGbXxE/P0cB6TRceMzShYYbpnSB59dM3l47+aU3Drw4kjKmiFy6Fn31lS
4HBvlVAPbRXILZQFCvJKAnrN0NnzUz8xLhRY1yUtCkYL3AIOchkKPpXZqrSj
Hdtevb18kALRXPZQN3ols85OMZACjwG19/3oYeGM/j9BFAwmHaiZQMffuvxH
+TEKmj49G9JcwpCrM7UuG2MouDNnWOKGfltsun5nOgX7z0yNidEi86zrLy9Q
oKdc0dSEzno+T83iEgVBpxvu/Y72b234RyeTAsmsS6oEPcg6dKsjhwJ9l5Jy
haUMUfLO1jl8m4KZrorL29DfKMhJJTynILFT3vYd2vFfXrp6Nfbzu9HZdrRz
uxM37wUFvsYhYgma/+Anlxe/USAnv/nkNHr/fs1MuQYKeLGLoqllDDkhokzO
tVHg5+RbHIW+F2gnuPAvBZ3s9z9T+gx56MGMU6MUSHmbt69FP950JrlijIJa
Z9rKGk00astaJij4e0xWj49uIPwZbSkatm+rSIhH92n7X8pWoqFm/YKJDrTB
q3jxLZqGe3yp2SIDhvwyf0nVEh4NDcFg+xC9y+XRkzQjGq7/7pBWhU5u/Hzn
5Eoaxgz7fP9Ej7zzvuhpTMNw+rJsZUOGiD+a+sttpEHP+6E4An1sWjLF7KTh
qbyW7XY2Q+ZvOj365y4amss1ffaib8bpf9nhRUPxVP3pIHQby/PjRm8aaNNC
+TPobxSrxZr7aWA/qqojaG2t7IsvD9PAcs/yt+BgvWt3rKVP0fB3m+waY4oh
EQbNDemnadhWXqRki16+cEcIK5GGnGrvaXd02rB7acdZGlYAWzUULahwX3kl
hQah65j0PbSCtTtP9QrWwzfZYEEzxH2rm/5EGQ0T1/vM3bj4flo0Vn57jwYX
o0W7DqAf89z2tdynIfOSeWI4mq3oln3/IQ1nnQoNM9Ajtdv1Qp7SkLXw46aP
6Iwd2xd3/UZDV/WEvpCH93Ovq2p9O8a/Nt0jMsL5lp59491JQ7l5sW0jOnm2
+rLkAw1eoT0VPWiTXCsDmR4aPki2StSXM+R0F8/Yup+GnqLnUSFooyCWR9E4
DXfcz2xbsQL7H/3o0g9qXLApyXeqWMmQufOGyzZt4UKwFzgtWcuQIMsWx3I7
LkTlrvO1QLd0JodT9lxI/SyfzEffWTsinu/IhZq+i2uS0Hvra8JbXbnQLeTn
j6NFCsGvju3hQtkGTec/1uF5cQ8j8o5xwSO7oOauCdYX7FyrcI0LWyxrDYrN
GRIc8UQ3K5cLY2yjU43orydWBq2+wYW1N7plRtAq5xYo8m9yQaPux4MbLRhi
U1S7NauYCw4XWHnN6Iwe56rVIi6Yja+TlrLE+exzecxv5kKmxe7gCGuGPHNz
LbgqzYO53TI3nwDenyDb0kL0kL3c+FN0/g9m9x+gDzmpOlWik58sfVaHrkw3
/0zQnryBlml0qmmbWQ3682yKnK8MD8ayIsVNaL07TcxSWR6o354e7kGrvHpx
eDk6y+2D/Se0VLco1AytM78+Q4Lu1bke64qu/PXxpv7/8vkh9GIs2nOZJHkQ
7eSr/vIvdMrjDGoKbXNcrrYPHVI4ED2NXpM+2TSKjix2rp1Ba7z6+F5Zjge1
n3XDpGzxvzK9P7IRvdpfhcii37gVTDqh/x68ukgeXROUJeWJDko3+VYBXZJ7
SikEHbMoXGUB+tqTaHUhemRwqb8SOq3lsHYievJDY4Uy+vSQ37I0dELvWUVV
dLTSTioHfXLW0VcN/X/U8LRN
        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hk01YkXAHCeJdsgJLI88f1+H2lDMqLmSpIfL0uWUkjeV8bWa1TKCMlS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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV1Hk0VW8XB3CuIfN4TRFyz70kQ0oT0pakXkSSohJyEBlSISUylUimVGbR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        "]]}, 
      {GrayLevel[0], Thickness[0.007], 
       LineBox[{{2.302585280960176, -174.89454989793387`}, {
        2.39297851233326, -174.89454989793387`}, {
        2.483371743706344, -174.89454989793387`}, {
        2.679364985809464, -174.89454989793387`}, {
        2.862370087763486, -174.89454989793387`}, {
        3.0417853560704273`, -174.89454989793387`}, {
        3.23640740373432, -174.89454989793387`}, {
        3.418041311249115, -174.89454989793387`}, {
        3.614881998120862, -174.89454989793387`}, {
        3.808132851345528, -174.89454989793387`}, {
        3.988395564421096, -174.89454989793387`}, {
        4.183865056853616, -174.89454989793387`}, {
        4.366346409137038, -174.89454989793387`}, {
        4.545237927773379, -174.89454989793387`}, {
        4.739336225766672, -174.89454989793387`}, {
        4.920446383610867, -174.89454989793387`}, {
        5.116763320812013, -174.89454989793387`}, {
        5.3094904243660785`, -174.89454989793387`}, {
        5.489229387771046, -174.89454989793387`}, {
        5.684175130532966, -174.89454989793387`}, {
        5.866132733145788, -174.89454989793387`}, {
        6.063297115115562, -174.89454989793387`}, {
        6.256871663438255, -174.89454989793387`}, {
        6.43745807161185, -174.89454989793387`}, {
        6.633251259142397, -174.89454989793387`}, {
        6.816056306523846, -174.89454989793387`}, {
        6.995271520258214, -174.89454989793387`}, {
        7.189693513349534, -174.89454989793387`}, {
        7.371127366291756, -174.89454989793387`}, {
        7.56776799859093, -174.89454989793387`}, {
        7.760818797243022, -174.89454989793387`}, {
        7.940881455746017, -174.89454989793387`}, {
        8.136150893605965, -174.89454989793387`}, {
        8.318432191316814, -174.89454989793387`}, {
        8.497123655380582, -174.89454989793387`}, {
        8.691021898801303, -174.89454989793387`}, {
        8.871932002072926, -174.89454989793387`}, {
        9.0680488847015, -174.89454989793387`}, {
        9.251177627180978, -174.89454989793387`}, {
        9.430716536013373, -174.89454989793387`}, {
        9.62546222420272, -174.89454989793387`}, {
        9.807219772242968, -174.89454989793387`}, {
        10.00418409964017, -174.89454989793387`}, {
        10.19755859339029, -174.89454989793387`}, {
        10.377944946991313`, -174.89454989793387`}, {
        10.573538079949287`, -174.89454989793387`}, {
        10.756143072758164`, -174.89454989793387`}, {
        10.935158231919958`, -174.89454989793387`}, {
        11.129380170438706`, -174.89454989793387`}, {
        11.310613968808356`, -174.89454989793387`}, {
        11.507054546534958`, -174.89454989793387`}, {
        11.509989911769528`, -174.89454989793387`}, {
        11.512925277004099`, -174.89454989793387`}}]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], -180}, {2.302585092994046, -180}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox["\"SSB Noise[dBc/Hz]\"", TraditionalForm]},
     FrameTicks->
      FrontEndValueCache[{{Automatic, Automatic}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{
        Automatic, Automatic}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
       9.210340371976184, 11.512925464970229`, 2.995732273553991, 
       3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
       4.0943445622221, 4.248495242049359, 4.382026634673881, 
       4.499809670330265, 5.298317366548036, 5.703782474656201, 
       5.991464547107982, 6.214608098422191, 6.396929655216146, 
       6.551080335043404, 6.684611727667927, 6.802394763324311, 
       7.600902459542082, 8.006367567650246, 8.294049640102028, 
       8.517193191416238, 8.699514748210191, 8.85366542803745, 
       8.987196820661973, 9.104979856318357, 9.903487552536127, 
       10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
       11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
       11.407564949312402`}, Automatic},
     ImageSize->Scaled[0.8],
     Method->{},
     PlotLabel->FormBox[
      "\"Input Referred Noise / 10dBm signal\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {-180, -150}}, {{2.302585092994046, 
        11.512925464970229`}, {-180, -150}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"50\[CapitalOmega]\"\>", {1.21, 0.58}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 1.24}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 4.0600000000000005`}, {-1, 0},
          Automatic, {1, 0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 4.739999999999999}}], {0.75, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.449521970936625*^9, 3.449522015249125*^9}, {
   3.44952223095225*^9, 3.449522256999125*^9}, 3.4495453852609468`*^9, {
   3.4495460204640713`*^9, 3.4495460351515713`*^9}, 3.4495466108234468`*^9, {
   3.4495467949484468`*^9, 3.4495468160890713`*^9}, 3.449579492213375*^9, 
   3.44957958332275*^9, 3.449579629057125*^9, 3.449579704494625*^9, 
   3.449580017994625*^9, 3.449580694994625*^9, 3.449581193588375*^9, {
   3.4495813655415*^9, 3.44958138882275*^9}, 3.449581425229*^9, 
   3.449582938734375*^9, 3.44959339578125*^9, 3.44959938603125*^9, 
   3.44960394278125*^9, 3.449689497078125*^9, 3.44968958871875*^9, 
   3.449689638046875*^9, 3.449689772765625*^9, 3.449691465765625*^9, 
   3.449692453734375*^9, 3.449692503890625*^9, 3.4496927626875*^9, 
   3.449692831046875*^9, 3.449693027046875*^9, 3.4497059931875*^9, 
   3.4501367922173915`*^9, 3.45018657721175*^9, 3.450189033727375*^9, 
   3.4502936766875*^9, 3.45045529471175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLinearPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"dB", "[", 
         RowBox[{"noisefigure", "[", "1*^-5", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"noisefigure", "[", "1*^-4", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"noisefigure", "[", "1*^-3", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Frequency[Hz]\>\"", ",", "\"\<NF[dB]\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Noise Figure\>\""}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "14"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<10\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<100\[Mu]A bias\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<1mA bias\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.75", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520317342875*^9, 
   3.44952032938975*^9}, {3.449521874921*^9, 3.449521911186625*^9}, {
   3.449521975217875*^9, 3.449522012374125*^9}, {3.449522126905375*^9, 
   3.449522181155375*^9}, {3.449522222671*^9, 3.449522254421*^9}, 
   3.4495460339953213`*^9, {3.4495467728859468`*^9, 3.4495468141515713`*^9}, {
   3.4495469308859468`*^9, 3.4495469964484468`*^9}, {3.4495470417609468`*^9, 
   3.4495470503546968`*^9}, {3.449579665744625*^9, 3.44957966638525*^9}, {
   3.4495797470415*^9, 3.449579752588375*^9}, 3.449580724479*^9, {
   3.44958120407275*^9, 3.44958120432275*^9}, {3.449581433713375*^9, 
   3.44958145307275*^9}, {3.449581520119625*^9, 3.44958157644775*^9}, {
   3.4495829224375*^9, 3.44958295503125*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd1Xk4ldseB3AJxxRi7/2+28x+3y2VHEldQ/Utl2MmKXIa1EEdGmSOyIkU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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xs4VVkfB/DjkBwZcisS58Tem1KhNG8K69eUSsglJaJM6EKhEcdI8eZS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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV02k4levbBnDDMma2zBmynvXQpBTJkOuKJCFCkqTyp0QlQ7ENERK22oZU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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 0}, {2.302585092994046, 0}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox["\"NF[dB]\"", TraditionalForm]},
     FrameTicks->
      FrontEndValueCache[{{Automatic, Automatic}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{
        Automatic, Automatic}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
       9.210340371976184, 11.512925464970229`, 2.995732273553991, 
       3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
       4.0943445622221, 4.248495242049359, 4.382026634673881, 
       4.499809670330265, 5.298317366548036, 5.703782474656201, 
       5.991464547107982, 6.214608098422191, 6.396929655216146, 
       6.551080335043404, 6.684611727667927, 6.802394763324311, 
       7.600902459542082, 8.006367567650246, 8.294049640102028, 
       8.517193191416238, 8.699514748210191, 8.85366542803745, 
       8.987196820661973, 9.104979856318357, 9.903487552536127, 
       10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
       11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
       11.407564949312402`}, Automatic},
     ImageSize->Scaled[0.8],
     Method->{},
     PlotLabel->FormBox["\"Noise Figure\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {0, 14}}, {{2.302585092994046, 11.512925464970229`}, {
        0, 14}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"1mA bias\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"100\[Mu]A bias\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {
         1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"10\[Mu]A bias\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1,
          0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.75, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.449521970936625*^9, 3.449522015249125*^9}, {
   3.44952223095225*^9, 3.449522256999125*^9}, 3.4495453852609468`*^9, {
   3.4495460204640713`*^9, 3.4495460351515713`*^9}, 3.4495466108234468`*^9, {
   3.4495467949484468`*^9, 3.4495468160890713`*^9}, 3.4495469449171968`*^9, {
   3.4495469933234468`*^9, 3.4495469976203213`*^9}, {3.4495470434171968`*^9, 
   3.4495470526359468`*^9}, 3.449579596994625*^9, {3.4495796486665*^9, 
   3.44957966813525*^9}, 3.449579705604*^9, {3.449579748744625*^9, 
   3.449579754525875*^9}, 3.449580025729*^9, {3.4495806961665*^9, 
   3.44958072601025*^9}, {3.449581194744625*^9, 3.44958120569775*^9}, 
   3.449581389963375*^9, {3.449581428400875*^9, 3.449581454807125*^9}, {
   3.449581521557125*^9, 3.449581577775875*^9}, {3.44958293984375*^9, 
   3.449582957015625*^9}, 3.449593396953125*^9, 3.44959938740625*^9, 
   3.44960394446875*^9, 3.44968949846875*^9, 3.4496895908125*^9, 
   3.449689639390625*^9, 3.449689774078125*^9, 3.449691467265625*^9, 
   3.449692456046875*^9, 3.44969250625*^9, 3.4496927649375*^9, 
   3.4496928333125*^9, 3.449693029359375*^9, 3.44970599534375*^9, 
   3.4501367944048915`*^9, 3.450186581039875*^9, 3.4501890370555*^9, 
   3.450293678890625*^9, 3.450455298618*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bias Servo Compensation Network", "Subsubtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}, {3.449520988499125*^9, 3.44952099113975*^9}, {
  3.449521640342875*^9, 3.4495216478585*^9}, {3.44971693896875*^9, 
  3.449716959453125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"fknee", "\[Rule]", "0.7"}], ",", 
    RowBox[{"R2", "\[Rule]", "10000"}], ",", 
    RowBox[{"R1", "\[Rule]", "20000"}], ",", 
    RowBox[{"C", "\[Rule]", "20*^-6"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"op1", "=", 
  RowBox[{
   RowBox[{"OpAmp", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "R1", ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"s", " ", "C"}]], "+", "R2"}]}], "]"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"op1", "\[Equal]", 
     RowBox[{
      FractionBox["R2", "R1"], 
      FractionBox[
       RowBox[{"s", "+", 
        RowBox[{"2", "\[Pi]", " ", "fknee"}]}], "s"]}]}], ",", "C"}], "]"}], 
  "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"1*^6", " ", "C"}], "/.", "%"}], "/.", 
  "prm"}], "\[IndentingNewLine]", 
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1*^9", 
      RowBox[{"OpAmpNoise", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "R1", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"s", " ", "C"}]], "+", "R2"}], ",", "en", ",", "in"}], 
       "]"}]}], "/.", 
     RowBox[{"OP27", "[", "f", "]"}]}], "/.", "prm"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1*^5"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1000"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.449706333359375*^9, 3.449706432796875*^9}, {
  3.449706466421875*^9, 3.449706508171875*^9}, {3.449706553046875*^9, 
  3.449706607484375*^9}, {3.449706651515625*^9, 3.449706688859375*^9}, {
  3.44970674990625*^9, 3.44970690609375*^9}, {3.449706960171875*^9, 
  3.449707071984375*^9}, {3.44971150509375*^9, 3.44971156403125*^9}, {
  3.44971161546875*^9, 3.449711622640625*^9}, {3.4497121201875*^9, 
  3.449712167484375*^9}, {3.4497123623125*^9, 3.449712366890625*^9}, {
  3.449713926828125*^9, 3.44971398234375*^9}, {3.449714248609375*^9, 
  3.449714254640625*^9}, {3.449715079953125*^9, 3.4497150966875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"fknee", "\[Rule]", "0.7`"}], ",", 
   RowBox[{"R2", "\[Rule]", "10000"}], ",", 
   RowBox[{"R1", "\[Rule]", "20000"}], ",", 
   RowBox[{"C", "\[Rule]", 
    FractionBox["1", "50000"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.449706352453125*^9, 3.44970638953125*^9}, {
   3.44970649334375*^9, 3.4497065086875*^9}, {3.44970655346875*^9, 
   3.449706608140625*^9}, 3.4497066520625*^9, {3.449706685296875*^9, 
   3.44970668953125*^9}, {3.449706770625*^9, 3.4497068336875*^9}, {
   3.449706894078125*^9, 3.449706906734375*^9}, {3.4497069764375*^9, 
   3.44970707253125*^9}, 3.44970754821875*^9, {3.449711506734375*^9, 
   3.44971156478125*^9}, {3.449711616625*^9, 3.449711624078125*^9}, 
   3.44971212934375*^9, 3.4497121881875*^9, 3.449712367609375*^9, {
   3.4497139293125*^9, 3.44971398325*^9}, 3.44971425515625*^9, {
   3.449715084015625*^9, 3.44971509721875*^9}, 3.449716167609375*^9, 
   3.4501367945142665`*^9, 3.450186581196125*^9, 3.450189037227375*^9, 
   3.450293678984375*^9, 3.450455298743*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"R2", "+", 
   FractionBox["1", 
    RowBox[{"C", " ", "s"}]]}], "R1"]], "Output",
 CellChangeTimes->{{3.449706352453125*^9, 3.44970638953125*^9}, {
   3.44970649334375*^9, 3.4497065086875*^9}, {3.44970655346875*^9, 
   3.449706608140625*^9}, 3.4497066520625*^9, {3.449706685296875*^9, 
   3.44970668953125*^9}, {3.449706770625*^9, 3.4497068336875*^9}, {
   3.449706894078125*^9, 3.449706906734375*^9}, {3.4497069764375*^9, 
   3.44970707253125*^9}, 3.44970754821875*^9, {3.449711506734375*^9, 
   3.44971156478125*^9}, {3.449711616625*^9, 3.449711624078125*^9}, 
   3.44971212934375*^9, 3.4497121881875*^9, 3.449712367609375*^9, {
   3.4497139293125*^9, 3.44971398325*^9}, 3.44971425515625*^9, {
   3.449715084015625*^9, 3.44971509721875*^9}, 3.449716167609375*^9, 
   3.4501367945142665`*^9, 3.450186581196125*^9, 3.450189037227375*^9, 
   3.450293678984375*^9, 3.45045529877425*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"C", "\[Rule]", 
   FractionBox["1", 
    RowBox[{"2", " ", "fknee", " ", "\[Pi]", " ", "R2"}]]}], "}"}]], "Output",\

 CellChangeTimes->{{3.449706352453125*^9, 3.44970638953125*^9}, {
   3.44970649334375*^9, 3.4497065086875*^9}, {3.44970655346875*^9, 
   3.449706608140625*^9}, 3.4497066520625*^9, {3.449706685296875*^9, 
   3.44970668953125*^9}, {3.449706770625*^9, 3.4497068336875*^9}, {
   3.449706894078125*^9, 3.449706906734375*^9}, {3.4497069764375*^9, 
   3.44970707253125*^9}, 3.44970754821875*^9, {3.449711506734375*^9, 
   3.44971156478125*^9}, {3.449711616625*^9, 3.449711624078125*^9}, 
   3.44971212934375*^9, 3.4497121881875*^9, 3.449712367609375*^9, {
   3.4497139293125*^9, 3.44971398325*^9}, 3.44971425515625*^9, {
   3.449715084015625*^9, 3.44971509721875*^9}, 3.449716167609375*^9, 
   3.4501367945142665`*^9, 3.450186581196125*^9, 3.450189037227375*^9, 
   3.450293678984375*^9, 3.450455298821125*^9}],

Cell[BoxData["22.736420441699337`"], "Output",
 CellChangeTimes->{{3.449706352453125*^9, 3.44970638953125*^9}, {
   3.44970649334375*^9, 3.4497065086875*^9}, {3.44970655346875*^9, 
   3.449706608140625*^9}, 3.4497066520625*^9, {3.449706685296875*^9, 
   3.44970668953125*^9}, {3.449706770625*^9, 3.4497068336875*^9}, {
   3.449706894078125*^9, 3.449706906734375*^9}, {3.4497069764375*^9, 
   3.44970707253125*^9}, 3.44970754821875*^9, {3.449711506734375*^9, 
   3.44971156478125*^9}, {3.449711616625*^9, 3.449711624078125*^9}, 
   3.44971212934375*^9, 3.4497121881875*^9, 3.449712367609375*^9, {
   3.4497139293125*^9, 3.44971398325*^9}, 3.44971425515625*^9, {
   3.449715084015625*^9, 3.44971509721875*^9}, 3.449716167609375*^9, 
   3.4501367945142665`*^9, 3.450186581196125*^9, 3.450189037227375*^9, 
   3.450293678984375*^9, 3.450455298821125*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8VN0bAHBkaujOYGwzwzC7ypIte80jaSHyWqK02fUjexRSyR4iS8hS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{0., 
        FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{0., 
        FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->
   NCache[{{0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
      9.210340371976184, 11.512925464970229`, 0.6931471805599453, 
      1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
      1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.214608098422191, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.517193191416238, 
      8.699514748210191, 8.85366542803745, 8.987196820661973, 
      9.104979856318357, 9.903487552536127, 10.308952660644293`, 
      10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
      11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {0, 
      Log[5], 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`,
       1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
      4.382026634673881, 4.499809670330265, 5.298317366548036, 
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
      6.551080335043404, 6.684611727667927, 6.802394763324311, 
      7.600902459542082, 8.006367567650246, 8.294049640102028}}, {{
     0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
      9.210340371976184, 11.512925464970229`, 0.6931471805599453, 
      1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
      1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.214608098422191, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.517193191416238, 
      8.699514748210191, 8.85366542803745, 8.987196820661973, 
      9.104979856318357, 9.903487552536127, 10.308952660644293`, 
      10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
      11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
     0, 1.6094379124341003`, 2.302585092994046, 3.912023005428146, 
      4.605170185988092, 6.214608098422191, 6.907755278982137, 
      8.517193191416238, 0.6931471805599453, 1.0986122886681098`, 
      1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
      2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
      3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.396929655216146, 6.551080335043404, 6.684611727667927, 
      6.802394763324311, 7.600902459542082, 8.006367567650246, 
      8.294049640102028}}],
  Method->{},
  PlotRange->NCache[{{0, 
      Log[100000]}, {0., 6.907755278982137}}, {{0, 11.512925464970229`}, {0., 
     6.907755278982137}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0, 
      FormBox["1", TraditionalForm]}, {
      NCache[
       Log[5], 1.6094379124341003`], 
      FormBox["5", TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.449706352453125*^9, 3.44970638953125*^9}, {
   3.44970649334375*^9, 3.4497065086875*^9}, {3.44970655346875*^9, 
   3.449706608140625*^9}, 3.4497066520625*^9, {3.449706685296875*^9, 
   3.44970668953125*^9}, {3.449706770625*^9, 3.4497068336875*^9}, {
   3.449706894078125*^9, 3.449706906734375*^9}, {3.4497069764375*^9, 
   3.44970707253125*^9}, 3.44970754821875*^9, {3.449711506734375*^9, 
   3.44971156478125*^9}, {3.449711616625*^9, 3.449711624078125*^9}, 
   3.44971212934375*^9, 3.4497121881875*^9, 3.449712367609375*^9, {
   3.4497139293125*^9, 3.44971398325*^9}, 3.44971425515625*^9, {
   3.449715084015625*^9, 3.44971509721875*^9}, 3.449716167609375*^9, 
   3.4501367945142665`*^9, 3.450186581196125*^9, 3.450189037227375*^9, 
   3.450293678984375*^9, 3.450455299008625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", "op1", "]"}], "/.", 
   RowBox[{"s", "\[Rule]", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "1."}]}]}], " ", "/.", 
  "prm"}], "\[IndentingNewLine]", 
 SuperscriptBox["10", 
  FractionBox[
   RowBox[{"-", "4.63"}], "20"]], "\[IndentingNewLine]", 
 RowBox[{"gain", "=", 
  RowBox[{"20", "%", " ", "%%"}]}]}], "Input",
 CellChangeTimes->{{3.449707232328125*^9, 3.44970729503125*^9}, {
  3.449707357015625*^9, 3.44970736428125*^9}, {3.44970739596875*^9, 
  3.449707413140625*^9}, {3.449708026921875*^9, 3.4497080525625*^9}, {
  3.449711589015625*^9, 3.449711599421875*^9}, {3.449712467484375*^9, 
  3.4497124681875*^9}, {3.449712786984375*^9, 3.44971278775*^9}, {
  3.44971418171875*^9, 3.449714185453125*^9}, {3.449716033609375*^9, 
  3.44971603825*^9}, {3.449716661046875*^9, 3.449716661671875*^9}}],

Cell[BoxData["0.6389947960986481`"], "Output",
 CellChangeTimes->{{3.44970723540625*^9, 3.449707296078125*^9}, {
   3.4497073585*^9, 3.449707365109375*^9}, 3.4497074141875*^9, 
   3.44970755315625*^9, {3.449708028984375*^9, 3.449708055984375*^9}, {
   3.449708130625*^9, 3.449708159609375*^9}, {3.449711573*^9, 
   3.44971159978125*^9}, 3.44971163025*^9, {3.44971245825*^9, 
   3.449712468671875*^9}, 3.44971278875*^9, {3.44971417540625*^9, 
   3.44971418709375*^9}, 3.4497160401875*^9, 3.449716662296875*^9, 
   3.4501367948580165`*^9, 3.45018658171175*^9, 3.450189037633625*^9, 
   3.450293679359375*^9, 3.450455299118*^9}],

Cell[BoxData["0.5868133696187728`"], "Output",
 CellChangeTimes->{{3.44970723540625*^9, 3.449707296078125*^9}, {
   3.4497073585*^9, 3.449707365109375*^9}, 3.4497074141875*^9, 
   3.44970755315625*^9, {3.449708028984375*^9, 3.449708055984375*^9}, {
   3.449708130625*^9, 3.449708159609375*^9}, {3.449711573*^9, 
   3.44971159978125*^9}, 3.44971163025*^9, {3.44971245825*^9, 
   3.449712468671875*^9}, 3.44971278875*^9, {3.44971417540625*^9, 
   3.44971418709375*^9}, 3.4497160401875*^9, 3.449716662296875*^9, 
   3.4501367948580165`*^9, 3.45018658171175*^9, 3.450189037633625*^9, 
   3.450293679359375*^9, 3.450455299118*^9}],

Cell[BoxData["7.499413789350166`"], "Output",
 CellChangeTimes->{{3.44970723540625*^9, 3.449707296078125*^9}, {
   3.4497073585*^9, 3.449707365109375*^9}, 3.4497074141875*^9, 
   3.44970755315625*^9, {3.449708028984375*^9, 3.449708055984375*^9}, {
   3.449708130625*^9, 3.449708159609375*^9}, {3.449711573*^9, 
   3.44971159978125*^9}, 3.44971163025*^9, {3.44971245825*^9, 
   3.449712468671875*^9}, 3.44971278875*^9, {3.44971417540625*^9, 
   3.44971418709375*^9}, 3.4497160401875*^9, 3.449716662296875*^9, 
   3.4501367948580165`*^9, 3.45018658171175*^9, 3.450189037633625*^9, 
   3.450293679359375*^9, 3.450455299118*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"fknee", "\[Rule]", "0.2"}], ",", 
    RowBox[{"R2", "\[Rule]", 
     FractionBox["1", 
      RowBox[{"2", "\[Pi]", " ", "fknee", " ", "C"}]]}], ",", 
    RowBox[{"C", "\[Rule]", "20*^-6"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"prm3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"fknee", "\[Rule]", "0.2"}], ",", 
    RowBox[{"R1", "\[Rule]", "300000"}], ",", 
    RowBox[{"R2", "\[Rule]", "40000"}], ",", 
    RowBox[{"C", "\[Rule]", "20*^-6"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"R2", "//.", "prm2"}], "\[IndentingNewLine]", 
 RowBox[{"op2", "=", 
  RowBox[{
   RowBox[{"OpAmp", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "R1", ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"s", " ", "C"}]], "+", "R2"}]}], "]"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"fr", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "op2", "]"}], "\[Equal]", 
        FractionBox["1", "gain"]}], "//.", "prm2"}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "1"}]}]}], ")"}], ",",
     
    RowBox[{"{", 
     RowBox[{"R1", ",", "1000"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1*^9", 
       RowBox[{"OpAmpNoise", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "R1", ",", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"s", " ", "C"}]], "+", "R2"}], ",", "en", ",", "in"}], 
        "]"}]}], "/.", 
      RowBox[{"LT1012", "[", "f", "]"}]}], "//.", "prm2"}], "/.", "fr"}], ",",
    
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1*^5"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1000"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.449706333359375*^9, 3.449706432796875*^9}, {
   3.449706466421875*^9, 3.449706508171875*^9}, {3.449706553046875*^9, 
   3.449706607484375*^9}, {3.449706651515625*^9, 3.449706688859375*^9}, {
   3.44970674990625*^9, 3.44970690609375*^9}, {3.449706960171875*^9, 
   3.449707071984375*^9}, {3.449707107953125*^9, 3.44970719284375*^9}, {
   3.449707285765625*^9, 3.449707343015625*^9}, {3.44970745409375*^9, 
   3.449707641546875*^9}, {3.4497076756875*^9, 3.449707677375*^9}, {
   3.449707778140625*^9, 3.449707793234375*^9}, {3.44970783078125*^9, 
   3.44970786884375*^9}, {3.44970790496875*^9, 3.449707963859375*^9}, {
   3.44970812634375*^9, 3.449708156140625*^9}, {3.449708206359375*^9, 
   3.4497082470625*^9}, {3.449708353453125*^9, 3.449708391359375*^9}, {
   3.449708452046875*^9, 3.4497084951875*^9}, {3.449708631796875*^9, 
   3.449708636265625*^9}, {3.4497087309375*^9, 3.4497087670625*^9}, {
   3.449709108984375*^9, 3.449709109265625*^9}, {3.44971146675*^9, 
   3.449711471046875*^9}, {3.449711738390625*^9, 3.44971176571875*^9}, {
   3.44971180565625*^9, 3.44971194096875*^9}, {3.449711973765625*^9, 
   3.449711974296875*^9}, {3.44971203234375*^9, 3.4497120351875*^9}, {
   3.449712426265625*^9, 3.449712438515625*^9}, {3.4497125940625*^9, 
   3.449712594234375*^9}, {3.449712675140625*^9, 3.4497126759375*^9}, {
   3.449713992953125*^9, 3.449714013625*^9}, {3.449714195796875*^9, 
   3.449714201265625*^9}, {3.449714282578125*^9, 3.44971430134375*^9}, {
   3.449714843703125*^9, 3.449714852921875*^9}, {3.44971506371875*^9, 
   3.44971506509375*^9}, 3.449715173609375*^9, {3.449715231734375*^9, 
   3.449715249078125*^9}, {3.44971565965625*^9, 3.449715709203125*^9}, {
   3.449715936515625*^9, 3.449715948234375*^9}, {3.449716059578125*^9, 
   3.44971607165625*^9}, {3.449716685140625*^9, 3.449716688484375*^9}, {
   3.44971688140625*^9, 3.44971690353125*^9}, 3.449717012078125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"fknee", "\[Rule]", "0.2`"}], ",", 
   RowBox[{"R2", "\[Rule]", 
    FractionBox["1", 
     RowBox[{"2", " ", "C", " ", "fknee", " ", "\[Pi]"}]]}], ",", 
   RowBox[{"C", "\[Rule]", 
    FractionBox["1", "50000"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299133625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"fknee", "\[Rule]", "0.2`"}], ",", 
   RowBox[{"R1", "\[Rule]", "300000"}], ",", 
   RowBox[{"R2", "\[Rule]", "40000"}], ",", 
   RowBox[{"C", "\[Rule]", 
    FractionBox["1", "50000"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299133625*^9}],

Cell[BoxData["39788.735772973836`"], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299133625*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"R2", "+", 
   FractionBox["1", 
    RowBox[{"C", " ", "s"}]]}], "R1"]], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299133625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"R1", "\[Rule]", "304301.5236929916`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299352375*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd1nc8ld8fAPBry173Ma5x3XvRsKIkpedTUqHwJSQR0jYyykgqZCcSIaOi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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{0., 
        FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{0., 
        FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {3.912023005428146, 
        FormBox["50", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.214608098422191, 
        FormBox["500", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {8.517193191416238, 
        FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->
   NCache[{{0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
      9.210340371976184, 11.512925464970229`, 0.6931471805599453, 
      1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
      1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.214608098422191, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.517193191416238, 
      8.699514748210191, 8.85366542803745, 8.987196820661973, 
      9.104979856318357, 9.903487552536127, 10.308952660644293`, 
      10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
      11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {0, 
      Log[5], 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`,
       1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
      4.382026634673881, 4.499809670330265, 5.298317366548036, 
      5.703782474656201, 5.991464547107982, 6.396929655216146, 
      6.551080335043404, 6.684611727667927, 6.802394763324311, 
      7.600902459542082, 8.006367567650246, 8.294049640102028}}, {{
     0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
      9.210340371976184, 11.512925464970229`, 0.6931471805599453, 
      1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
      1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
      2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
      3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.214608098422191, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.517193191416238, 
      8.699514748210191, 8.85366542803745, 8.987196820661973, 
      9.104979856318357, 9.903487552536127, 10.308952660644293`, 
      10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
      11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
     0, 1.6094379124341003`, 2.302585092994046, 3.912023005428146, 
      4.605170185988092, 6.214608098422191, 6.907755278982137, 
      8.517193191416238, 0.6931471805599453, 1.0986122886681098`, 
      1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
      2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
      3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
      4.248495242049359, 4.382026634673881, 4.499809670330265, 
      5.298317366548036, 5.703782474656201, 5.991464547107982, 
      6.396929655216146, 6.551080335043404, 6.684611727667927, 
      6.802394763324311, 7.600902459542082, 8.006367567650246, 
      8.294049640102028}}],
  Method->{},
  PlotRange->NCache[{{0, 
      Log[100000]}, {0., 6.907755278982137}}, {{0, 11.512925464970229`}, {0., 
     6.907755278982137}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0, 
      FormBox["1", TraditionalForm]}, {
      NCache[
       Log[5], 1.6094379124341003`], 
      FormBox["5", TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.449707312953125*^9, 3.449707344015625*^9, 3.449707456296875*^9, {
   3.449707515171875*^9, 3.44970755809375*^9}, {3.449707595296875*^9, 
   3.449707641890625*^9}, 3.449707677953125*^9, {3.449707779125*^9, 
   3.44970779390625*^9}, {3.44970783246875*^9, 3.44970786940625*^9}, {
   3.449707907390625*^9, 3.449707964453125*^9}, {3.449708127328125*^9, 
   3.449708156734375*^9}, {3.449708210984375*^9, 3.44970824990625*^9}, {
   3.449708353796875*^9, 3.449708391578125*^9}, {3.449708459296875*^9, 
   3.449708495390625*^9}, 3.449708636984375*^9, {3.449708731609375*^9, 
   3.449708767515625*^9}, 3.449709109734375*^9, 3.4497114719375*^9, 
   3.449711767921875*^9, {3.44971182815625*^9, 3.44971185678125*^9}, {
   3.449711887390625*^9, 3.4497119416875*^9}, 3.44971203575*^9, 
   3.4497124389375*^9, 3.44971259475*^9, 3.449712676640625*^9, {
   3.449713993640625*^9, 3.449714014140625*^9}, 3.4497142016875*^9, {
   3.4497142764375*^9, 3.449714302015625*^9}, {3.449714846171875*^9, 
   3.449714853671875*^9}, 3.449715065609375*^9, {3.4497152324375*^9, 
   3.449715249453125*^9}, {3.449715676109375*^9, 3.44971571003125*^9}, {
   3.449715940328125*^9, 3.449715949671875*^9}, {3.449716049046875*^9, 
   3.449716071890625*^9}, {3.44971667103125*^9, 3.449716697296875*^9}, {
   3.449716889640625*^9, 3.449716903921875*^9}, 3.449717012828125*^9, 
   3.4501367950923915`*^9, 3.450186582243*^9, 3.450189038039875*^9, 
   3.450293679390625*^9, 3.450455299618*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", "op1", "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "1."}]}]}], " ", "//.", 
   "prm2"}], "/.", "fr"}]], "Input",
 CellChangeTimes->{{3.449716327890625*^9, 3.4497163343125*^9}}],

Cell[BoxData["0.13334375567062173`"], "Output",
 CellChangeTimes->{3.44971633475*^9, 3.449716692234375*^9, 
  3.4501367950611415`*^9, 3.450186582164875*^9, 3.450189037993*^9, 
  3.450189095477375*^9, 3.45029367990625*^9, 3.45045529971175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", "op2", "]"}], " ", 
         RowBox[{"OpAmpNoise", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "R1", ",", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"s", " ", "C"}]], "+", "R2"}], ",", "en", ",", "in"}], 
          "]"}]}], "/.", 
        RowBox[{"LT1012", "[", "f", "]"}]}], "//.", "prm2"}], "/.", "fr"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", "op2", "]"}], "//.", "prm2"}], "/.", "fr"}], 
         ")"}], "1*^9", 
        RowBox[{"Abs", "[", "op1", "]"}], " ", 
        RowBox[{"OpAmpNoise", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "R1", ",", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"s", " ", "C"}]], "+", "R2"}], ",", "en", ",", "in"}], 
         "]"}]}], "/.", 
       RowBox[{"OP27", "[", "f", "]"}]}], "/.", "prm"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1*^5"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency[Hz]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10000"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449715183015625*^9, 3.449715223765625*^9}, {
  3.449715294375*^9, 3.44971539059375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd1nc4Vu8fB3B7PY89H/sZtERGVuV8ykgUIiQlCcmMjPIVqZDIJmRUaFhR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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwd1Xk41U8XAHBELtkvca13F8mWkGhO+SUhRFSSJFmylbWQIlkiEkoiKi1C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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Frequency[Hz]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{
    0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
     9.210340371976184, 11.512925464970229`, 0.6931471805599453, 
     1.0986122886681098`, 1.3862943611198906`, 1.6094379124341003`, 
     1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
     2.1972245773362196`, 2.995732273553991, 3.4011973816621555`, 
     3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.214608098422191, 6.396929655216146, 6.551080335043404, 
     6.684611727667927, 6.802394763324311, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
    0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
     9.210340371976184, 0.6931471805599453, 1.0986122886681098`, 
     1.3862943611198906`, 1.6094379124341003`, 1.791759469228055, 
     1.9459101490553132`, 2.0794415416798357`, 2.1972245773362196`, 
     2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
     3.912023005428146, 4.0943445622221, 4.248495242049359, 4.382026634673881,
      4.499809670330265, 5.298317366548036, 5.703782474656201, 
     5.991464547107982, 6.214608098422191, 6.396929655216146, 
     6.551080335043404, 6.684611727667927, 6.802394763324311, 
     7.600902459542082, 8.006367567650246, 8.294049640102028, 
     8.517193191416238, 8.699514748210191, 8.85366542803745, 
     8.987196820661973, 9.104979856318357}},
  Method->{},
  PlotRange->NCache[{{0, 
      Log[100000]}, {0., 9.210340371976184}}, {{0, 11.512925464970229`}, {0., 
     9.210340371976184}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.44971518609375*^9, 3.449715224421875*^9}, {
   3.449715310875*^9, 3.449715391578125*^9}, 3.44971595521875*^9, 
   3.44971670409375*^9, 3.449717017203125*^9, 3.4501367957955165`*^9, 
   3.450186583352375*^9, 3.45018903902425*^9, 3.45029368028125*^9, 
   3.450455300258625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"t1", "=", 
   RowBox[{
    RowBox[{"op1", "//.", "prm"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"op2", "//.", "prm3"}], "/.", "fr"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"20", "t1", " ", "t2", " ", 
    RowBox[{"OpAmpDrv", "[", "0", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "0.1", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Brown"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.44971572034375*^9, 3.449715819703125*^9}, {
   3.449715975234375*^9, 3.449715977046875*^9}, {3.44971609128125*^9, 
   3.4497161065625*^9}, {3.449716432203125*^9, 3.4497164475*^9}, {
   3.44971648696875*^9, 3.44971654540625*^9}, {3.4497167371875*^9, 
   3.449716740578125*^9}, 3.449716794359375*^9, {3.449716982859375*^9, 
   3.44971699*^9}, {3.44971703675*^9, 3.449717038578125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwl1Ps31GkAx/HxNRSzm0u2UsS0wzphZmjkMpfvk7SpmGjqTHSjmnFLshWN
1ZTkkj1aM9HFsdG0m5PKFLHd1vOkC4k47VBIqbHKLcY9g/bZsz98zvu8/oEP
fXfcJglBoVCEeP810HqR+lYMgSI4dVYpa7hgfyZkNkQSqCz+QUsbyQU5E9LS
TxICWYQYjnN8uEDTXHHDLoxA4wmswF4mF4QqRdezNxMoOXLP7pBFXCCl/Xo1
ik8gZBi8YV2fD5DPGP1ONyOQ7wELdrzCB6jfj5xXlBmgJytLTHrfegPrfDuH
dz0U1JgaOpsQ7gX0xkWHZEwKEqpCPjVRPUF5g+JyysAsrF79U5Cq0gMcj01V
9e2cgbe4tHzvLRzAT1jqNNirh36CEcE2qxXAZFfIcIN4Ctoq5KzyajfQ6PrP
K+P6SXjfxWNnZgobpEkW+7WGTkBn88lW3yomWH90cDS9bgzatvx5ynC7C6DM
xrq82DwKu3KUbQMrloObe/nH4rqHIXkz2GaNoxOIu3Z9Qf9WHWz+zu/S/GkH
wKvMiqLWD8IpVunEUyoD3G3WMz8W98P13pK6K0N04PJwnrNc2QOjRbaSoC47
IJcf4viXdUPz2+9ttgtswGe9dU3tGS1sqcwppIUuAoINlhHJJZ1Q3N4T/+ax
FQityLVvMGqHdWZBF54PmAP6Pv9OE40G2jatokyFmYLg7NWHQ6xfwEfyyp+L
4gxBq++YUKZ4CBerOyhrWyfIzK+1iXmyYjguKpVdK9SScwIdPyREXCGlPAux
yWQj7JcYl/xIqyYpGX2XDCxH4AKdp1Rb3ECyDyuZbBUFafkVsy+XNpMP7BmF
mpi5aFOfaceGgHbyftPVSt1Cc3Q8aUeQOqOTXNF11P55zXzkDcecThRryTM1
m6pa3yxEFu7cUbqym7R7YpSkerQEjb5+m/nt/h4yceSO0Va1HboHfXN9M/vJ
gnnPGk/MWYaKNCKlX+wgmZifui+JzkC3c5WG/v468kjTSnI8yRE5tQR7bobD
JHg10FhR5YQuuaGNxqxRMksVNvTHXGdEu3H6+46/xsjn59QZruddURosP7DY
fYJ8KRPXbJ3DRkM6L1nyk0mSEx20ZVLqhsIFsdKTwVNknkHhkZ5n7ugDfbJ+
uFpP9qk+c3m2HCRy0H5OE82QbuqzSal5HkgDGVnHns2S4YLTHcT0SuR6zzTN
zIYCBPr0grPhXiiSUa7SfaAAy8efQm71eSPnNuOZ9AIDcHF9XYAijIs+FppW
lEoIMMbYv7zwCw/VNw+jp9hV3efFTdhltPb6t9hr6/4+aTDFQ/LEa13zpAQ4
NCZ7twfbamOAVRw2VZOR56TnITCbfZAVQQCP+KvUsmkeyt9u4X4zkgDpDGLw
8VceOq78wq/FzjnNXjqOLal9v64Te75FXOAPFD5ic8rCzaMIsHenzfVT2DU0
keIANtXSK1powEej93KH2NEEiCk42POK4KO2oeRpf+ywmMvWJoZ8BB0lc8Ox
nYXadT7YWUoPewW2o/BMSQE2Pbplow47m3V7XziVj4yLqraZxBCAmbf3NyV2
f/OVCDq2+BuHF4+w76xKPBaMvYTZwnI04qOLibt+icJe9vppmBg79cbacynY
GcoaRSZ2pJZ1+QI2dcfr6rvYwv//DAR4fhnpxf4X5FtQlg==
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-2.3025849990109806`, -29.023116348594428`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[2], -0.6931471805599453], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[5], -1.6094379124341003`], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[10], -2.302585092994046], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[2], -0.6931471805599453], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[5], -1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[10], -2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{0, -Log[2], 
          Log[2], -Log[5], 
          Log[5], -Log[10], 
          Log[10], 
          Log[20], 
          Log[
          50], -1.2039728043259361`, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
          1.0986122886681098`, 1.3862943611198906`, 1.791759469228055, 
          1.9459101490553132`, 2.0794415416798357`, 2.1972245773362196`, 
          3.4011973816621555`, 3.6888794541139363`}, Automatic}, {{
         0, -0.6931471805599453, 0.6931471805599453, -1.6094379124341003`, 
          1.6094379124341003`, -2.302585092994046, 2.302585092994046, 
          2.995732273553991, 
          3.912023005428146, -1.2039728043259361`, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 1.0986122886681098`, 1.3862943611198906`, 
          1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
          2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{-2.3025849990109806`, 
       2.302584999010981}, {-29.023116348594428`, 27.271500872961408`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[2], -0.6931471805599453], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[2], 0.6931471805599453], 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[5], -1.6094379124341003`], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[5], 1.6094379124341003`], 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[10], -2.302585092994046], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[10], 2.302585092994046], 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.2039728043259361`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwl2Hc8Vf8fB3BuRlGSECp7ZUZWSocSKpRIyOG6RoiMipQuQslIVpK+JQ0S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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-2.3025849990109806`, -161.20617249153742`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[2], -0.6931471805599453], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[5], -1.6094379124341003`], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[-Log[10], -2.302585092994046], 
           FormBox[
            TagBox[
             InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[2], -0.6931471805599453], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[5], -1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[-Log[10], -2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {-1.2039728043259361`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{0, -Log[2], 
          Log[2], -Log[5], 
          Log[5], -Log[10], 
          Log[10], 
          Log[20], 
          Log[
          50], -1.2039728043259361`, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
          1.0986122886681098`, 1.3862943611198906`, 1.791759469228055, 
          1.9459101490553132`, 2.0794415416798357`, 2.1972245773362196`, 
          3.4011973816621555`, 3.6888794541139363`}, Automatic}, {{
         0, -0.6931471805599453, 0.6931471805599453, -1.6094379124341003`, 
          1.6094379124341003`, -2.302585092994046, 2.302585092994046, 
          2.995732273553991, 
          3.912023005428146, -1.2039728043259361`, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 1.0986122886681098`, 1.3862943611198906`, 
          1.791759469228055, 1.9459101490553132`, 2.0794415416798357`, 
          2.1972245773362196`, 3.4011973816621555`, 3.6888794541139363`}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{-2.3025849990109806`, 
       2.302584999010981}, {-161.20617249153742`, -116.3639721804311}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[2], -0.6931471805599453], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[2], 0.6931471805599453], 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[5], -1.6094379124341003`], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[5], 1.6094379124341003`], 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[-Log[10], -2.302585092994046], 
          FormBox[
           TagBox[
            InterpretationBox["\"0.1\"", 0.1, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[10], 2.302585092994046], 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.2039728043259361`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.449715764828125*^9, 3.449715769890625*^9}, 
   3.449715820484375*^9, {3.449715959234375*^9, 3.44971597746875*^9}, {
   3.44971608340625*^9, 3.44971610709375*^9}, {3.449716441078125*^9, 
   3.4497164485*^9}, {3.449716493421875*^9, 3.44971654590625*^9}, 
   3.44971670834375*^9, 3.449716741125*^9, 3.44971679521875*^9, {
   3.4497169834375*^9, 3.449717039078125*^9}, 3.4501367960142665`*^9, 
   3.45018658364925*^9, 3.45018903927425*^9, 3.450293680484375*^9, 
   3.450455300508625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bias Setpoints", "Subtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}, {3.449520988499125*^9, 3.44952099113975*^9}, {
  3.449521640342875*^9, 3.4495216478585*^9}, {3.44971693896875*^9, 
  3.449716959453125*^9}, {3.449777844484375*^9, 3.449777849953125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"set", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SuperscriptBox["10", 
      FractionBox["i", 
       RowBox[{"20", " ", "5."}]]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"12", "*", "10"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dac", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "set"}], "*", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["2", "16"], "-", "1"}], ")"}]}], "//", "Round"}], "//", 
   "Reverse"}]}]}], "Input",
 CellChangeTimes->{{3.450186498789875*^9, 3.450186505696125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4231", ",", "4330", ",", "4431", ",", "4534", ",", "4640", ",", "4748", 
   ",", "4858", ",", "4971", ",", "5087", ",", "5206", ",", "5327", ",", 
   "5451", ",", "5578", ",", "5708", ",", "5841", ",", "5977", ",", "6116", 
   ",", "6259", ",", "6404", ",", "6554", ",", "6706", ",", "6862", ",", 
   "7022", ",", "7186", ",", "7353", ",", "7524", ",", "7700", ",", "7879", 
   ",", "8063", ",", "8250", ",", "8443", ",", "8639", ",", "8840", ",", 
   "9046", ",", "9257", ",", "9473", ",", "9693", ",", "9919", ",", "10150", 
   ",", "10387", ",", "10629", ",", "10876", ",", "11129", ",", "11389", ",", 
   "11654", ",", "11925", ",", "12203", ",", "12487", ",", "12778", ",", 
   "13076", ",", "13381", ",", "13692", ",", "14011", ",", "14337", ",", 
   "14671", ",", "15013", ",", "15363", ",", "15721", ",", "16087", ",", 
   "16462", ",", "16845", ",", "17237", ",", "17639", ",", "18050", ",", 
   "18470", ",", "18901", ",", "19341", ",", "19791", ",", "20252", ",", 
   "20724", ",", "21207", ",", "21701", ",", "22206", ",", "22723", ",", 
   "23253", ",", "23794", ",", "24349", ",", "24916", ",", "25496", ",", 
   "26090", ",", "26698", ",", "27320", ",", "27956", ",", "28607", ",", 
   "29273", ",", "29955", ",", "30653", ",", "31367", ",", "32098", ",", 
   "32845", ",", "33610", ",", "34393", ",", "35194", ",", "36014", ",", 
   "36853", ",", "37711", ",", "38590", ",", "39489", ",", "40409", ",", 
   "41350", ",", "42313", ",", "43299", ",", "44307", ",", "45339", ",", 
   "46395", ",", "47476", ",", "48582", ",", "49713", ",", "50871", ",", 
   "52056", ",", "53269", ",", "54510", ",", "55779", ",", "57079", ",", 
   "58408", ",", "59769", ",", "61161", ",", "62585", ",", "64043", ",", 
   "65535"}], "}"}]], "Output",
 CellChangeTimes->{3.45018650658675*^9, 3.450186583789875*^9, 
  3.450189039383625*^9, 3.450293680546875*^9, 3.450455300602375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AM Stabilization Servo Compensation Network", "Subtitle",
 CellChangeTimes->{{3.449451243140625*^9, 3.4494512805625*^9}, {
  3.449454373078125*^9, 3.4494543785*^9}, {3.4495147419835*^9, 
  3.449514745467875*^9}, {3.449520988499125*^9, 3.44952099113975*^9}, {
  3.449521640342875*^9, 3.4495216478585*^9}, {3.44971693896875*^9, 
  3.449716959453125*^9}, {3.4501351906705165`*^9, 3.4501351955298915`*^9}}],

Cell["Voltage Controlled Attenuator", "Subsubtitle",
 CellChangeTimes->{{3.4501423208736415`*^9, 3.4501423347330165`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VCApole", "=", 
  FractionBox["1", 
   RowBox[{"2", "\[Pi]", " ", "0.2*^-6", " "}]]}]], "Input",
 CellChangeTimes->{{3.4501424933580165`*^9, 3.4501425431705165`*^9}, {
  3.4501426220142665`*^9, 3.4501426297642665`*^9}, {3.4501426716548915`*^9, 
  3.4501426857173915`*^9}, {3.4501427358267665`*^9, 3.4501427368736415`*^9}}],

Cell[BoxData["795774.7154594767`"], "Output",
 CellChangeTimes->{{3.4501426257173915`*^9, 3.4501426301548915`*^9}, 
   3.4501426864986415`*^9, 3.4501427383111415`*^9, 3.450186583789875*^9, 
   3.450189039414875*^9, 3.4502936805625*^9, 3.450455300618*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"VCAactuator", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"15", ",", 
       RowBox[{"-", "1.9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "12.1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.7", ",", 
       RowBox[{"-", "22.4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.5", ",", 
       RowBox[{"-", "28"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.4", ",", 
       RowBox[{"-", "35"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.3", ",", 
       RowBox[{"-", "42.5"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4501352042173915`*^9, 3.4501352800298915`*^9}, {
   3.4501354643736415`*^9, 3.4501354647330165`*^9}, 3.4501355368736415`*^9, {
   3.4501359357486415`*^9, 3.4501359460767665`*^9}, {3.4501360175298915`*^9, 
   3.4501361254517665`*^9}, 3.4501373647642665`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"VCAfit", "[", "x_", "]"}], "=", 
  RowBox[{"Fit", "[", 
   RowBox[{"VCAactuator", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RadicalBox[
       RowBox[{"x", "-", "2.2"}], "2"], ",", 
      RadicalBox[
       RowBox[{"x", "-", "2.2"}], "4"], ",", 
      RadicalBox[
       RowBox[{"x", "-", "2.2"}], "6"], ",", 
      RadicalBox[
       RowBox[{"x", "-", "2.2"}], "8"]}], "}"}], ",", "x"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.4501362087642665`*^9, 3.4501362472330165`*^9}, {
  3.4501364643736415`*^9, 3.4501365184986415`*^9}, {3.4501365555455165`*^9, 
  3.4501366207798915`*^9}, {3.4501366556392665`*^9, 3.4501366594205165`*^9}, {
  3.4501367049673915`*^9, 3.4501367343267665`*^9}, {3.4501376516861415`*^9, 
  3.4501376552017665`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "355.95296727871107`"}], "+", 
  RowBox[{"1352.2947873853798`", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2.2`"}], "+", "x"}], ")"}], 
    RowBox[{"1", "/", "8"}]]}], "-", 
  RowBox[{"1087.0578297495808`", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2.2`"}], "+", "x"}], ")"}], 
    RowBox[{"1", "/", "6"}]]}], "+", 
  RowBox[{"65.0965928109494`", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2.2`"}], "+", "x"}], ")"}], 
    RowBox[{"1", "/", "4"}]]}], "+", 
  RowBox[{"9.433075251842903`", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"-", "2.2`"}], "+", "x"}]]}]}]], "Output",
 CellChangeTimes->{{3.4501362158892665`*^9, 3.4501362476548915`*^9}, {
   3.4501364649673915`*^9, 3.4501365193892665`*^9}, {3.4501365805298915`*^9, 
   3.4501366211861415`*^9}, 3.4501366598423915`*^9, {3.4501367057642665`*^9, 
   3.4501367347486415`*^9}, 3.4501367961548915`*^9, 3.4501373677955165`*^9, 
   3.4501376559361415`*^9, 3.450186583993*^9, 3.450189039493*^9, 
   3.45029368075*^9, 3.4504553009305*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{"VCAactuator", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", " ", "[", "0.03", "]"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "15.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Voltage [V]\>\"", ",", "\"\<Attenuation [dB]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}], ",", 
   RowBox[{"LogLinearPlot", "[", 
    RowBox[{
     RowBox[{"VCAfit", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "15"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4501354967955165`*^9, 3.4501355273580165`*^9}, {
   3.4501358032798915`*^9, 3.4501358489048915`*^9}, 3.4501366372955165`*^9, {
   3.4501368323423915`*^9, 3.4501369004986415`*^9}, {3.4501369308580165`*^9, 
   3.4501369345767665`*^9}, {3.4501374345455165`*^9, 3.4501374969048915`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[1, 0, 0], PointSize[0.03], 
     PointBox[{{2.70805020110221, -1.9}, {1.791759469228055, -6.}, {
      1.6094379124341003`, -9.}, {1.3862943611198906`, -12.1}, {
      1.0986122886681098`, -18.}, {0.9932517730102834, -22.4}, {
      0.9162907318741551, -28.}, {0.8754687373538999, -35.}, {
      0.8329091229351039, -42.5}}]}, {}}, {{}, {}, 
    {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwd0Hk8VPsfBvCxJkVEQsma7VIzmaZBfAaVfc2eK9ySe6mQrXSzXJVWskQi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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.6931471805599453, -50},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Voltage [V]\"", TraditionalForm], 
    FormBox["\"Attenuation [dB]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.0986122886681098`, 
       FormBox[
        TagBox[
         InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.4011973816621555`, 
       FormBox[
        TagBox[
         InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.4054651081081644, 
       FormBox[
        TagBox[
         InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.70805020110221, 
       FormBox[
        TagBox[
         InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.9459101490553132`, 
       FormBox[
        TagBox[
         InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {4.248495242049359, 
       FormBox[
        TagBox[
         InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
       FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
       FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->
   NCache[{{
     0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
      0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
      3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
      1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
      0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
      0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
      0.6418538861723948, 
      Log[4], 
      Log[6], 2.0794415416798357`, 2.1972245773362196`, 2.3978952727983707`, 
      2.4849066497880004`, 2.5649493574615367`, 2.6390573296152584`, 
      2.772588722239781, 2.833213344056216, 2.8903717578961645`, 
      2.9444389791664403`, 
      Log[40], 
      Log[60]}, Automatic}, {{0., 2.302585092994046, 1.6094379124341003`, 
     3.912023005428146, 0.6931471805599453, 2.995732273553991, 
     1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
     2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
     0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
     0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
     0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
     1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
     2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
     2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
     2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
     4.0943445622221}, Automatic}],
  Method->{},
  PlotRange->{{0.6931471805599453, 2.7212954278522306`}, {-50, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.0\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.0\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"2.0\"", 2., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.0986122886681098`, 
      FormBox[
       TagBox[
        InterpretationBox["\"3.0\"", 3., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.4011973816621555`, 
      FormBox[
       TagBox[
        InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.4054651081081644, 
      FormBox[
       TagBox[
        InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.70805020110221, 
      FormBox[
       TagBox[
        InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.9459101490553132`, 
      FormBox[
       TagBox[
        InterpretationBox["\"7.0\"", 7., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {4.248495242049359, 
      FormBox[
       TagBox[
        InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.09531017980432493, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.1823215567939548, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.26236426446749106`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.336472236621213, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.47000362924573563`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5306282510621705, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5877866649021191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6418538861723948, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[4], 1.3862943611198906`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[6], 1.791759469228055], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.3978952727983707`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.5649493574615367`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.6390573296152584`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.772588722239781, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.833213344056216, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.8903717578961645`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.9444389791664403`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[40], 3.6888794541139363`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[60], 4.0943445622221], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.4501355006548915`*^9, 3.4501355601861415`*^9}, {
   3.4501357298267665`*^9, 3.4501358493580165`*^9}, 3.4501359495923915`*^9, {
   3.4501360957017665`*^9, 3.4501361537798915`*^9}, {3.4501362178111415`*^9, 
   3.4501362500923915`*^9}, 3.4501364658736415`*^9, {3.4501364962955165`*^9, 
   3.4501365216236415`*^9}, {3.4501365849361415`*^9, 
   3.4501366619986415`*^9}, {3.4501367079673915`*^9, 3.4501367366080165`*^9}, 
   3.4501367962017665`*^9, {3.4501368621861415`*^9, 3.4501369355142665`*^9}, 
   3.4501373685298915`*^9, {3.4501374743267665`*^9, 3.4501374972486415`*^9}, 
   3.4501376579361415`*^9, 3.45018658408675*^9, 3.45018903958675*^9, 
   3.45029368084375*^9, 3.450455301039875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wpoint", "=", 
   RowBox[{"-", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wrange", "=", "24"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wabs", "=", "3.55"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"24", "dBm"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"wvolt", "=", 
   RowBox[{"x", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"VCAfit", "[", "x", "]"}], "\[Equal]", "wpoint"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "5"}], "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"wvolt2", "=", 
  RowBox[{"x", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"VCAfit", "[", "x", "]"}], "\[Equal]", 
      RowBox[{"wpoint", "-", "wrange"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "5"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"wabs", " ", 
     RowBox[{"FromdB", "[", 
      RowBox[{"VCAfit", "[", "x", "]"}], "]"}]}], ",", "x"}], "]"}], "/.", 
  RowBox[{"x", "\[Rule]", "wvolt"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"wabs", " ", 
     RowBox[{"FromdB", "[", 
      RowBox[{"VCAfit", "[", "x", "]"}], "]"}]}], ",", "x"}], "]"}], "/.", 
  RowBox[{"x", "\[Rule]", "wvolt2"}]}], "\[IndentingNewLine]", 
 RowBox[{"wmax", "=", 
  RowBox[{"FindMaximum", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"wabs", " ", 
       RowBox[{"FromdB", "[", 
        RowBox[{"VCAfit", "[", "x", "]"}], "]"}]}], ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4501376788267665`*^9, 3.4501377623736415`*^9}, {
   3.4501377970611415`*^9, 3.4501379490455165`*^9}, {3.4501380003111415`*^9, 
   3.4501380092486415`*^9}, {3.4501380549986415`*^9, 
   3.4501380568736415`*^9}, {3.4501387610767665`*^9, 
   3.4501388380298915`*^9}, {3.4501388706548915`*^9, 
   3.4501388805767665`*^9}, {3.4501395370142665`*^9, 
   3.4501395736705165`*^9}, {3.4501396865611415`*^9, 
   3.4501396876080165`*^9}, {3.4501398511548915`*^9, 
   3.4501398517955165`*^9}, {3.4501469242173915`*^9, 
   3.4501469879205165`*^9}, {3.4501470638892665`*^9, 
   3.4501470832642665`*^9}, {3.4501471133111415`*^9, 
   3.4501471523580165`*^9}, {3.4501472159830165`*^9, 
   3.4501472285767665`*^9}, {3.450207221539875*^9, 3.450207270383625*^9}, {
   3.450207370946125*^9, 3.45020738014925*^9}, {3.450455268571125*^9, 
   3.450455268727375*^9}, {3.45045584808675*^9, 3.450455863118*^9}, {
   3.450456292039875*^9, 3.450456293727375*^9}, {3.4504564100555*^9, 
   3.45045642896175*^9}, 3.450456508727375*^9, {3.450463158321125*^9, 
   3.4504631666805*^9}, {3.45046321877425*^9, 3.450463255118*^9}}],

Cell[BoxData["5.237891399761838`"], "Output",
 CellChangeTimes->{
  3.4501396882486415`*^9, 3.4501398523892665`*^9, 3.4501401113892665`*^9, 
   3.4501469832173915`*^9, {3.4501471337173915`*^9, 3.4501471528111415`*^9}, 
   3.4501472290455165`*^9, 3.450186584102375*^9, 3.450189039633625*^9, {
   3.450207222071125*^9, 3.4502072710555*^9}, {3.45020737114925*^9, 
   3.450207380352375*^9}, 3.450293680875*^9, 3.45045530108675*^9, {
   3.450455848743*^9, 3.450455863977375*^9}, 3.450456295321125*^9, {
   3.4504564105555*^9, 3.45045642983675*^9}, 3.45045650977425*^9, 
   3.45046316714925*^9, {3.4504632329305*^9, 3.4504632559305*^9}}],

Cell[BoxData["2.427969614250858`"], "Output",
 CellChangeTimes->{
  3.4501396882486415`*^9, 3.4501398523892665`*^9, 3.4501401113892665`*^9, 
   3.4501469832173915`*^9, {3.4501471337173915`*^9, 3.4501471528111415`*^9}, 
   3.4501472290455165`*^9, 3.450186584102375*^9, 3.450189039633625*^9, {
   3.450207222071125*^9, 3.4502072710555*^9}, {3.45020737114925*^9, 
   3.450207380352375*^9}, 3.450293680875*^9, 3.45045530108675*^9, {
   3.450455848743*^9, 3.450455863977375*^9}, 3.450456295321125*^9, {
   3.4504564105555*^9, 3.45045642983675*^9}, 3.45045650977425*^9, 
   3.45046316714925*^9, {3.4504632329305*^9, 3.450463255946125*^9}}],

Cell[BoxData["0.31563340720009675`"], "Output",
 CellChangeTimes->{
  3.4501396882486415`*^9, 3.4501398523892665`*^9, 3.4501401113892665`*^9, 
   3.4501469832173915`*^9, {3.4501471337173915`*^9, 3.4501471528111415`*^9}, 
   3.4501472290455165`*^9, 3.450186584102375*^9, 3.450189039633625*^9, {
   3.450207222071125*^9, 3.4502072710555*^9}, {3.45020737114925*^9, 
   3.450207380352375*^9}, 3.450293680875*^9, 3.45045530108675*^9, {
   3.450455848743*^9, 3.450455863977375*^9}, 3.450456295321125*^9, {
   3.4504564105555*^9, 3.45045642983675*^9}, 3.45045650977425*^9, 
   3.45046316714925*^9, {3.4504632329305*^9, 3.450463255977375*^9}}],

Cell[BoxData["0.5586090916230781`"], "Output",
 CellChangeTimes->{
  3.4501396882486415`*^9, 3.4501398523892665`*^9, 3.4501401113892665`*^9, 
   3.4501469832173915`*^9, {3.4501471337173915`*^9, 3.4501471528111415`*^9}, 
   3.4501472290455165`*^9, 3.450186584102375*^9, 3.450189039633625*^9, {
   3.450207222071125*^9, 3.4502072710555*^9}, {3.45020737114925*^9, 
   3.450207380352375*^9}, 3.450293680875*^9, 3.45045530108675*^9, {
   3.450455848743*^9, 3.450455863977375*^9}, 3.450456295321125*^9, {
   3.4504564105555*^9, 3.45045642983675*^9}, 3.45045650977425*^9, 
   3.45046316714925*^9, {3.4504632329305*^9, 3.450463255977375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6185976905342218`", ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "2.690426841162246`"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.4501396882486415`*^9, 3.4501398523892665`*^9, 3.4501401113892665`*^9, 
   3.4501469832173915`*^9, {3.4501471337173915`*^9, 3.4501471528111415`*^9}, 
   3.4501472290455165`*^9, 3.450186584102375*^9, 3.450189039633625*^9, {
   3.450207222071125*^9, 3.4502072710555*^9}, {3.45020737114925*^9, 
   3.450207380352375*^9}, 3.450293680875*^9, 3.45045530108675*^9, {
   3.450455848743*^9, 3.450455863977375*^9}, 3.450456295321125*^9, {
   3.4504564105555*^9, 3.45045642983675*^9}, 3.45045650977425*^9, 
   3.45046316714925*^9, {3.4504632329305*^9, 3.450463255977375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", " ", 
  RowBox[{
   RowBox[{"FromdB", "[", 
    RowBox[{"VCAfit", "[", "x", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "2", ",", "15"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "15"}], "}"}], ",", "All"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Voltage [V]\>\"", ",", "\"\<Attenuation\>\""}], "}"}]}], 
   ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501380676236415`*^9, 3.4501381408736415`*^9}, {
   3.4501384616548915`*^9, 3.4501385134517665`*^9}, {3.4501389257486415`*^9, 
   3.4501389275767665`*^9}, {3.4501472791392665`*^9, 3.4501472796861415`*^9}, 
   3.4501473485923915`*^9, {3.450456603477375*^9, 3.4504566176805*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Gs81PkCBnCG0YR121IKEZsuWOSW2/NfnNIFaVunQmSxlSa3dArlUqnG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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.6931471805599453, 1.0535827475851158`*^-10},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Voltage [V]\"", TraditionalForm], 
    FormBox["\"Attenuation\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.0986122886681098`, 
       FormBox[
        TagBox[
         InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.4011973816621555`, 
       FormBox[
        TagBox[
         InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.4054651081081644, 
       FormBox[
        TagBox[
         InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.70805020110221, 
       FormBox[
        TagBox[
         InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.9459101490553132`, 
       FormBox[
        TagBox[
         InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {4.248495242049359, 
       FormBox[
        TagBox[
         InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
       FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
       FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->
   NCache[{{0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
      0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
      3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
      1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
      0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
      0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
      0.6418538861723948, 
      Log[4], 
      Log[6], 2.0794415416798357`, 2.1972245773362196`, 2.3978952727983707`, 
      2.4849066497880004`, 2.5649493574615367`, 2.6390573296152584`, 
      2.772588722239781, 2.833213344056216, 2.8903717578961645`, 
      2.9444389791664403`, 
      Log[40], 
      Log[60]}, Automatic}, {{0., 2.302585092994046, 1.6094379124341003`, 
     3.912023005428146, 0.6931471805599453, 2.995732273553991, 
     1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
     2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
     0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
     0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
     0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
     1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
     2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
     2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
     2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
     4.0943445622221}, Automatic}],
  Method->{},
  PlotRange->{{0.6931471805599453, 2.70805020110221}, {
   1.0535827475851158`*^-10, 0.808421543559309}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, 
    Scaled[0.02]},
  Ticks->{{{0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.0\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.0\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"2.0\"", 2., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.0986122886681098`, 
      FormBox[
       TagBox[
        InterpretationBox["\"3.0\"", 3., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.4011973816621555`, 
      FormBox[
       TagBox[
        InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.4054651081081644, 
      FormBox[
       TagBox[
        InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.70805020110221, 
      FormBox[
       TagBox[
        InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.9459101490553132`, 
      FormBox[
       TagBox[
        InterpretationBox["\"7.0\"", 7., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {4.248495242049359, 
      FormBox[
       TagBox[
        InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.09531017980432493, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.1823215567939548, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.26236426446749106`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.336472236621213, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.47000362924573563`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5306282510621705, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5877866649021191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6418538861723948, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[4], 1.3862943611198906`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[6], 1.791759469228055], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.3978952727983707`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.5649493574615367`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.6390573296152584`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.772588722239781, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.833213344056216, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.8903717578961645`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.9444389791664403`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[40], 3.6888794541139363`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[60], 4.0943445622221], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.4501380870923915`*^9, 3.4501381417642665`*^9}, {
   3.4501384662642665`*^9, 3.4501385140923915`*^9}, 3.4501389283736415`*^9, 
   3.4501401146548915`*^9, 3.4501472802330165`*^9, 3.4501473512330165`*^9, 
   3.4501865841805*^9, 3.45018903996175*^9, 3.4502936809375*^9, 
   3.450455301164875*^9, {3.450455850368*^9, 3.450455865758625*^9}, 
   3.450456301602375*^9, 3.45045641314925*^9, 3.45045651114925*^9, {
   3.450456604321125*^9, 3.450456618321125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"LogLinearPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"wabs", " ", 
        RowBox[{"FromdB", "[", 
         RowBox[{"VCAfit", "[", "y", "]"}], "]"}]}], ",", "y"}], "]"}], "/.", 
     
     RowBox[{"y", "\[Rule]", "x"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "2", ",", "15"}], "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "15"}], "}"}], ",", "All"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
      "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Voltage [V]\>\"", ",", "\"\<Volt/Volt\>\""}], "}"}]}], ",",
     
    RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4501380676236415`*^9, 3.4501382358892665`*^9}, {
   3.4501382665142665`*^9, 3.4501382809048915`*^9}, {3.4501383131548915`*^9, 
   3.4501383629361415`*^9}, {3.4501383952330165`*^9, 
   3.4501384394673915`*^9}, {3.4501384740298915`*^9, 
   3.4501384890455165`*^9}, {3.4501385727330165`*^9, 3.4501385752017665`*^9}, 
   3.4501422426236415`*^9, {3.4501473576705165`*^9, 3.4501473633580165`*^9}, 
   3.45045638939925*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nc8lt0fB3CzUCGJ1lORRI8QTdTnLkWFREXD0zRCyYiyKzIyHnlKw2qJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.6931471805599453, 0.00010852779853953342`},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Voltage [V]\"", TraditionalForm], 
    FormBox["\"Volt/Volt\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.0986122886681098`, 
       FormBox[
        TagBox[
         InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {3.4011973816621555`, 
       FormBox[
        TagBox[
         InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.4054651081081644, 
       FormBox[
        TagBox[
         InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {2.70805020110221, 
       FormBox[
        TagBox[
         InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.9459101490553132`, 
       FormBox[
        TagBox[
         InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {4.248495242049359, 
       FormBox[
        TagBox[
         InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
       FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
       FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939548, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.26236426446749106`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.336472236621213, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.47000362924573563`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5306282510621705, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.5877866649021191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6418538861723948, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[4], 1.3862943611198906`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[6], 1.791759469228055], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.3978952727983707`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[40], 3.6888794541139363`], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {
       NCache[
        Log[60], 4.0943445622221], 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->
   NCache[{{0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
      0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
      3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
      1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
      0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
      0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
      0.6418538861723948, 
      Log[4], 
      Log[6], 2.0794415416798357`, 2.1972245773362196`, 2.3978952727983707`, 
      2.4849066497880004`, 2.5649493574615367`, 2.6390573296152584`, 
      2.772588722239781, 2.833213344056216, 2.8903717578961645`, 
      2.9444389791664403`, 
      Log[40], 
      Log[60]}, Automatic}, {{0., 2.302585092994046, 1.6094379124341003`, 
     3.912023005428146, 0.6931471805599453, 2.995732273553991, 
     1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
     2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
     0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
     0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
     0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
     1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
     2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
     2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
     2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
     4.0943445622221}, Automatic}],
  Method->{},
  PlotRange->{{0.6931471805599453, 2.70805020110221}, {
   0.00010852779853953342`, 0.6185975256478764}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, 
    Scaled[0.02]},
  Ticks->{{{0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.0\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.0\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"2.0\"", 2., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.0986122886681098`, 
      FormBox[
       TagBox[
        InterpretationBox["\"3.0\"", 3., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {3.4011973816621555`, 
      FormBox[
       TagBox[
        InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.4054651081081644, 
      FormBox[
       TagBox[
        InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {2.70805020110221, 
      FormBox[
       TagBox[
        InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.9459101490553132`, 
      FormBox[
       TagBox[
        InterpretationBox["\"7.0\"", 7., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {4.248495242049359, 
      FormBox[
       TagBox[
        InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0.09531017980432493, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.1823215567939548, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.26236426446749106`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.336472236621213, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.47000362924573563`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5306282510621705, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.5877866649021191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6418538861723948, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[4], 1.3862943611198906`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[6], 1.791759469228055], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.3978952727983707`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.5649493574615367`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.6390573296152584`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.772588722239781, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.833213344056216, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.8903717578961645`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.9444389791664403`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[40], 3.6888794541139363`], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {
      NCache[
       Log[60], 4.0943445622221], 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.4501382813267665`*^9, 3.4501382844673915`*^9}, {
   3.4501383145455165`*^9, 3.4501383673580165`*^9}, {3.4501384031392665`*^9, 
   3.4501384401705165`*^9}, {3.4501384751705165`*^9, 3.4501384900142665`*^9}, 
   3.4501385767798915`*^9, 3.4501391194048915`*^9, 3.4501401162486415`*^9, {
   3.4501473592798915`*^9, 3.4501473637955165`*^9}, 3.450186584321125*^9, 
   3.450189040118*^9, 3.450293681046875*^9, 3.450455301289875*^9, {
   3.45045585264925*^9, 3.450455867977375*^9}, 3.45045630439925*^9, {
   3.4504563908055*^9, 3.450456414868*^9}, 3.450456512914875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Detector Transfer Function", "Subsubtitle",
 CellChangeTimes->{{3.4501423208736415`*^9, 3.4501423621236415`*^9}}],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.4501424302642665`*^9, 3.4501424305298915`*^9}, {
  3.4501424667955165`*^9, 3.4501424683267665`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tfreq", "=", 
   RowBox[{
    RowBox[{"1*^3", 
     RowBox[{"{", 
      RowBox[{
      "1000", ",", "\n", "857.696", ",", "\n", "735.642", ",", "\n", 
       "630.957", ",", "\n", "541.17", ",", "\n", "464.159", ",", "\n", 
       "398.107", ",", "\n", "341.455", ",", "\n", "292.864", ",", "\n", 
       "251.189", ",", "\n", "215.443", ",", "\n", "184.785", ",", "\n", 
       "158.489", ",", "\n", "135.936", ",", "\n", "116.591", ",", "\n", 
       "100", ",", "\n", "85.77", ",", "\n", "73.564", ",", "\n", "63.096", 
       ",", "\n", "54.117", ",", "\n", "46.416", ",", "\n", "39.811", ",", 
       "\n", "34.145", ",", "\n", "29.286", ",", "\n", "25.119", ",", "\n", 
       "21.544", ",", "\n", "18.478", ",", "\n", "15.849", ",", "\n", 
       "13.594", ",", "\n", "11.659", ",", "\n", "10", ",", "\n", "1", ",", 
       "\n", "0.1", ",", "\n", "0.01", ",", "\n", "0.001"}], "}"}]}], "//", 
    "Reverse"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dtrans", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"12.37", ",", " ", 
       RowBox[{"-", "178.09"}], ",", "\n", " ", "15.22", ",", " ", 
       RowBox[{"-", "167.47"}], ",", "\n", " ", "17.77", ",", " ", 
       RowBox[{"-", "155.95"}], ",", "\n", " ", "20.12", ",", " ", 
       RowBox[{"-", "144.11"}], ",", "\n", " ", "22.21", ",", " ", 
       RowBox[{"-", "132.29"}], ",", "\n", " ", "24.00", ",", " ", 
       RowBox[{"-", "120.65"}], ",", "\n", " ", "25.57", ",", " ", 
       RowBox[{"-", "109.51"}], ",", "\n", " ", "26.87", ",", " ", 
       RowBox[{"-", "98.01"}], ",", "\n", " ", "28.06", ",", " ", 
       RowBox[{"-", "87.72"}], ",", "\n", " ", "28.97", ",", " ", 
       RowBox[{"-", "77.29"}], ",", "\n", " ", "29.77", ",", " ", 
       RowBox[{"-", "68.27"}], ",", "\n", " ", "30.42", ",", " ", 
       RowBox[{"-", "59.9"}], ",", "\n", " ", "30.91", ",", " ", 
       RowBox[{"-", "52.42"}], ",", "\n", " ", "31.31", ",", " ", 
       RowBox[{"-", "45.61"}], ",", "\n", " ", "31.62", ",", " ", 
       RowBox[{"-", "39.66"}], ",", "\n", " ", "31.79", ",", " ", 
       RowBox[{"-", "34.08"}], ",", "\n", " ", "31.99", ",", " ", 
       RowBox[{"-", "29.24"}], ",", "\n", " ", "32.11", ",", " ", 
       RowBox[{"-", "25.36"}], ",", "\n", " ", "32.18", ",", " ", 
       RowBox[{"-", "22.18"}], ",", "\n", " ", "32.24", ",", " ", 
       RowBox[{"-", "19.24"}], ",", "\n", " ", "32.29", ",", " ", 
       RowBox[{"-", "16.69"}], ",", "\n", " ", "32.31", ",", " ", 
       RowBox[{"-", "14.18"}], ",", "\n", " ", "32.36", ",", " ", 
       RowBox[{"-", "12.09"}], ",", "\n", " ", "32.37", ",", " ", 
       RowBox[{"-", "10.42"}], ",", "\n", " ", "32.40", ",", " ", 
       RowBox[{"-", "9.07"}], ",", "\n", " ", "32.41", ",", " ", 
       RowBox[{"-", "7.82"}], ",", "\n", " ", "32.41", ",", " ", 
       RowBox[{"-", "6.73"}], ",", "\n", " ", "32.42", ",", " ", 
       RowBox[{"-", "5.93"}], ",", "\n", " ", "32.41", ",", " ", 
       RowBox[{"-", "4.98"}], ",", "\n", " ", "32.42", ",", " ", 
       RowBox[{"-", "4.32"}], ",", "\n", " ", "32.43", ",", " ", 
       RowBox[{"-", "3.74"}], ",", "\n", " ", "32.43", ",", " ", 
       RowBox[{"-", "0.374"}], ",", "\n", " ", "32.43", ",", " ", 
       RowBox[{"-", "0.0374"}], ",", "\n", " ", "32.43", ",", " ", 
       RowBox[{"-", "0.00374"}], ",", "\n", " ", "32.43", ",", " ", 
       RowBox[{"-", "0.000374"}]}], "}"}], "~", "Partition", "~", "2"}], "//",
     "Reverse"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4501409089361415`*^9, 3.4501412960142665`*^9}, {
   3.4501415898892665`*^9, 3.4501415911548915`*^9}, {3.4501419137642665`*^9, 
   3.4501419926080165`*^9}, {3.4501420276080165`*^9, 3.4501420473580165`*^9}, 
   3.4501429890455165`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{"tfreq", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FromdB", "[", 
         RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "Degree"}]]}], "}"}], "&"}], "/@", "dtrans"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4501413036705165`*^9, 3.4501415256392665`*^9}, 
   3.4501415978423915`*^9, 3.4501429934986415`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.83116886425838`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.00027305426836688124`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.83116877603105`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.002730542681749123`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"100.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.831159953298325`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.027305424897802376`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", 
     RowBox[{"{", 
      RowBox[{"41.830277683158236`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.273052329293255`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"10000", ",", 
     RowBox[{"{", 
      RowBox[{"41.74208198859699`", "\[InvisibleSpace]", "-", 
       RowBox[{"2.728604017057933`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"11659.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.664326890083466`", "\[InvisibleSpace]", "-", 
       RowBox[{"3.147382677205492`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"13594.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.577412897781294`", "\[InvisibleSpace]", "-", 
       RowBox[{"3.622928389993761`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"15849.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.55944973242575`", "\[InvisibleSpace]", "-", 
       RowBox[{"4.3167454011654325`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18478.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.44738196492393`", "\[InvisibleSpace]", "-", 
       RowBox[{"4.89095099600388`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"21544.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.34684168275326`", "\[InvisibleSpace]", "-", 
       RowBox[{"5.678517082209997`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"25119.`", ",", 
     RowBox[{"{", 
      RowBox[{"41.165704994934764`", "\[InvisibleSpace]", "-", 
       RowBox[{"6.571572187793419`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"29286.`", ",", 
     RowBox[{"{", 
      RowBox[{"40.85809111212533`", "\[InvisibleSpace]", "-", 
       RowBox[{"7.513606501771938`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"34145.`", ",", 
     RowBox[{"{", 
      RowBox[{"40.575028196845246`", "\[InvisibleSpace]", "-", 
       RowBox[{"8.691125462862757`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"39811.`", ",", 
     RowBox[{"{", 
      RowBox[{"40.00015403140313`", "\[InvisibleSpace]", "-", 
       RowBox[{"10.106739625565488`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46416.`", ",", 
     RowBox[{"{", 
      RowBox[{"39.428273994977474`", "\[InvisibleSpace]", "-", 
       RowBox[{"11.821548554411628`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"54117.`", ",", 
     RowBox[{"{", 
      RowBox[{"38.64020390696051`", "\[InvisibleSpace]", "-", 
       RowBox[{"13.486197316328719`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63096.`", ",", 
     RowBox[{"{", 
      RowBox[{"37.63675062842598`", "\[InvisibleSpace]", "-", 
       RowBox[{"15.34394995959944`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"73564.`", ",", 
     RowBox[{"{", 
      RowBox[{"36.43282233977512`", "\[InvisibleSpace]", "-", 
       RowBox[{"17.268416606882862`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85770.`", ",", 
     RowBox[{"{", 
      RowBox[{"34.69811553173047`", "\[InvisibleSpace]", "-", 
       RowBox[{"19.423923852225823`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"100000", ",", 
     RowBox[{"{", 
      RowBox[{"32.18582030860829`", "\[InvisibleSpace]", "-", 
       RowBox[{"21.775057410397952`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"116591.`", ",", 
     RowBox[{"{", 
      RowBox[{"29.336173754136496`", "\[InvisibleSpace]", "-", 
       RowBox[{"24.320783849515546`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135936.`", ",", 
     RowBox[{"{", 
      RowBox[{"25.722412744023845`", "\[InvisibleSpace]", "-", 
       RowBox[{"26.276035580360247`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"158489.`", ",", 
     RowBox[{"{", 
      RowBox[{"21.415895994335788`", "\[InvisibleSpace]", "-", 
       RowBox[{"27.829197472954583`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"184785.`", ",", 
     RowBox[{"{", 
      RowBox[{"16.64486340663479`", "\[InvisibleSpace]", "-", 
       RowBox[{"28.713896143085243`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215443.`", ",", 
     RowBox[{"{", 
      RowBox[{"11.401850961563587`", "\[InvisibleSpace]", "-", 
       RowBox[{"28.60797542559049`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"251189.`", ",", 
     RowBox[{"{", 
      RowBox[{"6.179526235978957`", "\[InvisibleSpace]", "-", 
       RowBox[{"27.39842282171371`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"292864.`", ",", 
     RowBox[{"{", 
      RowBox[{"1.006230759859661`", "\[InvisibleSpace]", "-", 
       RowBox[{"25.272956596737163`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"341455.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.073224582738064`"}], "-", 
       RowBox[{"21.839471064005107`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"398107.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6.341751876489322`"}], "-", 
       RowBox[{"17.898626376308517`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"464159.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8.079664424312309`"}], "-", 
       RowBox[{"13.634796145944401`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"541170.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8.678403186623294`"}], "-", 
       RowBox[{"9.540785248994112`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"630957.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8.214141946507473`"}], "-", 
       RowBox[{"5.943862540072219`", " ", "\[ImaginaryI]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"735642.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7.064171359094279`"}], "-", 
       RowBox[{"3.1525612627487627`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"857696.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5.630293545546125`"}], "-", 
       RowBox[{"1.2512992928880424`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000000", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4.152012430306042`"}], "-", 
       RowBox[{"0.13846190265249428`", " ", "\[ImaginaryI]"}]}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4501413357798915`*^9, 3.4501414959830165`*^9}, 
   3.4501415264830165`*^9, 3.4501415982486415`*^9, 3.4501419996236415`*^9, 
   3.4501420537955165`*^9, 3.4501429962486415`*^9, 3.450186584368*^9, 
   3.4501890401805*^9, 3.450293681078125*^9, 3.450455301352375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dbipol", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"tfreq", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "}"}], "&"}], "/@", "dtrans"}]}], "}"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"phaseipol", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"tfreq", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "}"}], "&"}], "/@", "dtrans"}]}], "}"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4501415526236415`*^9, 3.4501415554986415`*^9}, {
  3.4501416162017665`*^9, 3.4501416543580165`*^9}, {3.45018878996175*^9, 
  3.450188791243*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "1.`*^6"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.4501416273892665`*^9, 3.4501416547798915`*^9}, 
   3.4501420014361415`*^9, 3.4501420553423915`*^9, 3.4501429987955165`*^9, 
   3.450186584571125*^9, 3.450188792227375*^9, 3.450189040227375*^9, 
   3.45029368115625*^9, 3.45045530139925*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "1.`*^6"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
   "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{{3.4501416273892665`*^9, 3.4501416547798915`*^9}, 
   3.4501420014361415`*^9, 3.4501420553423915`*^9, 3.4501429987955165`*^9, 
   3.450186584571125*^9, 3.450188792227375*^9, 3.450189040227375*^9, 
   3.45029368115625*^9, 3.45045530139925*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Response", "Subsubsection",
 CellChangeTimes->{{3.4501424302642665`*^9, 3.4501424305298915`*^9}, {
  3.4501424726861415`*^9, 3.4501424745455165`*^9}, {3.450296599140625*^9, 
  3.450296619828125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dettrans", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{"FromdB", "[", 
    RowBox[{"dbipol", "[", "f", "]"}], "]"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"phaseipol", "[", "f", "]"}], "Degree"}]]}]}]], "Input",
 CellChangeTimes->{{3.4501416660298915`*^9, 3.4501417616080165`*^9}, {
  3.4501418090455165`*^9, 3.4501418125767665`*^9}, {3.4501423746548915`*^9, 
  3.4501423749361415`*^9}, {3.4501434464830165`*^9, 3.4501434498892665`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"dettrans", "[", 
    RowBox[{"1000", "f"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "10", ",", "1000"}], "}"}], ",", 
   RowBox[{"MagnitudeRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseRange", "\[Rule]", "All"}], ",", 
   RowBox[{"XAxisLabel", "\[Rule]", "\"\<kHz\>\""}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501417669673915`*^9, 3.4501417817017665`*^9}, {
   3.4501418276548915`*^9, 3.4501418332955165`*^9}, 3.4501418981705165`*^9, {
   3.4501420847330165`*^9, 3.4501421491236415`*^9}, {3.4501422095298915`*^9, 
   3.4501422555142665`*^9}, {3.4501423777173915`*^9, 
   3.4501423779830165`*^9}, {3.4501434084361415`*^9, 3.4501434429673915`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd13c8ld8fAPBwpzvsLUUpJLNs7icJRYVCoZJSViWlMlORJg1lhAghsrNH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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.302585186977111, 12.370001872895967`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["20", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["200", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["2000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{
          Log[10], 
          Log[20], 
          Log[50], 
          Log[100], 
          Log[200], 
          Log[500], 
          Log[1000], 
          Log[2000], 
          Log[5000], 3.4011973816621555`, 3.6888794541139363`, 
          4.0943445622221, 4.248495242049359, 4.382026634673881, 
          4.499809670330265, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}, {{2.302585092994046, 2.995732273553991, 
         3.912023005428146, 4.605170185988092, 5.298317366548036, 
         6.214608098422191, 6.907755278982137, 7.600902459542082, 
         8.517193191416238, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982, 
         6.396929655216146, 6.551080335043404, 6.684611727667927, 
         6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{2.302585186977111, 6.907755184999072}, {
       12.370001872895967`, 32.429999995928426`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox["20", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[200], 5.298317366548036], 
          FormBox["200", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[2000], 7.600902459542082], 
          FormBox["2000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVznk41IkfB3BrLnKNGWPMkMrP8UvLj+Qa12ectZIjRZR1jaSQVCKr8ovK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.302585186977111, -178.08999391069852`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["20", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["200", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["2000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{
          Log[10], 
          Log[20], 
          Log[50], 
          Log[100], 
          Log[200], 
          Log[500], 
          Log[1000], 
          Log[2000], 
          Log[5000], 3.4011973816621555`, 3.6888794541139363`, 
          4.0943445622221, 4.248495242049359, 4.382026634673881, 
          4.499809670330265, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}, {{2.302585092994046, 2.995732273553991, 
         3.912023005428146, 4.605170185988092, 5.298317366548036, 
         6.214608098422191, 6.907755278982137, 7.600902459542082, 
         8.517193191416238, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982, 
         6.396929655216146, 6.551080335043404, 6.684611727667927, 
         6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{2.302585186977111, 
       6.907755184999072}, {-178.08999391069852`, -3.740000352880166}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox["20", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[200], 5.298317366548036], 
          FormBox["200", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[2000], 7.600902459542082], 
          FormBox["2000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{433.5999999999998, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4501417822798915`*^9, {3.4501418151392665`*^9, 3.4501418338580165`*^9}, 
   3.4501418988423915`*^9, 3.4501420045455165`*^9, {3.4501420577486415`*^9, 
   3.4501421386548915`*^9}, {3.4501422107642665`*^9, 3.4501422561392665`*^9}, 
   3.4501423803580165`*^9, 3.4501430038423915`*^9, 3.4501434097330165`*^9, {
   3.4501434434830165`*^9, 3.4501434533267665`*^9}, 3.450186585446125*^9, 
   3.450188798664875*^9, 3.45018904039925*^9, 3.450293681265625*^9, 
   3.45045530158675*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compensation Design", "Subsection",
 CellChangeTimes->{{3.4501423208736415`*^9, 3.4501423621236415`*^9}, {
  3.4501428707486415`*^9, 3.4501428762955165`*^9}, {3.450296623765625*^9, 
  3.45029662490625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"comp", "[", "f_", "]"}], ":=", 
  RowBox[{"2*^5", 
   RowBox[{"pole", "[", 
    RowBox[{"f", ",", "100"}], "]"}], 
   RowBox[{"zero", "[", 
    RowBox[{"f", ",", "1*^5"}], "]"}], 
   RowBox[{"pole", "[", 
    RowBox[{"f", ",", "100"}], "]"}], 
   RowBox[{"zero", "[", 
    RowBox[{"f", ",", "1*^4"}], "]"}], 
   RowBox[{"pole", "[", 
    RowBox[{"f", ",", "0.756"}], "]"}], 
   RowBox[{"zero", "[", 
    RowBox[{"f", ",", "15.12"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{"comp", "[", "f", "]"}], " ", 
   RowBox[{"wmax", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   " ", 
   RowBox[{"pole", "[", 
    RowBox[{"f", ",", "VCApole"}], "]"}], 
   RowBox[{"dettrans", "[", "f", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"gainadj", "=", 
  FractionBox["1", 
   RowBox[{"Abs", "[", 
    RowBox[{"trans", "[", "1*^5", "]"}], "]"}]]}]}], "Input",
 CellChangeTimes->{{3.4501428959830165`*^9, 3.4501429610298915`*^9}, {
   3.4501430483580165`*^9, 3.4501431580767665`*^9}, {3.4501435232330165`*^9, 
   3.4501435245455165`*^9}, {3.4501436580611415`*^9, 
   3.4501436653423915`*^9}, {3.4501476439986415`*^9, 
   3.4501476518267665`*^9}, {3.450296551328125*^9, 3.45029655309375*^9}, {
   3.450298822703125*^9, 3.450298845609375*^9}, {3.4504632716805*^9, 
   3.45046327771175*^9}, {3.450463380477375*^9, 3.45046338346175*^9}, {
   3.45046349927425*^9, 3.450463519789875*^9}, 3.450463887743*^9}],

Cell[BoxData["0.29499775377859183`"], "Output",
 CellChangeTimes->{{3.4501431358580165`*^9, 3.4501431587486415`*^9}, 
   3.4501434570923915`*^9, 3.4501435254517665`*^9, 3.4501436657173915`*^9, 
   3.4501476455298915`*^9, 3.450186585571125*^9, 3.450188806946125*^9, 
   3.4501890405555*^9, 3.4502936813125*^9, 3.450298847578125*^9, 
   3.450455301602375*^9, 3.45046310102425*^9, {3.450463273118*^9, 
   3.450463278493*^9}, {3.45046338121175*^9, 3.450463384696125*^9}, 
   3.45046352114925*^9, 3.450463587227375*^9, 3.450463889383625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"gainadj", " ", 
    RowBox[{"trans", "[", "f", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1000000"}], "}"}], ",", 
   RowBox[{"MagnitudeRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501417669673915`*^9, 3.4501417817017665`*^9}, {
   3.4501418276548915`*^9, 3.4501418332955165`*^9}, 3.4501418981705165`*^9, {
   3.4501420847330165`*^9, 3.4501421491236415`*^9}, {3.4501422095298915`*^9, 
   3.4501422555142665`*^9}, {3.4501423777173915`*^9, 
   3.4501423779830165`*^9}, {3.4501430254361415`*^9, 
   3.4501430296705165`*^9}, {3.4501431634830165`*^9, 3.4501431641080165`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVz3k41PsXB3DLWMIw1uxkLLM0FYp8LXPsu6yzxEhlyVZIKmooUiphLFGW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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.8194919506049536`*^-7, -26.476548485068097`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}, {{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}],
      GridLines->{{
        0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
         9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`, 
         1.6094379124341003`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
         3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.298317366548036, 5.703782474656201, 
         5.991464547107982, 6.214608098422191, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         7.600902459542082, 8.006367567650246, 8.294049640102028, 
         8.517193191416238, 8.699514748210191, 8.85366542803745, 
         8.987196820661973, 9.104979856318357, 9.903487552536127, 
         10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
         11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
         11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
         12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
         13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{2.8194919506049536`*^-7, 
       13.815510276015079`}, {-26.476548485068097`, 119.30041788575677`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["5", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["6", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.903487552536127, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.308952660644293`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.596634733096073`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.819778284410283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.002099841204238`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.156250521031495`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.289781913656018`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.407564949312402`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.206072645530174`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.611537753638338`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.89921982609012, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.122363377404328`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.304684934198283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.458835614025542`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.592367006650065`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.710150042306449`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8VF8UAHCVfY3sZpCYsaRCu+UdknUwIxlLso0tFEIS2osKLQpZsmdp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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.8194919506049536`*^-7, -235.8509840410248},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}, {{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}],
      GridLines->{{
        0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
         9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`, 
         1.6094379124341003`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
         3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.298317366548036, 5.703782474656201, 
         5.991464547107982, 6.214608098422191, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         7.600902459542082, 8.006367567650246, 8.294049640102028, 
         8.517193191416238, 8.699514748210191, 8.85366542803745, 
         8.987196820661973, 9.104979856318357, 9.903487552536127, 
         10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
         11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
         11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
         12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
         13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{2.8194919506049536`*^-7, 
       13.815510276015079`}, {-235.8509840410248, -50.26685465922034}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["5", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["6", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.903487552536127, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.308952660644293`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.596634733096073`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.819778284410283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.002099841204238`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.156250521031495`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.289781913656018`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.407564949312402`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.206072645530174`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.611537753638338`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.89921982609012, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.122363377404328`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.304684934198283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.458835614025542`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.592367006650065`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.710150042306449`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4501417822798915`*^9, {3.4501418151392665`*^9, 3.4501418338580165`*^9}, 
   3.4501418988423915`*^9, 3.4501420045455165`*^9, {3.4501420577486415`*^9, 
   3.4501421386548915`*^9}, {3.4501422107642665`*^9, 3.4501422561392665`*^9}, 
   3.4501423803580165`*^9, {3.4501430038423915`*^9, 3.4501431057017665`*^9}, 
   3.4501431646392665`*^9, 3.4501434626705165`*^9, 3.4501435264986415`*^9, 
   3.4501436686080165`*^9, 3.450186588414875*^9, 3.4501888090555*^9, 
   3.450189040821125*^9, 3.450293681484375*^9, 3.4502988511875*^9, 
   3.450455301852375*^9, 3.450463526493*^9, 3.4504635888055*^9, 
   3.450463892227375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"gainadj", " ", 
    RowBox[{"trans", "[", 
     RowBox[{"1000", "f"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "10", ",", "1000"}], "}"}], ",", 
   RowBox[{"MagnitudeRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseRange", "\[Rule]", "All"}], ",", 
   RowBox[{"XAxisLabel", "\[Rule]", "\"\<kHz\>\""}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501417669673915`*^9, 3.4501417817017665`*^9}, {
   3.4501418276548915`*^9, 3.4501418332955165`*^9}, 3.4501418981705165`*^9, {
   3.4501420847330165`*^9, 3.4501421491236415`*^9}, {3.4501422095298915`*^9, 
   3.4501422555142665`*^9}, {3.4501423777173915`*^9, 
   3.4501423779830165`*^9}, {3.4501430254361415`*^9, 
   3.4501430296705165`*^9}, {3.4501431634830165`*^9, 
   3.4501432760298915`*^9}, {3.4501433385767665`*^9, 3.4501433667955165`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVx38803kcwPG1rYb5MT9mWE1oGJJYNd+H8XZFdUXKdhelKEnqNuuHHzV1
PJAfpbpcoXJNJtqcch4npXzkcYWKVPO4RiX9UFGSNDS5z/3xerweT4ct0nXb
yCQSKRT3/58dX9d6ZScZ7KMa65/W8aHRQbXilIQMfYyrevfLfDhTS2nbLyPD
iuFd9/ar+LD+cV3b0mQyzHm33NiujA8PWay7mgwyfNxYbbb5GB9ul/bcnygm
Q2bpFT4lgQ/V6thHga1k4H0PT6qz54O8NelZ1zwKJHSlGzYd8QELxqp1mR8o
UFNUoO0Te4PXhXby+0oqqOUSaZVwIaxtUSjLomeC5qbv+y+LvCBh1LXig8ss
YAkzlsQHeQJduuHl4ItZkFbm+eRbqAcoJ4UH5SoaNCT2OG8FNwi0TKFHywzg
yZs/V9utcYVtyVGarzxDSNOfvFOS7wwZg5/19p8N4eKr0OTl1fPAReUTo1cb
wdi50b+TdY7Qqbtb7x5LB2EvTWId4QBSkdWuD27GsId0Ldd8rT2c1tOitrwy
hqRzv22N9JwN9XUq1Y5qE1BcXj31vM8GtBMVQy27TYGirXlBfciErLyQhC43
M4gsD1s7YWgJPPfyINlnM5C3M8c9WAxQ0R95bvmJASbfu/pZA0Zww1D9TnSd
ARqpQm+WOBPCOi7PkXHMgflGestURIKLAvqnN/vNYWjzhJF9vC7g2yXhCPe5
ORS2ZDZ4zxsMsGz55/hNPwvI2NfMPIu6AtSK1KpfiyxAEi9a8KNBZ1NgzswR
ut4CdFmy+DCvt00lVgPdn9Zbwp1jK3WxDl+ahivPD5besISYYH2Qs81U021K
dmrSXCuYtM+9lzNMRjHUZuVFuRUcFtNux5nS0LjxY1JZnxWcFT0tqK6go/Dr
fpNjQibIHkQsF3AZaIFX1649xUxIP8L4KCm0QAbVQtNreiZ0HifVUOKYSNk5
HRIZYQ0XTHjL0p1skP9kcWPLDWsIdqnKmytmozPtuW3ZbBaM+EiNhzo4KDVG
uWZPMgvo+RyhrZ8DCicVU3k9LCh+cCBxOsQJjSzr/1kgsIFRVH/fI4mLjpyg
aBnnbEAq1jkfNXFFleVhGguSLbDUr80/drihnKhRiWSjLVCDpi99UcxHsRzJ
kpPIFpQe0Yv+PeSFqFn+peYcO9hQdTqt0tsbcWuJgw2pdrCXuvCq04QPWjpg
etTtqR2UMMeuJM5YjLi3BMSYLxviiwyYvTQBoigJ69xSNjgFxThOxRHoa5Pn
7N+x+aZZZiu3E+it1tFRgS3uy5sqxO5g0D0bsOub/Xo94glUIu8JeofNjSPK
N+4gkLdIvm/lH2wARfmmxp0EiqbcfGx4ng0nxIlp8kQChXNqtUxsTe3r7Fbs
YN+KPgdsa57/CSsZgTykBUO+2LUZRZVqbJ12EzUBm/Nk9EXvbgIV1E77tGNL
81cfEu4jUPr9Ud9u7J4U3alc7L1vBwL6sYdp2TUa7EjOg1WT2IL5oS9/SSIQ
N+/8VjcFG9iZ+eLSZALZKAt3LMaOkoj2vsc2QjnSH7Cv+c8oXJxCoE9jiQci
sYm6Wd0d2C8Z29LjsFMSNo/bpRKo2z3i8G5sV95Z9nbstuCQowexe8YbA/7C
bowJPJmH7dLfHDuN/R83Ty5L
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.302585186977111, -26.476553246817414`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["20", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["200", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["2000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{
          Log[10], 
          Log[20], 
          Log[50], 
          Log[100], 
          Log[200], 
          Log[500], 
          Log[1000], 
          Log[2000], 
          Log[5000], 3.4011973816621555`, 3.6888794541139363`, 
          4.0943445622221, 4.248495242049359, 4.382026634673881, 
          4.499809670330265, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}, {{2.302585092994046, 2.995732273553991, 
         3.912023005428146, 4.605170185988092, 5.298317366548036, 
         6.214608098422191, 6.907755278982137, 7.600902459542082, 
         8.517193191416238, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982, 
         6.396929655216146, 6.551080335043404, 6.684611727667927, 
         6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{2.302585186977111, 
       6.907755184999072}, {-26.476553246817414`, 20.70650814388966}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox["20", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[200], 5.298317366548036], 
          FormBox["200", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[2000], 7.600902459542082], 
          FormBox["2000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13dcjd8fAPDcSpr3nueWppJCUwlpqU+yZ8t9bilug4YmUjSsvlFakpKQ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.302585186977111, -235.85100029496147`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["20", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["200", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["2000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2000], 7.600902459542082], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{
          Log[10], 
          Log[20], 
          Log[50], 
          Log[100], 
          Log[200], 
          Log[500], 
          Log[1000], 
          Log[2000], 
          Log[5000], 3.4011973816621555`, 3.6888794541139363`, 
          4.0943445622221, 4.248495242049359, 4.382026634673881, 
          4.499809670330265, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}, {{2.302585092994046, 2.995732273553991, 
         3.912023005428146, 4.605170185988092, 5.298317366548036, 
         6.214608098422191, 6.907755278982137, 7.600902459542082, 
         8.517193191416238, 3.4011973816621555`, 3.6888794541139363`, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.703782474656201, 5.991464547107982, 
         6.396929655216146, 6.551080335043404, 6.684611727667927, 
         6.802394763324311, 8.006367567650246, 8.294049640102028}, 
         Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{2.302585186977111, 
       6.907755184999072}, {-235.85100029496147`, -91.29774490180785}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[20], 2.995732273553991], 
          FormBox["20", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[200], 5.298317366548036], 
          FormBox["200", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[2000], 7.600902459542082], 
          FormBox["2000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4501417822798915`*^9, {3.4501418151392665`*^9, 3.4501418338580165`*^9}, 
   3.4501418988423915`*^9, 3.4501420045455165`*^9, {3.4501420577486415`*^9, 
   3.4501421386548915`*^9}, {3.4501422107642665`*^9, 3.4501422561392665`*^9}, 
   3.4501423803580165`*^9, {3.4501430038423915`*^9, 3.4501431057017665`*^9}, 
   3.4501431646392665`*^9, {3.4501431953892665`*^9, 3.4501432358267665`*^9}, 
   3.4501432768267665`*^9, {3.4501433392330165`*^9, 3.4501433673892665`*^9}, 
   3.4501434650767665`*^9, 3.4501435324361415`*^9, 3.450186589446125*^9, 
   3.45018904127425*^9, 3.450293681796875*^9, 3.450455302289875*^9, 
   3.450463528758625*^9, 3.45046359558675*^9, 3.4504638949305*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compensation Network", "Subsubtitle",
 CellChangeTimes->{{3.4501424302642665`*^9, 3.4501424305298915`*^9}, {
  3.4501424726861415`*^9, 3.4501424745455165`*^9}, {3.45029658715625*^9, 
  3.450296591359375*^9}}],

Cell["\<\
This includes a polarity switch, an excitation summing junction, a boost \
gain, a resistive divider network, the compensation filter, a limiter and an \
output driver.\
\>", "Text",
 CellChangeTimes->{{3.449580849104*^9, 3.449580863854*^9}, {
  3.44958123801025*^9, 3.44958125501025*^9}, {3.44958133107275*^9, 
  3.44958135257275*^9}, {3.450377550953125*^9, 3.450377553515625*^9}, {
  3.450377592796875*^9, 3.450377681203125*^9}}],

Cell[CellGroupData[{

Cell["Polarity Switch", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.4503780105625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "1", "]"}], "=", "3300"}], ";"}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "1", "]"}], "=", 
    RowBox[{"par", "[", 
     RowBox[{"3300", ",", 
      FractionBox["1", 
       RowBox[{"s", " ", "27*^-12"}]]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"z1", "[", "1", "]"}], ",", 
      RowBox[{"z2", "[", "1", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"z1", "[", "1", "]"}], ",", 
       RowBox[{"z2", "[", "1", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.450378061*^9, 
   3.45037807946875*^9}, 3.45037821834375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Excitation Summing Junction", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "2", "]"}], "=", "3300"}], ";"}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "2", "]"}], "=", 
    RowBox[{"par", "[", 
     RowBox[{"3300", ",", 
      FractionBox["1", 
       RowBox[{"s", " ", "10*^-12"}]]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"z1", "[", "2", "]"}], ",", 
      RowBox[{"z2", "[", "2", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"z1", "[", "2", "]"}], ",", 
       RowBox[{"z2", "[", "2", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.45037805715625*^9, 
   3.45037809375*^9}, {3.4503781623125*^9, 3.450378163390625*^9}, 
   3.45037822028125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boost Gain", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.450378097734375*^9, 3.45037810078125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "3", "]"}], "=", "1500"}], ";"}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "3", "]"}], "=", 
    RowBox[{"par", "[", 
     RowBox[{"1*^6", ",", 
      FractionBox["1", 
       RowBox[{"s", " ", "10*^-9"}]]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{"1", ",", 
      RowBox[{"z1", "[", "3", "]"}], ",", 
      RowBox[{"z2", "[", "3", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "3", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{"1", ",", 
       RowBox[{"z1", "[", "3", "]"}], ",", 
       RowBox[{"z2", "[", "3", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.45037805715625*^9, 
   3.450378071671875*^9}, {3.45037811590625*^9, 3.45037816971875*^9}, 
   3.45037822171875*^9, {3.45038125109375*^9, 3.450381261875*^9}, {
   3.45038130990625*^9, 3.45038131525*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resistive Divider Network", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.450378097734375*^9, 3.45037810078125*^9}, {3.450378179546875*^9, 
  3.450378188484375*^9}, {3.450378429953125*^9, 3.450378436578125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "4", "]"}], "=", "3500"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "4", "]"}], "=", "gainadj"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "4", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"z1", "[", "4", "]"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["in", "2"], 
         SuperscriptBox[
          RowBox[{"Abs", "[", 
           RowBox[{"z1", "[", "4", "]"}], "]"}], "2"]}]}]], 
      RowBox[{"2", "gainadj"}]], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4503782111875*^9, 3.45037830203125*^9}, {
   3.450378345671875*^9, 3.45037841065625*^9}, 3.450378440921875*^9, {
   3.450380164734375*^9, 3.4503801685*^9}, {3.45038047675*^9, 
   3.4503804786875*^9}, {3.4503805690625*^9, 3.45038057646875*^9}, {
   3.4503807245*^9, 3.450380734421875*^9}, {3.450380795546875*^9, 
   3.4503808085625*^9}, 3.450463546852375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compensation Filter", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.450378097734375*^9, 3.45037810078125*^9}, {3.45037845103125*^9, 
  3.4503784555625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "5", "]"}], "=", "82"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "5", "]"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"s", " ", "10*^-9"}]], "+", "82"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{"1", ",", 
      RowBox[{"z1", "[", "5", "]"}], ",", 
      RowBox[{"z2", "[", "5", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "5", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{"1", ",", 
       RowBox[{"z1", "[", "5", "]"}], ",", 
       RowBox[{"z2", "[", "5", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.45037805715625*^9, 
   3.450378071671875*^9}, {3.45037811590625*^9, 3.45037816971875*^9}, 
   3.45037822171875*^9, 3.450378457875*^9, {3.450378509859375*^9, 
   3.45037851953125*^9}, {3.450463905008625*^9, 3.4504639058055*^9}, {
   3.450464004258625*^9, 3.450464034446125*^9}, {3.450464090227375*^9, 
   3.450464148618*^9}, {3.450464218446125*^9, 3.45046422164925*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Limiter", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.450378097734375*^9, 3.45037810078125*^9}, {3.450378485421875*^9, 
  3.450378486546875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "6", "]"}], "=", "\[Infinity]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "6", "]"}], "=", "100"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "6", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{"1", ",", 
      RowBox[{"z1", "[", "6", "]"}], ",", 
      RowBox[{"z2", "[", "6", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "6", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{"1", ",", 
       RowBox[{"z1", "[", "6", "]"}], ",", 
       RowBox[{"z2", "[", "6", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.45037805715625*^9, 
   3.450378071671875*^9}, {3.45037811590625*^9, 3.45037816971875*^9}, 
   3.45037822171875*^9, {3.450378490109375*^9, 3.450378530703125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Output Driver", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.45037855109375*^9, 3.450378553546875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "7", "]"}], "=", "10000"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z2", "[", "7", "]"}], "=", 
    RowBox[{"par", "[", 
     RowBox[{"10000", ",", 
      RowBox[{"526", "+", 
       FractionBox["1", 
        RowBox[{"s", " ", "20*^-6"}]]}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "7", "]"}], "=", 
   RowBox[{
    RowBox[{"OpAmp", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"z1", "[", "7", "]"}], ",", 
      RowBox[{"z2", "[", "7", "]"}]}], "]"}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "7", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"OpAmpNoise", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"z1", "[", "7", "]"}], ",", 
       RowBox[{"z2", "[", "7", "]"}], ",", "en", ",", "in"}], "]"}], "/.", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
    RowBox[{"AD829", "[", "f", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.449515368421*^9, 3.449515446530375*^9}, {
   3.44951549688975*^9, 3.4495155154835*^9}, {3.449515555155375*^9, 
   3.4495156274835*^9}, {3.449515694296*^9, 3.44951576726475*^9}, {
   3.4495158114835*^9, 3.449515825967875*^9}, {3.449516700436625*^9, 
   3.449516750249125*^9}, {3.449517049671*^9, 3.44951706663975*^9}, {
   3.4495171026085*^9, 3.44951716888975*^9}, {3.449518387030375*^9, 
   3.449518494374125*^9}, {3.449518786467875*^9, 3.449518810561625*^9}, {
   3.4495189117335*^9, 3.449519014124125*^9}, {3.449519056671*^9, 
   3.44951926613975*^9}, {3.449519296655375*^9, 3.449519325655375*^9}, 
   3.4495194807335*^9, {3.449519522749125*^9, 3.44951953301475*^9}, {
   3.44951956501475*^9, 3.44951959220225*^9}, {3.449519759405375*^9, 
   3.449519782967875*^9}, {3.449519974124125*^9, 3.449520068655375*^9}, {
   3.449521006342875*^9, 3.44952125082725*^9}, {3.449521396249125*^9, 
   3.449521458249125*^9}, {3.44952152870225*^9, 3.449521561249125*^9}, {
   3.449580388994625*^9, 3.449580408463375*^9}, 3.449580544557125*^9, {
   3.449580606713375*^9, 3.449580674229*^9}, {3.449580841838375*^9, 
   3.449580842588375*^9}, {3.44958093907275*^9, 3.449581037807125*^9}, {
   3.449581070025875*^9, 3.44958113932275*^9}, {3.44958128657275*^9, 
   3.449581318463375*^9}, {3.45037768653125*^9, 3.45037769696875*^9}, {
   3.4503779405*^9, 3.450377995515625*^9}, {3.45037805715625*^9, 
   3.45037809375*^9}, {3.4503781623125*^9, 3.450378163390625*^9}, 
   3.45037822028125*^9, {3.450378559046875*^9, 3.45037856515625*^9}, {
   3.4503786068125*^9, 3.450378630265625*^9}, {3.45038006140625*^9, 
   3.450380073703125*^9}, {3.450380111984375*^9, 3.45038011428125*^9}, {
   3.45038020928125*^9, 3.4503802096875*^9}, {3.450380243921875*^9, 
   3.4503802519375*^9}, {3.450380288421875*^9, 3.450380293359375*^9}, {
   3.450380365421875*^9, 3.45038036990625*^9}, {3.450380463140625*^9, 
   3.45038046340625*^9}, {3.450380520484375*^9, 3.450380521046875*^9}, {
   3.450380559359375*^9, 3.45038055975*^9}, {3.450380601328125*^9, 
   3.4503806238125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total", "Subsection",
 CellChangeTimes->{{3.45037800175*^9, 3.450378033609375*^9}, {
  3.45037855109375*^9, 3.450378553546875*^9}, {3.450378753890625*^9, 
  3.450378755359375*^9}, {3.450378858359375*^9, 3.45037885990625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"stages", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "0", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpProduct", "[", 
     RowBox[{"opamp", ",", "stages"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "0", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpNoiseProduct", "[", 
     RowBox[{"opamp", ",", "opampnoise", ",", "stages"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4482001880950003`*^9, 3.4482002000950003`*^9}, {
   3.4482009844700003`*^9, 3.4482009886887503`*^9}, {3.4482010215950003`*^9, 
   3.4482010232512503`*^9}, 3.450378863671875*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loop", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"dettrans", "[", "f", "]"}], 
    RowBox[{"opamp", "[", "0", "]"}], " ", 
    RowBox[{"wmax", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
    RowBox[{"pole", "[", 
     RowBox[{"f", ",", "VCApole"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"loopnoise", "[", "0", "]"}], "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"opampnoise", "[", "0", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"totalnoise", "[", "2", "]"}], "2"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.450379186578125*^9, 3.450379234046875*^9}, {
   3.450379645890625*^9, 3.45037968525*^9}, {3.450379767109375*^9, 
   3.45037979165625*^9}, 3.450463636227375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Magnitude (dB)\>\"", ",", 
        "\"\<Phase (\[Degree])\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"dB", "[", 
          RowBox[{"loop", "[", "0", "]"}], "]"}], "/.", 
         RowBox[{"f", "\[Rule]", "#"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Arg", "[", 
           RowBox[{"loop", "[", "0", "]"}], "]"}], "/", "Degree"}], "/.", 
         RowBox[{"f", "\[Rule]", "#"}]}]}], "}"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
      "0.01", ",", "0.1", ",", "1", ",", "10", ",", "100", ",", "1000", ",", 
       "1*^4", ",", "1*^5", ",", "1*^6"}], "}"}]}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
  3.4482002402825003`*^9, 3.4482004240168753`*^9}, {3.4482004740793753`*^9, 
  3.4482005057512503`*^9}, {3.4482009979543753`*^9, 3.4482010018450003`*^9}, {
  3.4482012028293753`*^9, 3.4482012032512503`*^9}, {3.45037894846875*^9, 
  3.450378966515625*^9}, {3.450379225765625*^9, 3.450379257984375*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Magnitude (dB)\"\>", "\<\"Phase \
(\[Degree])\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0.01`", "219.9050999388345`", 
     RowBox[{"-", "90.75590088197863`"}]},
    {"0.1`", "199.83054941065387`", 
     RowBox[{"-", "97.5157099447359`"}]},
    {"1", "175.5149373550891`", 
     RowBox[{"-", "142.7184862838532`"}]},
    {"10", "137.5808706649332`", 
     RowBox[{"-", "174.29924936836306`"}]},
    {"100", "97.90649380578218`", 
     RowBox[{"-", "178.57748969717335`"}]},
    {"1000", "57.95534598602761`", 
     RowBox[{"-", "174.4351180206943`"}]},
    {"10000", "20.71624747215538`", 
     RowBox[{"-", "135.74649903359438`"}]},
    {"100000", 
     RowBox[{"-", "0.14313460878931186`"}], 
     RowBox[{"-", "95.8403144701271`"}]},
    {"1000000", 
     RowBox[{"-", "27.85077425002558`"}], "83.31470552685127`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Magnitude (dB)", "Phase (\[Degree])"}, {}, {0.01, 
    219.9050999388345, -90.75590088197863}, {0.1, 
    199.83054941065387`, -97.5157099447359}, {
    1, 175.5149373550891, -142.7184862838532}, {
    10, 137.5808706649332, -174.29924936836306`}, {
    100, 97.90649380578218, -178.57748969717335`}, {
    1000, 57.95534598602761, -174.4351180206943}, {
    10000, 20.71624747215538, -135.74649903359438`}, {
    100000, -0.14313460878931186`, -95.8403144701271}, {
    1000000, -27.85077425002558, 83.31470552685127}}]]], "Output",
 CellChangeTimes->{
  3.450378898015625*^9, {3.450378959109375*^9, 3.450378966890625*^9}, {
   3.450379242125*^9, 3.45037925878125*^9}, 3.450380119390625*^9, 
   3.450380176921875*^9, 3.450380213140625*^9, 3.45038025625*^9, 
   3.450380297546875*^9, 3.45038037378125*^9, {3.450380438984375*^9, 
   3.450380481578125*^9}, {3.450380582203125*^9, 3.45038060553125*^9}, 
   3.45038066553125*^9, 3.450380743*^9, 3.450380803578125*^9, 
   3.45038132453125*^9, 3.450455303243*^9, 3.450463321743*^9, {
   3.450463533852375*^9, 3.450463553008625*^9}, 3.450463599008625*^9, 
   3.45046363896175*^9, 3.450463910868*^9, 3.450464229852375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"loop", "[", "0", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1000000"}], "}"}], ",", 
   RowBox[{"MagnitudeRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseReference", "\[Rule]", 
    RowBox[{"-", "180"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501417669673915`*^9, 3.4501417817017665`*^9}, {
   3.4501418276548915`*^9, 3.4501418332955165`*^9}, 3.4501418981705165`*^9, {
   3.4501420847330165`*^9, 3.4501421491236415`*^9}, {3.4501422095298915`*^9, 
   3.4501422555142665`*^9}, {3.4501423777173915`*^9, 
   3.4501423779830165`*^9}, {3.4501430254361415`*^9, 
   3.4501430296705165`*^9}, {3.4501431634830165`*^9, 
   3.4501431641080165`*^9}, {3.450379273796875*^9, 3.4503792753125*^9}, {
   3.45037934984375*^9, 3.450379354703125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Gk41HsbB3DEPGMiso5Jdmb+/8mabP+Y21K2kr1lIhySrUg5VMchIpXs
IpWtPGUL2T3xK4dcibJGUaGSrYiQYs48L+7re31efa/vm1vR65SjDx8PD088
9/6fF36Elg7PpJoczIpyOTfvA3e+dD7dzw5hkWkFvde++kBtEnWGzo5mkfRJ
DXdmfcBswoQjwU5hBeqQWtEXHyALOyZsZuezVrM1B9c/+MBMPrubxK5kCTZ1
2x3t8QG3wA/B/OwnrEPppb5llT6Q2aNktondw5L4U6KpIdgHhlr5Rd5LjrMa
fywcrhn1BosHHOfCd9Ms/6lHdx/ZeYNfxpXz9x4vsLZ4U/I2mv8AvtqaSF+/
ZVZseQd/s8If0Jnzce5o2xqrq9JAa+iqFxwf25mEIjms/bcWK2enPCHByOob
ZSsfkD5/nB218YSV46v7Xhrxw5CWKsqu9QC71vpWmzQSWOm2TL6X9ABjvvPz
71vJUE7hl3DiuMOuL+ZLQVMU0C4LbpEfcgOpDdmtj4yFQS4sV24q8ygkLa9M
bPUXAd9LJ24H+LMhImlhMm1cFOq/rVeJqxwBzT/9rXMoYsC3/8y61cQh0Lb/
eOmhnDg0a2ypHa87CHTTz3byNhIgWV62mT/UFfyUp77neEqChbjW6wZzF8jb
fkb5TLIUeLcJaon/cgJ2wMWWjgZpGMwbMD9d7whexSl6+EsqiBoKTly/6gDu
vJjR5C8ZcHNqtbm8xx6KrJ9QKyW2QV4vprOA28HpTyNeK3RZ2CL5QO/da1vQ
yY4yzHbcDtGXDWRDna3BxER1xtJPDuL4U3XDOXuB9csBc7whD19ByHY20gLG
BaL9Zo8pwI+nG/sokmbwPG6YqTetAL6THWFzHSwoFQ+rVo9SBOfcdmkBYwJ0
ZdKKmUJKQHr426nUVB8iO0IGfTOUQIQYoJQU7YTWmPQOB1wZXuw0Mp2nakF5
nT7DrEYZamx/pvUROKStyNl9sFWBDXf9d1UeKiBXETcWO6QC25yQhNpjOQgQ
qyj29VIF75aCh+bVklAVtd1odUUV5Nuq+5beCEKu72b9pBg12D/8ZOrA6DIr
/ojxWh+NDiMGJ43/WR5s0V7RWnR9SAc/0eWz0UsbLXHPnlOjK+mw/pnHMcuF
0zJyw9uk5BEdLL4KZDTWclriDLISOHV0kH5vHJ+ymwe9jeDI30d00JKd/GDJ
4UGXfnft+9lDBzeXxhKZOD40zBtQlLNEB/Momzv8NwVQtNC9wx8MGRCqE51N
G9uMSHMH9Qx3M6DVcrA8Q0YIXeuiiKeaMKDsxFgXOAqhzOvBL8zNGaAquFRA
bhNCxaK7Wf/dx4AkIjb2Z7kw6pfoUzl5jAEBQbK3ghJFkNp23vlfsQwwdv6S
sKNpK+pUd4uTfsUAGwHf8vu/JJGOaPsFq14G/JLAXenbpdDN7xqhEf0MoItP
rD42kUL+dTweb4cYcMKDz1PnohQSNL1rmDvGgPl3CzeHydLI0nlmVm2RAdET
+AULKSpqPRfhpCeFQWC/b+8bSxrC3catfakYrPP2fNkdSEOpLFvIomEQM3Ij
+EUyDXnxb1dfk8PALqvkWfgbGuK9jkjNdAyWlV4l4sHbECv/P417DLl2uZqz
Vi6Lmp5lKLgcxWBVYBPf22Py6HnFgMh5dwwWfr6g9l2VR0PZkpw8DwzE8sT6
1urk0XJAxuisNwbWh7vG/MkK3L0ZN2ODMDhVYLt8wEsB3T+ULlEdiUH6hERY
OFURpU+lksXzMQhgzahhcUqosLd3xaAQg8WXRfsKbyuhqiaxSfd7GHCk+lt0
apTQy8TUtuIHGEx66p9J+6iEKDqpF82qMOhRfvDRz0IZRZ1L+R3SioGlB7V9
jKyCgjYnz7/6hMFaMSSYVKiiUv6pTNUvGJRXLx3e062KptdNjc9NY9D23ckq
dFYVnZhfTFD+hkFvXriDBaaGvAYOKoetcvsHvMIa7qqhQ7nyrts246Dzj2jh
SAEdWex82OSjhcNNG4X6nXUYitlB9mrUwQHF7I9MGcbQU1VPssguHKh7qz5J
/sYQiyruUm+IQ/QP2/E0UxwZrYd9pZjj8ETg8EBQN440n5koVrjgkDi7fnzy
GxPR2N1xa+dwCJj2nBA9qIEI19G99L9wwAeKQq5c0EBHHWZJzn/j4JW/yqtR
oIFyLSnxZTE4TPzdRV+c00AqunvjPa7hUEieNT0br4k0hZvj22/jkOtWYY55
aiGLlrLLqQiHn6cMPuuXaKMg5cQrOIkJfY4nzSBCFzVr1PDGkZlgdGxjrSpV
F4kajYaPUZggnP4qxahUF1XZq/tmiTBBsSpt7vJ7XbT8V5c5SYYJJg3MFDXL
XShqSHh9jMmEzp7IuQSaHkpPvH4q24EJrjrSYNmnjxpXkpzJt5lQf7p5S3QO
gdQUIt1oXOckJ26LuEWgVKvA4zu4DhPw0A65TaCAbKtwe65lCsXCPXMJJEvw
3sriegf3sZkVEigy8vQE4w4T0sv3SJNKCGQm4HLaOpcJsvYC2umNBCpXNz/P
5jq8geKR2EQgmqt2bBDXn/W0s+L+R6DFIuHMFK7tND8pRzQT6K5Ve8Mw1xvH
Nz1wf0og0jV9Xv88JuQuzvgznxPodLUq5QLXa8mhO1Q7CfRuRFz8OtdWh5gr
ci8IVKc+r1LFtZ+m5n2xbgKdeHnfao3r+JSC8LUeAvWvZDoI5TOhTKQ9ZqmX
QKBw6Ygc17X2illf+wgkE+IZaMZ10/TFkfEBAsVlHzjrzHUN86rQ6CCBvj8x
jjzO9V+c7j2vXxPIfZoZH8511JEDl3uGCPRcjJZ8hWtCW7i/c5hA/wKZi9WY

         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.8194919506049536`*^-7, -27.850766423435953`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}, {{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}],
      GridLines->{{
        0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
         9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`, 
         1.6094379124341003`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
         3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.298317366548036, 5.703782474656201, 
         5.991464547107982, 6.214608098422191, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         7.600902459542082, 8.006367567650246, 8.294049640102028, 
         8.517193191416238, 8.699514748210191, 8.85366542803745, 
         8.987196820661973, 9.104979856318357, 9.903487552536127, 
         10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
         11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
         11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
         12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
         13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{2.8194919506049536`*^-7, 
       13.815510276015079`}, {-27.850766423435953`, 175.51493334881044`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["5", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["6", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.903487552536127, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.308952660644293`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.596634733096073`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.819778284410283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.002099841204238`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.156250521031495`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.289781913656018`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.407564949312402`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.206072645530174`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.611537753638338`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.89921982609012, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.122363377404328`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.304684934198283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.458835614025542`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.592367006650065`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.710150042306449`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k81E0YAHBJQs7ddd/X7lIUOULZh4SoCLXryrW/RSjXm0LSpVQkhJJS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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{2.8194919506049536`*^-7, -276.68525996175373`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}, {{Automatic, Automatic}, {{{0., 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {9.210340371976184, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
            FormBox[
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["6", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{0., 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
            FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
            FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
            FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {7.600902459542082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.006367567650246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.294049640102028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.517193191416238, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.699514748210191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.85366542803745, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {8.987196820661973, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.104979856318357, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {9.903487552536127, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.308952660644293`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.596634733096073`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {10.819778284410283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.002099841204238`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.156250521031495`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.289781913656018`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {11.407564949312402`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.206072645530174`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.611537753638338`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {12.89921982609012, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.122363377404328`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.304684934198283`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.458835614025542`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.592367006650065`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {13.710150042306449`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}}],
      GridLines->{{
        0, 2.302585092994046, 4.605170185988092, 6.907755278982137, 
         9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`, 
         1.6094379124341003`, 1.791759469228055, 1.9459101490553132`, 
         2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
         3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
         4.0943445622221, 4.248495242049359, 4.382026634673881, 
         4.499809670330265, 5.298317366548036, 5.703782474656201, 
         5.991464547107982, 6.214608098422191, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         7.600902459542082, 8.006367567650246, 8.294049640102028, 
         8.517193191416238, 8.699514748210191, 8.85366542803745, 
         8.987196820661973, 9.104979856318357, 9.903487552536127, 
         10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
         11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
         11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
         12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
         13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
        Automatic},
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{2.8194919506049536`*^-7, 
       13.815510276015079`}, {-276.68525996175373`, -94.68959194974369}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["5", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["6", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.903487552536127, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.308952660644293`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.596634733096073`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.819778284410283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.002099841204238`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.156250521031495`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.289781913656018`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.407564949312402`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.206072645530174`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.611537753638338`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.89921982609012, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.122363377404328`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.304684934198283`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.458835614025542`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.592367006650065`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.710150042306449`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{439.9999999999999, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.4503792775*^9, 3.4503793555*^9, 3.45038012240625*^9, 
  3.45038043915625*^9, 3.45038048175*^9, 3.450380582359375*^9, 
  3.450380665703125*^9, 3.450380743171875*^9, 3.45038080375*^9, 
  3.45038132753125*^9, 3.45045530352425*^9, 3.450463321977375*^9, 
  3.450463534102375*^9, 3.45046359927425*^9, 3.450463646883625*^9, 
  3.450463911118*^9, 3.450464236368*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"loop", "[", "0", "]"}], "/.", 
    RowBox[{"f", "\[Rule]", 
     RowBox[{"1000", "f"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1000"}], "}"}], ",", 
   RowBox[{"MagnitudeRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PhaseRange", "\[Rule]", "All"}], ",", 
   RowBox[{"XAxisLabel", "\[Rule]", "\"\<kHz\>\""}], ",", 
   RowBox[{"PhaseReference", "\[Rule]", 
    RowBox[{"-", "180"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4501417669673915`*^9, 3.4501417817017665`*^9}, {
   3.4501418276548915`*^9, 3.4501418332955165`*^9}, 3.4501418981705165`*^9, {
   3.4501420847330165`*^9, 3.4501421491236415`*^9}, {3.4501422095298915`*^9, 
   3.4501422555142665`*^9}, {3.4501423777173915`*^9, 
   3.4501423779830165`*^9}, {3.4501430254361415`*^9, 
   3.4501430296705165`*^9}, {3.4501431634830165`*^9, 
   3.4501431641080165`*^9}, {3.450379273796875*^9, 3.4503792753125*^9}, {
   3.45037934984375*^9, 3.450379354703125*^9}, {3.450379387484375*^9, 
   3.450379441*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVx3s0lHkcgHGE5JJmmMkMhpLkVmwym3fH+0XbDk2Kndr0KhJmJ5yQyOrM
cR3rtkMuNYcuFJVVCSlSfqjQdFyixrTVuJVii1BjdVb77h/Pec5nTchR/zAN
NTU1X7L/f/LzsRrFVKp7R1xmHXeRB+feydp3Eodw1ySpyZnPPGiUmEzZEDG4
wdTR9IkZHniOuX8zJlJw4WBqlHiCBzoG/ll6RAHOl09nPBjkwVQ50aNNlOON
8XHPPG7w4EDkcLQmcRN34yyYeYTyoKR/recyog1PuH124OeeHTDUoWmopD3F
ox1S+NeyfGDb1W/8i69f4EnBAwYuhDcIi7OTKu+N4II2TWXiZi5oNN4SCYRv
cd6m11bKue0gKx3/EPhwEv9dOOKjJ/sRwkc2S5BoGvf+8Ne1iJxtkOXGndal
zOKnBC1Wu/leoApf4PW6zePyBLZy4xZP8O240+FT+AUPZohPG2p4AEcjaUbZ
sYDn2rZX5vThsOWd13zU+0U8IS2F2FXPAfqSGaWe8y/eUmZ9mJmAgeSLaoxy
5Bs+Q80OLYvZComSTxOFo2oguWP4j9oeNmxKOOJdqqsBQ4Hdw8P7toDz7vGM
G6xl4FvDEDIKN4ONx1tfCx9NuLgubDDgnjMIrd7Plh7Sghc5VEWqhRNcMI+z
isvXhgf1ApnjtAMQEamtXU3LQdmbG8oZtIWQ6gJXu14dmL5GfXKCbgMH1W3d
Jr6ugNlRw+oKbB1UebeZ3DTWgx/8DhfMXl0DsW9ehqhs9GFgrCI+tIQF30mT
t0r9DYC+IiuzN48B7u7WUz8JV8IlmzP5Cgca4F/9bP1PG8Lx8ebgpapVMKqV
Ivw7aBVUddEqWOM68FissHedXAVsM40i8xJ1qDGKb3BMpoDXq/LOfq953IVR
WG2vT4WeWqf2+6MvcFFXzHNBMRWcZJh5epi8tSOtqMvPzgg6lUM8Hm229fpt
9gbPW0YQmIcHvPNaai1UsXyHdxjD6WMnmZXdWohVKx5JHzIGSVH0KV1HfRRB
ra0WhNAgbxfW86mAguqSzd0WVDQ4Zr8vW95FQ+cFemxJGh1aK3O2R+sxUeZ+
zuIAczVcTrzq15ZhgZxVTnN7b6yGxp2/PFomX4tS9CsDhreaQAD90p859PVI
5nhAvLrPBIRlQR2GLnbobmex5Z5ABrQQfuFhpRtRlF7+TN8bBjS8koaWdTsj
JtEjXvyNCWeb6rcv9LmgKKu8bDttUyhyypBGf2SjZpWEr3PWFFLqgmKLmjG0
3lJ0gEmaLm7VodzF0CluZLgD6eZkQXke6Qgp98Ru0j6H8xXiFgyZYeplZ0hf
XO8dlngfQyJR7NiGc6bgooqePNiOIU+tPbHe500hvi2yxv4xhq47eiURpCN6
9HKvkGbudU6PIn2u80uUtQxDc1UGJQWkly/Ufm/xBEOXuI+aFKTVKpreU3sw
pJ3LVj9ywRSUNa7Ni/0Yim2w1j1J2ulOxf2Epxh6/dLI6A/SA8WBD+dJ33ac
WVdHes6jWfFxAEO/9l7hLpLurbNkjT3D0KCqxE+/3BRWVi25BD/HEFhm7GeR
zguy931FmhFzKNKTdMT5mEy5HENi6a7jfNJvQnIu84cwNNvGEYWTfhA+391P
+uCkfeYJ0uXdNR99FRh6TGXmZ5OmVDfQnpD+DyubQZQ=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{1.4097459753024768`*^-7, -27.85077033673048},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0, 
           FormBox["1", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["5", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{0, 
          Log[5], 
          Log[10], 
          Log[50], 
          Log[100], 
          Log[500], 
          Log[1000], 
          Log[5000], 0.6931471805599453, 1.0986122886681098`, 
          1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
          2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
          3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
          5.298317366548036, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 7.600902459542082, 8.006367567650246, 
          8.294049640102028}, Automatic}, {{
         0, 1.6094379124341003`, 2.302585092994046, 3.912023005428146, 
          4.605170185988092, 6.214608098422191, 6.907755278982137, 
          8.517193191416238, 0.6931471805599453, 1.0986122886681098`, 
          1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
          2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
          3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
          5.298317366548036, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 7.600902459542082, 8.006367567650246, 
          8.294049640102028}, Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{1.4097459753024768`*^-7, 
       6.9077551380075395`}, {-27.85077033673048, 57.9553435479552}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {
          NCache[
           Log[5], 1.6094379124341003`], 
          FormBox["5", TraditionalForm]}, {
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8lN0XAHCEsgzzzIysSVkiKSopfpoTihZr5XlmGPuSLGUvMm9FKiVJ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{1.4097459753024768`*^-7, -276.68527721745164`},
      BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"kHz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0, 
           FormBox["1", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["5", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["1000", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[1000], 6.907755278982137], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5000], 8.517193191416238], 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->NCache[{{0, 
          Log[5], 
          Log[10], 
          Log[50], 
          Log[100], 
          Log[500], 
          Log[1000], 
          Log[5000], 0.6931471805599453, 1.0986122886681098`, 
          1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
          2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
          3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
          5.298317366548036, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 7.600902459542082, 8.006367567650246, 
          8.294049640102028}, Automatic}, {{
         0, 1.6094379124341003`, 2.302585092994046, 3.912023005428146, 
          4.605170185988092, 6.214608098422191, 6.907755278982137, 
          8.517193191416238, 0.6931471805599453, 1.0986122886681098`, 
          1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
          2.0794415416798357`, 2.1972245773362196`, 2.995732273553991, 
          3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
          5.298317366548036, 5.703782474656201, 5.991464547107982, 
          6.396929655216146, 6.551080335043404, 6.684611727667927, 
          6.802394763324311, 7.600902459542082, 8.006367567650246, 
          8.294049640102028}, Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{1.4097459753024768`*^-7, 
       6.9077551380075395`}, {-276.68527721745164`, -94.68950995933217}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0, 
          FormBox["1", TraditionalForm]}, {
          NCache[
           Log[5], 1.6094379124341003`], 
          FormBox["5", TraditionalForm]}, {
          NCache[
           Log[10], 2.302585092994046], 
          FormBox["10", TraditionalForm]}, {
          NCache[
           Log[50], 3.912023005428146], 
          FormBox["50", TraditionalForm]}, {
          NCache[
           Log[100], 4.605170185988092], 
          FormBox["100", TraditionalForm]}, {
          NCache[
           Log[500], 6.214608098422191], 
          FormBox["500", TraditionalForm]}, {
          NCache[
           Log[1000], 6.907755278982137], 
          FormBox["1000", TraditionalForm]}, {
          NCache[
           Log[5000], 8.517193191416238], 
          FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{427.1999999999998, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.450379388609375*^9, {3.45037942065625*^9, 3.45037944146875*^9}, 
   3.45038043946875*^9, 3.45038048203125*^9, 3.45038058265625*^9, 
   3.450380666*^9, 3.45038074346875*^9, 3.45038080403125*^9, 
   3.45038133765625*^9, 3.450455304008625*^9, 3.450463322477375*^9, 
   3.450463534539875*^9, 3.450463599696125*^9, 3.450463648696125*^9, 
   3.45046391158675*^9, 3.45046424202425*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1*^9", " ", 
         RowBox[{"totalnoise", "[", "2", "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"opampnoise", "[", "0", "]"}]}], ",", 
        RowBox[{"1*^9", " ", 
         RowBox[{"loopnoise", "[", "0", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "10", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Frequency[Hz]\>\"", ",", 
         "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
      
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Noise at Error Point\>\""}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"10", ",", "500"}], "}"}]}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<RF detector\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Servo\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Total\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.85", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.449493257749125*^9, 3.449493303374125*^9}, {
   3.449493396280375*^9, 3.449493420561625*^9}, {3.4494934624835*^9, 
   3.44949348320225*^9}, 3.44949351520225*^9, {3.449493599046*^9, 
   3.449493610421*^9}, {3.449495180530375*^9, 3.44949521051475*^9}, {
   3.44949553438975*^9, 3.44949553913975*^9}, {3.4494963747335*^9, 
   3.449496399171*^9}, {3.4494966816085*^9, 3.449496692671*^9}, {
   3.449496743874125*^9, 3.44949674907725*^9}, {3.449496857311625*^9, 
   3.449496915155375*^9}, {3.4494969871085*^9, 3.449497001686625*^9}, {
   3.449512989717875*^9, 3.449513041155375*^9}, {3.44951309507725*^9, 
   3.449513159842875*^9}, {3.4495136761085*^9, 3.4495137421085*^9}, {
   3.449514037780375*^9, 3.4495140469835*^9}, {3.4495140897335*^9, 
   3.44951417501475*^9}, {3.4495194382335*^9, 3.44951946107725*^9}, {
   3.449519605061625*^9, 3.449519606405375*^9}, {3.449519677546*^9, 
   3.449519747796*^9}, {3.4495198129835*^9, 3.449519912405375*^9}, {
   3.449520094780375*^9, 3.449520209092875*^9}, {3.449520365921*^9, 
   3.44952038451475*^9}, 3.449520934030375*^9, {3.449521483624125*^9, 
   3.449521503499125*^9}, {3.450379746328125*^9, 3.450379757328125*^9}, {
   3.450379801984375*^9, 3.450379820671875*^9}, {3.4503798760625*^9, 
   3.45037990903125*^9}, 3.450379942734375*^9, 3.450379994421875*^9, {
   3.450381462640625*^9, 3.450381491734375*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hk8lVkYB/DrWrqWQa+b3KzpfV+MytIeNY/BlDB2JpOSQWWLkisqQorK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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8VG8XAHCEO7aQdcwdZsaWklKWLOmUXdnJUqTsS4sWZImIsmRNUUrK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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwd13c4lu8XAHCZEeIlo/A+77D6lpVkVaeoZCQrSigrSRkNskPKDIVIsqII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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[10], 2.302585092994046}, {2.302585092994046, 2.302585092994046}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Frequency[Hz]\"", TraditionalForm], 
       FormBox[
       "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{2.302585092994046, 4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 2.995732273553991, 
        3.4011973816621555`, 3.6888794541139363`, 3.912023005428146, 
        4.0943445622221, 4.248495242049359, 4.382026634673881, 
        4.499809670330265, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`}, {
         Log[10], 
         Log[20], 
         Log[50], 
         Log[100], 
         Log[200], 
         Log[500], 
         Log[1000], 
         Log[2000], 
         Log[5000], 3.4011973816621555`, 3.6888794541139363`, 4.0943445622221,
          4.248495242049359, 4.382026634673881, 4.499809670330265, 
         5.703782474656201, 5.991464547107982, 6.396929655216146, 
         6.551080335043404, 6.684611727667927, 6.802394763324311, 
         8.006367567650246, 8.294049640102028}}, {{2.302585092994046, 
        4.605170185988092, 6.907755278982137, 9.210340371976184, 
        11.512925464970229`, 2.995732273553991, 3.4011973816621555`, 
        3.6888794541139363`, 3.912023005428146, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.298317366548036, 5.703782474656201, 5.991464547107982, 
        6.214608098422191, 6.396929655216146, 6.551080335043404, 
        6.684611727667927, 6.802394763324311, 7.600902459542082, 
        8.006367567650246, 8.294049640102028, 8.517193191416238, 
        8.699514748210191, 8.85366542803745, 8.987196820661973, 
        9.104979856318357, 9.903487552536127, 10.308952660644293`, 
        10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
        11.156250521031495`, 11.289781913656018`, 11.407564949312402`}, {
        2.302585092994046, 2.995732273553991, 3.912023005428146, 
        4.605170185988092, 5.298317366548036, 6.214608098422191, 
        6.907755278982137, 7.600902459542082, 8.517193191416238, 
        3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
        4.248495242049359, 4.382026634673881, 4.499809670330265, 
        5.703782474656201, 5.991464547107982, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        8.006367567650246, 8.294049640102028}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotLabel->FormBox["\"Noise at Error Point\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[10], 
         Log[100000]}, {2.302585092994046, 6.214608098422191}}, {{
       2.302585092994046, 11.512925464970229`}, {2.302585092994046, 
       6.214608098422191}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {
         NCache[
          Log[1000], 6.907755278982137], 
         FormBox["1000", TraditionalForm]}, {
         NCache[
          Log[2000], 7.600902459542082], 
         FormBox["2000", TraditionalForm]}, {
         NCache[
          Log[5000], 8.517193191416238], 
         FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Total\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Servo\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"RF detector\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1, 
         0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.85, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.44951946251475*^9, 3.4495195362335*^9, {3.4495195972335*^9, 
   3.449519608217875*^9}, {3.449519679546*^9, 3.44951974851475*^9}, {
   3.4495197899835*^9, 3.449519913842875*^9}, {3.449520107905375*^9, 
   3.44952021145225*^9}, 3.4495203867335*^9, 3.449520937436625*^9, 
   3.449521507546*^9, 3.449521570592875*^9, 3.4495453841828213`*^9, 
   3.4495460193859468`*^9, 3.44957947638525*^9, 3.449579702932125*^9, 
   3.4495806797915*^9, 3.44958115051025*^9, {3.449581358494625*^9, 
   3.449581387307125*^9}, 3.44958293721875*^9, 3.449593394078125*^9, 
   3.449599384109375*^9, 3.449603940890625*^9, 3.449689495203125*^9, 
   3.449689586171875*^9, 3.44968963621875*^9, 3.449689770984375*^9, 
   3.449691463703125*^9, 3.449692450609375*^9, 3.449692497453125*^9, 
   3.449692759609375*^9, 3.449692827921875*^9, 3.44969302371875*^9, 
   3.44970599021875*^9, 3.4501367892173915`*^9, 3.45018657271175*^9, 
   3.450189029133625*^9, 3.4502936736875*^9, 3.450378902484375*^9, 
   3.4503798249375*^9, 3.45037991284375*^9, 3.45037994775*^9, 
   3.450379997859375*^9, 3.450380088171875*^9, 3.450380129265625*^9, 
   3.4503802218125*^9, 3.450380263625*^9, 3.450380304203125*^9, 
   3.4503803799375*^9, 3.45038044278125*^9, 3.4503804853125*^9, 
   3.450380586671875*^9, 3.45038066925*^9, 3.45038074659375*^9, 
   3.450380807421875*^9, 3.45038136215625*^9, 3.450381496078125*^9, 
   3.450455309039875*^9, 3.450463327789875*^9, 3.45046353946175*^9, 
   3.450463604633625*^9, 3.45046365846175*^9, 3.450463916618*^9, 
   3.4504642486805*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attenuator Chain", "Subsubtitle",
 CellChangeTimes->{{3.450296648453125*^9, 3.45029665375*^9}, {
  3.45030080715625*^9, 3.450300811078125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"att", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"par", "[", 
        RowBox[{"r1", ",", 
         RowBox[{"r2", "+", 
          RowBox[{"par", "[", 
           RowBox[{"r1", ",", "rt"}], "]"}]}]}], "]"}], "\[Equal]", "rt"}], 
      ",", 
      RowBox[{
       FractionBox[
        RowBox[{"par", "[", 
         RowBox[{"r1", ",", "rt"}], "]"}], 
        RowBox[{"r2", "+", 
         RowBox[{"par", "[", 
          RowBox[{"r1", ",", "rt"}], "]"}]}]], "\[Equal]", 
       RowBox[{"FromdB", "[", 
        RowBox[{"-", "1.5"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r1", ",", "r2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4501484586548915`*^9, 3.4501485085142665`*^9}, {
   3.4501485518892665`*^9, 3.4501486549048915`*^9}, {3.4501487110455165`*^9, 
   3.4501488442642665`*^9}, 3.45029930796875*^9, {3.45029943246875*^9, 
   3.45029943375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r2", "\[Rule]", 
     RowBox[{"0.17355354289591177`", " ", "rt"}]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     RowBox[{"11.609954201566296`", " ", "rt"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.4501485089830165`*^9, {3.4501486051861415`*^9, 3.4501486241392665`*^9}, 
   3.4501486577486415`*^9, {3.4501487143267665`*^9, 3.4501487875611415`*^9}, {
   3.4501488185611415`*^9, 3.4501488447486415`*^9}, 3.450186589618*^9, 
   3.45018904139925*^9, 3.450293681921875*^9, 3.450299308296875*^9, 
   3.45029943428125*^9, 3.45037890365625*^9, 3.450380442984375*^9, 
   3.4503804855*^9, 3.45038058728125*^9, 3.45038066940625*^9, 
   3.450380746796875*^9, 3.450380807734375*^9, 3.450455309227375*^9, 
   3.4504636636805*^9, 3.450464254102375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rtt", "=", 
   RowBox[{"40*^3", "/", "11.61"}]}], " ", 
  RowBox[{"(*", " ", "termination", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"att", "/.", 
   RowBox[{"rt", "\[Rule]", "rtt"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"r2", ":", " ", 
     RowBox[{"series", " ", "resistor"}]}], ";", " ", 
    RowBox[{"r1", ":", " ", 
     RowBox[{"resistor", " ", "to", " ", "GND"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"par", "[", 
    RowBox[{"rtt", ",", "r1"}], "]"}], "/.", "att"}], "/.", 
  RowBox[{"rt", "\[Rule]", "rtt", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"last", " ", "resistor", " ", "in", " ", "chain"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.450299364703125*^9, 3.450299378515625*^9}, {
  3.4502994110625*^9, 3.450299454296875*^9}, {3.450299734046875*^9, 
  3.450299771390625*^9}, {3.450353502328125*^9, 3.450353570625*^9}}],

Cell[BoxData["3445.3057708871665`"], "Output",
 CellChangeTimes->{{3.45029936903125*^9, 3.4502993789375*^9}, {
   3.45029941925*^9, 3.4502994546875*^9}, {3.45029974634375*^9, 
   3.45029977246875*^9}, 3.450353505375*^9, 3.4503789036875*^9, 
   3.450380443015625*^9, 3.45038048553125*^9, 3.450380587296875*^9, 
   3.4503806694375*^9, 3.450380746828125*^9, 3.45038080775*^9, 
   3.450455309243*^9, 3.450463663743*^9, 3.450464254164875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r2", "\[Rule]", "597.9450228971982`"}], ",", 
    RowBox[{"r1", "\[Rule]", "39999.84221039207`"}]}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{{3.45029936903125*^9, 3.4502993789375*^9}, {
   3.45029941925*^9, 3.4502994546875*^9}, {3.45029974634375*^9, 
   3.45029977246875*^9}, 3.450353505375*^9, 3.4503789036875*^9, 
   3.450380443015625*^9, 3.45038048553125*^9, 3.450380587296875*^9, 
   3.4503806694375*^9, 3.450380746828125*^9, 3.45038080775*^9, 
   3.450455309243*^9, 3.450463663743*^9, 3.450464254164875*^9}],

Cell[BoxData[
 RowBox[{"{", "3172.0846539968907`", "}"}]], "Output",
 CellChangeTimes->{{3.45029936903125*^9, 3.4502993789375*^9}, {
   3.45029941925*^9, 3.4502994546875*^9}, {3.45029974634375*^9, 
   3.45029977246875*^9}, 3.450353505375*^9, 3.4503789036875*^9, 
   3.450380443015625*^9, 3.45038048553125*^9, 3.450380587296875*^9, 
   3.4503806694375*^9, 3.450380746828125*^9, 3.45038080775*^9, 
   3.450455309243*^9, 3.450463663743*^9, 3.450464254164875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FromdB", "[", 
   RowBox[{"7", " ", "1.5"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"half", " ", "the", " ", "gain", " ", "range"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "gainadj"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"initial", " ", "gain", " ", "drop"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"attfirst", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"par", "[", 
        RowBox[{"r1", ",", 
         RowBox[{"r2", "+", 
          RowBox[{"par", "[", 
           RowBox[{"r1", ",", "rt"}], "]"}]}]}], "]"}], "\[Equal]", "rt"}], 
      ",", 
      RowBox[{
       FractionBox[
        RowBox[{"par", "[", 
         RowBox[{"r1", ",", "rt"}], "]"}], 
        RowBox[{"r2", "+", 
         RowBox[{"par", "[", 
          RowBox[{"r1", ",", "rt"}], "]"}]}]], "\[Equal]", "%"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"r1", ",", "r2"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"attfirst", "/.", 
   RowBox[{"rt", "\[Rule]", "rtt"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"First", " ", 
     RowBox[{"stage", ":", " ", 
      RowBox[{"r2", ":", " ", "series"}]}]}], ";", " ", 
    RowBox[{"r1", ":", " ", 
     RowBox[{"to", " ", "GND"}]}]}], "  ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"par", "[", 
      RowBox[{"r1", ",", "rr"}], "]"}], "/.", "att"}], "/.", 
    RowBox[{"rr", "\[Rule]", "r1"}]}], "/.", "%"}], "/.", 
  RowBox[{"rt", "\[Rule]", "rtt", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"combined", " ", "2", "nd", " ", 
     RowBox[{"res", ".", " ", "to"}], " ", "GND"}], " ", "*)"}], 
   " "}]}]}], "Input",
 CellChangeTimes->{{3.450186529383625*^9, 3.4501865700555*^9}, {
  3.45018660921175*^9, 3.450186648039875*^9}, {3.45018669033675*^9, 
  3.450186715258625*^9}, {3.450299142328125*^9, 3.450299146015625*^9}, {
  3.45029917775*^9, 3.45029919828125*^9}, {3.450299885421875*^9, 
  3.450299905296875*^9}, {3.450300639859375*^9, 3.45030064840625*^9}, {
  3.450300831703125*^9, 3.450300942828125*^9}, {3.450353583609375*^9, 
  3.450353687796875*^9}}],

Cell[BoxData["3.3496543915782766`"], "Output",
 CellChangeTimes->{{3.450186589618*^9, 3.450186648493*^9}, {
   3.45018669114925*^9, 3.45018671577425*^9}, 3.4501890414305*^9, 
   3.4502936819375*^9, 3.4502991463125*^9, {3.4502991835625*^9, 
   3.45029919875*^9}, 3.45029990596875*^9, 3.45030064984375*^9, 
   3.450300943890625*^9, 3.45035369003125*^9, 3.450378903703125*^9, 
   3.4503804430625*^9, 3.45038048559375*^9, 3.45038058734375*^9, 
   3.45038066946875*^9, 3.450380746890625*^9, 3.45038080778125*^9, 
   3.45045530927425*^9, 3.45046366377425*^9, 3.45046425421175*^9}],

Cell[BoxData["0.9881405214501873`"], "Output",
 CellChangeTimes->{{3.450186589618*^9, 3.450186648493*^9}, {
   3.45018669114925*^9, 3.45018671577425*^9}, 3.4501890414305*^9, 
   3.4502936819375*^9, 3.4502991463125*^9, {3.4502991835625*^9, 
   3.45029919875*^9}, 3.45029990596875*^9, 3.45030064984375*^9, 
   3.450300943890625*^9, 3.45035369003125*^9, 3.450378903703125*^9, 
   3.4503804430625*^9, 3.45038048559375*^9, 3.45038058734375*^9, 
   3.45038066946875*^9, 3.450380746890625*^9, 3.45038080778125*^9, 
   3.45045530927425*^9, 3.45046366377425*^9, 3.450464254227375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r2", "\[Rule]", 
     RowBox[{"0.011930646176491503`", " ", "rt"}]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     RowBox[{"167.6414787631267`", " ", "rt"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.450186589618*^9, 3.450186648493*^9}, {
   3.45018669114925*^9, 3.45018671577425*^9}, 3.4501890414305*^9, 
   3.4502936819375*^9, 3.4502991463125*^9, {3.4502991835625*^9, 
   3.45029919875*^9}, 3.45029990596875*^9, 3.45030064984375*^9, 
   3.450300943890625*^9, 3.45035369003125*^9, 3.450378903703125*^9, 
   3.4503804430625*^9, 3.45038048559375*^9, 3.45038058734375*^9, 
   3.45038066946875*^9, 3.450380746890625*^9, 3.45038080778125*^9, 
   3.45045530927425*^9, 3.45046366377425*^9, 3.45046425427425*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r2", "\[Rule]", "41.10472412227909`"}], ",", 
    RowBox[{"r1", "\[Rule]", "577576.1542226588`"}]}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{{3.450186589618*^9, 3.450186648493*^9}, {
   3.45018669114925*^9, 3.45018671577425*^9}, 3.4501890414305*^9, 
   3.4502936819375*^9, 3.4502991463125*^9, {3.4502991835625*^9, 
   3.45029919875*^9}, 3.45029990596875*^9, 3.45030064984375*^9, 
   3.450300943890625*^9, 3.45035369003125*^9, 3.450378903703125*^9, 
   3.4503804430625*^9, 3.45038048559375*^9, 3.45038058734375*^9, 
   3.45038066946875*^9, 3.450380746890625*^9, 3.45038080778125*^9, 
   3.45045530927425*^9, 3.45046366377425*^9, 3.450464254321125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "37409.08838236548`", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.450186589618*^9, 3.450186648493*^9}, {
   3.45018669114925*^9, 3.45018671577425*^9}, 3.4501890414305*^9, 
   3.4502936819375*^9, 3.4502991463125*^9, {3.4502991835625*^9, 
   3.45029919875*^9}, 3.45029990596875*^9, 3.45030064984375*^9, 
   3.450300943890625*^9, 3.45035369003125*^9, 3.450378903703125*^9, 
   3.4503804430625*^9, 3.45038048559375*^9, 3.45038058734375*^9, 
   3.45038066946875*^9, 3.450380746890625*^9, 3.45038080778125*^9, 
   3.45045530927425*^9, 3.45046366377425*^9, 3.450464254368*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vc", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox["v", "r1"], "+", 
          FractionBox[
           RowBox[{"v", "-", "v15"}], "r2"], "+", 
          FractionBox[
           RowBox[{"v", "-", "vc"}], "r3"]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"vc", "-", "vcc"}], "r4"], "\[Equal]", 
         FractionBox[
          RowBox[{"vc", "-", "v"}], "r3"]}]}], "}"}], ",", "vc", ",", "v"}], 
     "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.45029415128125*^9, 3.450294263515625*^9}, {
  3.450294472375*^9, 3.450294544515625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"r1", " ", "r4", " ", "v15"}], 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "+", 
     RowBox[{"r1", " ", "r3"}], "+", 
     RowBox[{"r2", " ", "r3"}], "-", 
     RowBox[{"r1", " ", "r4"}], "-", 
     RowBox[{"r2", " ", "r4"}]}]]}], "+", 
  FractionBox[
   RowBox[{"r1", " ", "r2", " ", "vcc"}], 
   RowBox[{
    RowBox[{"r1", " ", "r2"}], "+", 
    RowBox[{"r1", " ", "r3"}], "+", 
    RowBox[{"r2", " ", "r3"}], "-", 
    RowBox[{"r1", " ", "r4"}], "-", 
    RowBox[{"r2", " ", "r4"}]}]], "+", 
  FractionBox[
   RowBox[{"r1", " ", "r3", " ", "vcc"}], 
   RowBox[{
    RowBox[{"r1", " ", "r2"}], "+", 
    RowBox[{"r1", " ", "r3"}], "+", 
    RowBox[{"r2", " ", "r3"}], "-", 
    RowBox[{"r1", " ", "r4"}], "-", 
    RowBox[{"r2", " ", "r4"}]}]], "+", 
  FractionBox[
   RowBox[{"r2", " ", "r3", " ", "vcc"}], 
   RowBox[{
    RowBox[{"r1", " ", "r2"}], "+", 
    RowBox[{"r1", " ", "r3"}], "+", 
    RowBox[{"r2", " ", "r3"}], "-", 
    RowBox[{"r1", " ", "r4"}], "-", 
    RowBox[{"r2", " ", "r4"}]}]]}]], "Output",
 CellChangeTimes->{{3.450294210359375*^9, 3.450294263984375*^9}, {
   3.450294484109375*^9, 3.45029454496875*^9}, 3.45037890375*^9, 
   3.450380443140625*^9, 3.450380485703125*^9, 3.450380587625*^9, 
   3.450380669515625*^9, 3.450380747*^9, 3.4503808078125*^9, 
   3.4504553093055*^9, 3.450463664008625*^9, 3.450464254414875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"r1", " ", "r2", " ", "vcc"}], 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "+", 
     RowBox[{"r1", " ", "r3"}], "+", 
     RowBox[{"r2", " ", "r3"}], "-", 
     RowBox[{"r1", " ", "r4"}], "-", 
     RowBox[{"r2", " ", "r4"}]}]], "+", 
   FractionBox[
    RowBox[{"r1", " ", "r3", " ", "vcc"}], 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "+", 
     RowBox[{"r1", " ", "r3"}], "+", 
     RowBox[{"r2", " ", "r3"}], "-", 
     RowBox[{"r1", " ", "r4"}], "-", 
     RowBox[{"r2", " ", "r4"}]}]], "+", 
   FractionBox[
    RowBox[{"r2", " ", "r3", " ", "vcc"}], 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "+", 
     RowBox[{"r1", " ", "r3"}], "+", 
     RowBox[{"r2", " ", "r3"}], "-", 
     RowBox[{"r1", " ", "r4"}], "-", 
     RowBox[{"r2", " ", "r4"}]}]]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.45029455809375*^9, 3.45029456*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r2", " ", "r3"}], "+", 
     RowBox[{"r1", " ", 
      RowBox[{"(", 
       RowBox[{"r2", "+", "r3"}], ")"}]}]}], ")"}], " ", "vcc"}], 
  RowBox[{
   RowBox[{"r2", " ", 
    RowBox[{"(", 
     RowBox[{"r3", "-", "r4"}], ")"}]}], "+", 
   RowBox[{"r1", " ", 
    RowBox[{"(", 
     RowBox[{"r2", "+", "r3", "-", "r4"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{3.4502945608125*^9, 3.450378903765625*^9, 
  3.450380443171875*^9, 3.450380485734375*^9, 3.450380587671875*^9, 
  3.450380669546875*^9, 3.450380747015625*^9, 3.450380807828125*^9, 
  3.45045530933675*^9, 3.4504636640555*^9, 3.45046425446175*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{874, 1035},
WindowMargins->{{Automatic, 505}, {Automatic, 8}},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 195, 3, 103, "Title"],
Cell[788, 28, 322, 10, 108, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1135, 42, 40, 0, 62, "Subtitle"],
Cell[1178, 44, 914, 14, 117, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2129, 63, 34, 0, 62, "Subtitle"],
Cell[2166, 65, 191, 6, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2394, 76, 25, 0, 62, "Subtitle"],
Cell[2422, 78, 579, 10, 80, "Input"],
Cell[3004, 90, 222, 6, 35, "Input"],
Cell[3229, 98, 1066, 29, 102, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4332, 132, 104, 1, 62, "Subtitle"],
Cell[4439, 135, 563, 13, 60, "Input"],
Cell[5005, 150, 193, 4, 35, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5235, 159, 88, 1, 62, "Subtitle"],
Cell[5326, 162, 52, 0, 35, "Subsubtitle"],
Cell[5381, 164, 906, 26, 159, "Input"],
Cell[CellGroupData[{
Cell[6312, 194, 102, 1, 35, "Subsubtitle"],
Cell[6417, 197, 479, 14, 101, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6933, 216, 121, 5, 35, "Subsubtitle"],
Cell[7057, 223, 330, 7, 97, "Text"],
Cell[7390, 232, 402, 12, 73, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7829, 249, 40, 0, 35, "Subsubtitle"],
Cell[7872, 251, 379, 9, 138, "Text"],
Cell[8254, 262, 2738, 84, 216, "Input"],
Cell[10995, 348, 232, 4, 55, "Text"],
Cell[11230, 354, 1639, 40, 201, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12906, 399, 101, 1, 35, "Subsubtitle"],
Cell[13010, 402, 7809, 175, 828, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20856, 582, 39, 0, 35, "Subsubtitle"],
Cell[20898, 584, 96, 2, 34, "Text"],
Cell[CellGroupData[{
Cell[21019, 590, 997, 26, 111, "Input"],
Cell[22019, 618, 16551, 341, 329, "Output"]
}, Open  ]],
Cell[38585, 962, 92, 2, 34, "Text"],
Cell[CellGroupData[{
Cell[38702, 968, 974, 26, 111, "Input"],
Cell[39679, 996, 16493, 340, 329, "Output"]
}, Open  ]],
Cell[56187, 1339, 113, 1, 34, "Text"],
Cell[CellGroupData[{
Cell[56325, 1344, 1391, 31, 111, "Input"],
Cell[57719, 1377, 28726, 519, 343, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86494, 1902, 47, 0, 35, "Subsubtitle"],
Cell[86544, 1904, 92, 2, 34, "Text"],
Cell[86639, 1908, 254, 8, 35, "Input"],
Cell[86896, 1918, 97, 2, 34, "Text"],
Cell[86996, 1922, 883, 28, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87916, 1955, 36, 0, 35, "Subsubtitle"],
Cell[87955, 1957, 40, 0, 34, "Text"],
Cell[87998, 1959, 986, 30, 58, "Input"],
Cell[88987, 1991, 31, 0, 34, "Text"],
Cell[89021, 1993, 1550, 43, 172, "Input"],
Cell[90574, 2038, 39, 0, 34, "Text"],
Cell[90616, 2040, 3238, 84, 291, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93891, 2129, 150, 2, 35, "Subsubtitle"],
Cell[94044, 2133, 225, 5, 34, "Text"],
Cell[CellGroupData[{
Cell[94294, 2142, 189, 3, 46, "Subsection"],
Cell[94486, 2147, 801, 19, 80, "Input"],
Cell[CellGroupData[{
Cell[95312, 2170, 163, 3, 35, "Input"],
Cell[95478, 2175, 758, 11, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96285, 2192, 221, 3, 46, "Subsection"],
Cell[96509, 2197, 1068, 29, 113, "Input"],
Cell[CellGroupData[{
Cell[97602, 2230, 596, 12, 102, "Input"],
Cell[98201, 2244, 926, 13, 35, "Output"],
Cell[99130, 2259, 927, 13, 35, "Output"],
Cell[100060, 2274, 925, 13, 35, "Output"],
Cell[100988, 2289, 926, 13, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101951, 2307, 3322, 86, 256, "Input"],
Cell[105276, 2395, 55932, 1003, 333, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[161257, 3404, 110, 1, 46, "Subsection"],
Cell[161370, 3407, 1379, 34, 126, "Input"],
Cell[CellGroupData[{
Cell[162774, 3445, 990, 24, 102, "Input"],
Cell[163767, 3471, 25295, 461, 339, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[189111, 3938, 151, 2, 46, "Subsection"],
Cell[189265, 3942, 2194, 48, 193, "Input"],
Cell[CellGroupData[{
Cell[191484, 3994, 1397, 38, 124, "Input"],
Cell[192884, 4034, 46131, 841, 323, "Output"]
}, Open  ]],
Cell[239030, 4878, 454, 8, 55, "Text"],
Cell[239487, 4888, 442, 13, 39, "Input"],
Cell[239932, 4903, 862, 23, 61, "Input"],
Cell[CellGroupData[{
Cell[240819, 4930, 4056, 104, 335, "Input"],
Cell[244878, 5036, 58669, 1079, 397, "Output"]
}, Open  ]],
Cell[303562, 6118, 577, 9, 55, "Text"],
Cell[304142, 6129, 1544, 42, 124, "Input"],
Cell[CellGroupData[{
Cell[305711, 6175, 5396, 134, 425, "Input"],
Cell[311110, 6311, 61618, 1124, 397, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[372777, 7441, 236, 3, 46, "Subsection"],
Cell[373016, 7446, 149, 2, 34, "Text"],
Cell[373168, 7450, 921, 21, 52, "Input"],
Cell[374092, 7473, 654, 19, 73, "Input"],
Cell[374749, 7494, 1480, 38, 87, "Input"],
Cell[CellGroupData[{
Cell[376254, 7536, 1489, 39, 124, "Input"],
Cell[377746, 7577, 22906, 488, 318, "Output"]
}, Open  ]],
Cell[400667, 8068, 839, 21, 98, "Text"],
Cell[401509, 8091, 852, 19, 102, "Input"],
Cell[402364, 8112, 2884, 69, 148, "Input"],
Cell[405251, 8183, 7036, 208, 688, "Input"],
Cell[412290, 8393, 615, 17, 58, "Input"],
Cell[412908, 8412, 170, 2, 34, "Text"],
Cell[413081, 8416, 1594, 46, 117, "Input"],
Cell[CellGroupData[{
Cell[414700, 8466, 6167, 146, 414, "Input"],
Cell[420870, 8614, 57937, 1056, 329, "Output"]
}, Open  ]],
Cell[478822, 9673, 109, 1, 34, "Text"],
Cell[CellGroupData[{
Cell[478956, 9678, 627, 17, 75, "Input"],
Cell[479586, 9697, 214, 4, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[479837, 9706, 1271, 34, 102, "Input"],
Cell[481111, 9742, 37184, 641, 632, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[518344, 10389, 259, 3, 46, "Subsection"],
Cell[518606, 10394, 849, 25, 80, "Input"],
Cell[CellGroupData[{
Cell[519480, 10423, 4368, 109, 335, "Input"],
Cell[523851, 10534, 46444, 822, 397, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[570356, 11363, 197, 3, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[570578, 11370, 5170, 144, 434, "Input"],
Cell[575751, 11516, 1085, 15, 35, "Output"],
Cell[576839, 11533, 1086, 15, 35, "Output"]
}, Open  ]],
Cell[577940, 11551, 569, 9, 55, "Text"],
Cell[CellGroupData[{
Cell[578534, 11564, 4670, 114, 335, "Input"],
Cell[583207, 11680, 54071, 949, 401, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637315, 12634, 5226, 128, 357, "Input"],
Cell[642544, 12764, 53041, 934, 401, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[695634, 13704, 239, 3, 35, "Subsubtitle"],
Cell[695876, 13709, 334, 7, 55, "Text"],
Cell[CellGroupData[{
Cell[696235, 13720, 4225, 110, 311, "Input"],
Cell[700463, 13832, 919, 14, 35, "Output"],
Cell[701385, 13848, 917, 14, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[702339, 13867, 5226, 128, 357, "Input"],
Cell[707568, 13997, 73692, 1274, 401, 54953, 966, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[781309, 15277, 290, 4, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[781624, 15285, 1941, 50, 298, "Input"],
Cell[783568, 15337, 1101, 16, 35, "Output"],
Cell[784672, 15355, 1119, 17, 35, "Output"],
Cell[785794, 15374, 1119, 17, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[786950, 15396, 5461, 131, 379, "Input"],
Cell[792414, 15529, 40071, 708, 417, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[832522, 16242, 5278, 119, 322, "Input"],
Cell[837803, 16363, 37732, 661, 417, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[875584, 17030, 349, 5, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[875958, 17039, 2679, 71, 254, "Input"],
Cell[878640, 17112, 1058, 19, 51, "Output"],
Cell[879701, 17133, 923, 16, 61, "Output"],
Cell[880627, 17151, 961, 17, 52, "Output"],
Cell[881591, 17170, 850, 12, 35, "Output"],
Cell[882444, 17184, 52289, 949, 321, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[934770, 18138, 867, 18, 89, "Input"],
Cell[935640, 18158, 625, 9, 35, "Output"],
Cell[936268, 18169, 625, 9, 35, "Output"],
Cell[936896, 18180, 624, 9, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[937557, 18194, 4367, 99, 298, "Input"],
Cell[941927, 18295, 1761, 30, 52, "Output"],
Cell[943691, 18327, 1734, 29, 51, "Output"],
Cell[945428, 18358, 1522, 22, 35, "Output"],
Cell[946953, 18382, 1596, 26, 61, "Output"],
Cell[948552, 18410, 1573, 24, 35, "Output"],
Cell[950128, 18436, 53930, 975, 321, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1004095, 19416, 300, 8, 35, "Input"],
Cell[1004398, 19426, 242, 3, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1004677, 19434, 2105, 61, 257, "Input"],
Cell[1006785, 19497, 61992, 1111, 321, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1068814, 20613, 1923, 51, 146, "Input"],
Cell[1070740, 20666, 33848, 693, 548, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1104649, 21366, 375, 5, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[1105049, 21375, 654, 22, 74, "Input"],
Cell[1105706, 21399, 1922, 28, 256, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1107677, 21433, 408, 5, 62, "Subtitle"],
Cell[1108088, 21440, 122, 1, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1108235, 21445, 346, 6, 52, "Input"],
Cell[1108584, 21453, 254, 3, 35, "Output"]
}, Open  ]],
Cell[1108853, 21459, 1183, 35, 58, "Input"],
Cell[CellGroupData[{
Cell[1110061, 21498, 788, 20, 47, "Input"],
Cell[1110852, 21520, 1129, 30, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1112018, 21555, 1770, 44, 124, "Input"],
Cell[1113791, 21601, 20717, 425, 321, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1134545, 22031, 2806, 68, 190, "Input"],
Cell[1137354, 22101, 631, 9, 35, "Output"],
Cell[1137988, 22112, 633, 9, 35, "Output"],
Cell[1138624, 22123, 635, 9, 35, "Output"],
Cell[1139262, 22134, 634, 9, 35, "Output"],
Cell[1139899, 22145, 753, 14, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1140689, 22164, 1141, 27, 80, "Input"],
Cell[1141833, 22193, 19016, 398, 325, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1160886, 22596, 1492, 37, 124, "Input"],
Cell[1162381, 22635, 22017, 447, 325, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1184435, 23087, 119, 1, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1184579, 23092, 149, 2, 46, "Subsection"],
Cell[1184731, 23096, 3736, 64, 1554, "Input"],
Cell[CellGroupData[{
Cell[1188492, 23164, 640, 17, 40, "Input"],
Cell[1189135, 23183, 8009, 224, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1197181, 23412, 888, 24, 58, "Input"],
Cell[1198072, 23438, 498, 13, 70, "Output"],
Cell[1198573, 23453, 498, 13, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1199108, 23471, 205, 3, 34, "Subsubsection"],
Cell[1199316, 23476, 524, 11, 38, "Input"],
Cell[CellGroupData[{
Cell[1199865, 23491, 949, 20, 80, "Input"],
Cell[1200817, 23513, 34333, 665, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1235211, 24185, 212, 3, 35, "Subsection"],
Cell[CellGroupData[{
Cell[1235448, 24192, 1504, 36, 120, "Input"],
Cell[1236955, 24230, 536, 7, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1237528, 24242, 951, 20, 58, "Input"],
Cell[1238482, 24264, 90861, 1546, 548, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1329380, 25815, 1086, 23, 80, "Input"],
Cell[1330469, 25840, 41650, 786, 548, 26372, 535, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1372180, 26633, 214, 3, 35, "Subsubtitle"],
Cell[1372397, 26638, 441, 8, 55, "Text"],
Cell[CellGroupData[{
Cell[1372863, 26650, 97, 1, 46, "Subsection"],
Cell[1372963, 26653, 2635, 59, 119, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1375635, 26717, 111, 1, 46, "Subsection"],
Cell[1375749, 26720, 2685, 60, 119, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1378471, 26785, 142, 2, 46, "Subsection"],
Cell[1378616, 26789, 2730, 59, 119, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1381383, 26853, 252, 3, 46, "Subsection"],
Cell[1381638, 26858, 1244, 34, 106, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1382919, 26897, 197, 3, 46, "Subsection"],
Cell[1383119, 26902, 2857, 59, 119, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1386013, 26966, 188, 3, 46, "Subsection"],
Cell[1386204, 26971, 2581, 54, 102, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1388822, 27030, 145, 2, 46, "Subsection"],
Cell[1388970, 27034, 3285, 69, 119, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1392292, 27108, 231, 3, 46, "Subsection"],
Cell[1392526, 27113, 735, 19, 80, "Input"],
Cell[1393264, 27134, 805, 21, 69, "Input"],
Cell[CellGroupData[{
Cell[1394094, 27159, 1295, 33, 80, "Input"],
Cell[1395392, 27194, 2506, 54, 203, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1397935, 27253, 1091, 23, 80, "Input"],
Cell[1399029, 27278, 86641, 1478, 666, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1485707, 28761, 1272, 28, 80, "Input"],
Cell[1486982, 28791, 34143, 649, 647, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1521162, 29445, 4936, 116, 335, "Input"],
Cell[1526101, 29563, 57283, 1001, 397, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1583445, 30571, 149, 2, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1583619, 30577, 957, 27, 86, "Input"],
Cell[1584579, 30606, 816, 16, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1585432, 30627, 960, 25, 80, "Input"],
Cell[1586395, 30654, 437, 6, 35, "Output"],
Cell[1586835, 30662, 588, 12, 35, "Output"],
Cell[1587426, 30676, 459, 7, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1587922, 30688, 2211, 62, 143, "Input"],
Cell[1590136, 30752, 574, 8, 35, "Output"],
Cell[1590713, 30762, 575, 8, 35, "Output"],
Cell[1591291, 30772, 780, 15, 35, "Output"],
Cell[1592074, 30789, 726, 14, 35, "Output"],
Cell[1592803, 30805, 616, 10, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1593456, 30820, 787, 23, 51, "Input"],
Cell[1594246, 30845, 1418, 39, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1595701, 30889, 916, 27, 91, "Input"],
Cell[1596620, 30918, 689, 19, 54, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
